﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using ArcGIS.Core.CIM;
using ArcGIS.Core.Data;
using ArcGIS.Core.Data.UtilityNetwork;
using ArcGIS.Core.Geometry;
using ArcGIS.Desktop.Catalog;
using ArcGIS.Desktop.Core;
using ArcGIS.Desktop.Editing;
using ArcGIS.Desktop.Extensions;
using ArcGIS.Desktop.Framework;
using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Dialogs;
using ArcGIS.Desktop.Framework.Threading.Tasks;
using ArcGIS.Desktop.Mapping;

namespace UPDM_Addin
{
	class UPDM_Helper
	{

		public const string DomainNetwork = "Pipeline";
		public const string SystemTier = "Pipe Distribution System";
		public const string PressureTier = "Pipe Distribution Pressure";
		public const string IsolationTier = "Pipe Distribution Isolation";
		public const string DeviceName = "Pipeline Device";
		public const string LineName = "Pipeline Line";

		private static UtilityNetwork _un = null;

		public static UtilityNetwork GetUtilityNetwork()
		{

			if (_un != null)
				return _un;
			MapView mv = MapView.Active;
			foreach (Layer layer in mv.Map.Layers.OfType<Layer>())
			{
				UtilityNetwork un = GetUtilityNetworkFromLayer(layer);
				if (un == null)
					continue;
				_un = un;
				break;
			}
			if (_un == null)
				MessageBox.Show("Utility network not found.");
			return _un;

		}

		public static UtilityNetwork GetUtilityNetworkFromLayer(Layer layer)
		{

			UtilityNetwork un = null;
			if (layer is UtilityNetworkLayer)
			{
				UtilityNetworkLayer unLyr = layer as UtilityNetworkLayer;
				return unLyr.GetUtilityNetwork();
			}
			else if (layer is FeatureLayer)
			{
				FeatureLayer fLyr = layer as FeatureLayer;
				FeatureClass fc = fLyr.GetFeatureClass();
				if (!fc.IsControllerDatasetSupported())
					return null;
				foreach (Dataset dsController in fc.GetControllerDatasets())
				{
					if (dsController is UtilityNetwork)
						return dsController as UtilityNetwork;
					else
						dsController.Dispose();
				}
			}
			else if (layer is CompositeLayer)
			{
				CompositeLayer compLyr = layer as CompositeLayer;
				foreach (Layer lyr in compLyr.Layers)
				{
					un = GetUtilityNetworkFromLayer(lyr);
					if (un == null)
						continue;
					return un;
				}
			}
			return null;

		}

		public static FeatureClass GetFeatureClass(string sAliasName)
		{

			FeatureClass fc = null;
			UtilityNetwork un = GetUtilityNetwork();
			if (un == null)
				return null;
			Geodatabase gdb = un.GetDatastore() as Geodatabase;
			if (gdb == null)
				return null;
			foreach (FeatureClassDefinition fcDef in gdb.GetDefinitions<FeatureClassDefinition>())
			{
				string sName = fcDef.GetAliasName();
				if (sName != sAliasName)
					continue;
				fc = gdb.OpenDataset<FeatureClass>(fcDef.GetName());
				break;
			}
			if (fc == null)
				MessageBox.Show("Feature class '" + sAliasName + "' not found.");
			return fc;

		}

		public static Row FetchRowFromElement(UtilityNetwork un, Element elem)
		{

			using (Table table = un.GetTable(elem.NetworkSource))
			using (TableDefinition tableDef = table.GetDefinition())
			{
				QueryFilter qf = new QueryFilter()
				{
					WhereClause = String.Format("{0} = '{1}'", tableDef.GetGlobalIDField(), elem.GlobalID.ToString().ToUpper())
				};
				using (RowCursor cursor = table.Search(qf, false))
				{
					if (cursor.MoveNext())
						return cursor.Current;
					else
						return null;
				}
			}

		}



	}
}
