﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using ArcGIS.Core.CIM;
using ArcGIS.Core.Data;
using ArcGIS.Core.Data.UtilityNetwork;
using ArcGIS.Core.Data.UtilityNetwork.Extensions;
using ArcGIS.Core.Geometry;
using ArcGIS.Desktop.Catalog;
using ArcGIS.Desktop.Core;
using ArcGIS.Desktop.Editing;
using ArcGIS.Desktop.Extensions;
using ArcGIS.Desktop.Framework;
using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Dialogs;
using ArcGIS.Desktop.Framework.Threading.Tasks;
using ArcGIS.Desktop.Mapping;

namespace UPDM_Addin
{

	internal class btnClearAssociations : Button
	{

		protected override void OnClick()
		{
			QueuedTask.Run(() => { this.ClearAssociations(); });
		}

		private async void ClearAssociations()
		{

			int iAttachmentCount = 0;
			int iConnectionCount = 0;
			int iContainmentCount = 0;
			try
			{

				UtilityNetwork un = UPDM_Helper.GetUtilityNetwork();
				if (un == null)
					return;
				Envelope envFullExtent = un.GetExtent();

				// Get attachment association descriptions

				List<StructuralAttachmentAssociationDescription> Attachments = new List<StructuralAttachmentAssociationDescription>();
				IReadOnlyList<AssociationFeature> Att = un.GetAssociationFeatures(envFullExtent, AssociationType.Attachment);
				foreach (AssociationFeature feat in Att)
				{
					Element elemFrom = feat.FromElement;
					RowHandle rhFrom = new RowHandle(elemFrom, un);
					Element elemTo = feat.ToElement;
					RowHandle rhTo = new RowHandle(elemTo, un);
					StructuralAttachmentAssociationDescription attDesc = new StructuralAttachmentAssociationDescription(rhFrom, rhTo);
					Attachments.Add(attDesc);
				}

				// Get connection association descriptions

				List<ConnectivityAssociationDescription> Connections = new List<ConnectivityAssociationDescription>();
				IReadOnlyList<AssociationFeature> Conn = un.GetAssociationFeatures(envFullExtent, AssociationType.JunctionJunctionConnectivity);
				foreach (AssociationFeature feat in Conn)
				{
					Element elemFrom = feat.FromElement;
					RowHandle rhFrom = new RowHandle(elemFrom, un);
					Element elemTo = feat.ToElement;
					RowHandle rhTo = new RowHandle(elemTo, un);
					ConnectivityAssociationDescription connDesc = new ConnectivityAssociationDescription(rhFrom, rhTo);
					Connections.Add(connDesc);
				}

				// Get containment associations
				// [GetAssociationFeatures does not currently support containment associations]

				UtilityNetworkDefinition unDef = un.GetDefinition();
				DomainNetwork dn = unDef.GetDomainNetwork(UPDM_Helper.DomainNetwork);
				NetworkSource srcAssembly = null;
				foreach (NetworkSource src in dn.NetworkSources)
				{
					if (src.UsageType != SourceUsageType.Assembly)
						continue;
					srcAssembly = src;
					break;
				}
				if (srcAssembly == null)
				{
					MessageBox.Show("Assembly source not found.");
					return;
				}
				Table tabAssembly = un.GetTable(srcAssembly);
				List<ContainmentAssociationDescription> Containments = new List<ContainmentAssociationDescription>();
				using (RowCursor cursor = tabAssembly.Search(null, true))
				{
					while (cursor.MoveNext())
					{
						Row row = cursor.Current;
						Element elem = un.CreateElement(row);
						foreach (Association assoc in un.GetAssociations(elem, AssociationType.Containment))
						{
							Element elemFrom = assoc.FromElement;
							RowHandle rhFrom = new RowHandle(elemFrom, un);
							Element elemTo = assoc.ToElement;
							RowHandle rhTo = new RowHandle(elemTo, un);
							bool bVis = assoc.IsContainmentVisible;
							ContainmentAssociationDescription contDesc = new ContainmentAssociationDescription(rhFrom, rhTo, bVis);
							Containments.Add(contDesc);
						}
					}
				}

				// Perform delete operations

				foreach (StructuralAttachmentAssociationDescription desc in Attachments)
				{
					EditOperation op = new EditOperation();
					op.Delete(desc);
					await op.ExecuteAsync();
					iAttachmentCount++;
				}
				foreach(ConnectivityAssociationDescription desc in Connections)
				{
					EditOperation op = new EditOperation();
					op.Delete(desc);
					await op.ExecuteAsync();
					iConnectionCount++;
				}
				foreach(ContainmentAssociationDescription desc in Containments)
				{
					EditOperation op = new EditOperation();
					op.Delete(desc);
					await op.ExecuteAsync();
					iContainmentCount++;
				}

			}
			catch (Exception ex)
			{
				Debug.Print("ClearContainmentAssociations error: \n" + ex.Message);
				return;
			}

			string sMsg = "Associations deleted:";
			sMsg += "\nAttachment: " + iAttachmentCount.ToString();
			sMsg += "\nConnection: " + iConnectionCount.ToString();
			sMsg += "\nContainment:" + iContainmentCount.ToString();
			MessageBox.Show(sMsg);

		}

	}

}
