﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using ArcGIS.Core.CIM;
using ArcGIS.Core.Data;
using ArcGIS.Core.Data.UtilityNetwork;
using ArcGIS.Core.Data.UtilityNetwork.Extensions;
using ArcGIS.Core.Geometry;
using ArcGIS.Desktop.Catalog;
using ArcGIS.Desktop.Core;
using ArcGIS.Desktop.Editing;
using ArcGIS.Desktop.Extensions;
using ArcGIS.Desktop.Framework;
using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Dialogs;
using ArcGIS.Desktop.Framework.Threading.Tasks;
using ArcGIS.Desktop.Mapping;

namespace UPDM_Addin
{
	internal class btnClearSubnetworkControllers : Button
	{

		protected override void OnClick()
		{
			QueuedTask.Run(() => { this.ClearSubnetworkControllers(); });
		}

		private void ClearSubnetworkControllers()
		{

			int iCount = 0;
			try
			{
				UtilityNetwork un = UPDM_Helper.GetUtilityNetwork();
				if (un == null)
					return;
				SubnetworkManager sm = un.GetSubnetworkManager();
				UtilityNetworkDefinition unDef = un.GetDefinition();
				DomainNetwork dn = unDef.GetDomainNetwork(UPDM_Helper.DomainNetwork);
				List<Tier> Tiers = new List<Tier>();
				Tiers.Add(dn.GetTier(UPDM_Helper.SystemTier));
				Tiers.Add(dn.GetTier(UPDM_Helper.PressureTier));
				Tiers.Add(dn.GetTier(UPDM_Helper.IsolationTier));
				foreach (Tier tier in Tiers)
				{
					foreach (Subnetwork sn in sm.GetSubnetworks(tier, SubnetworkStates.All))
					{
						foreach (SubnetworkController snc in sn.GetControllers())
						{
							if (snc.IsDeleted)
								continue;
							Element elem = snc.Element;
							UtilityNetworkExtensions.DisableControllerInEditOperation(sm, elem);
							iCount++;
						}
					}
				}
			}
			catch (Exception ex)
			{
				Debug.Print("ClearSubnetworkControllers error: \n" + ex.Message);
				return;
			}
			MessageBox.Show("Controllers disabled: " + iCount.ToString());

		}


	}
}
