################################################################################################
#  Create UPDM 2018 Edition Integrity Module
#   CreateIntegrityModule_2018.py
#
#  Created on: 2018-03-05
#
#  Description: Purpose of this python script is to add the portion of the Utility and
#  Pipeline Data Model (UPDM) whose purpose is to support linear referencing data management
#  and to suport Transmission Integrity data management.
#
################################################################################################
import arcpy
from timeit import default_timer as timer
import logging
import sys
import os
arcpy.SetLogHistory(False)

file_logger = logging.FileHandler(filename=os.path.join(os.path.dirname(__file__), 'log_UPDM2018_Integrity.txt'), mode='w')
stream_logger = logging.StreamHandler(stream=sys.stdout)

logging.basicConfig(level=logging.DEBUG,
                    format="%(asctime)s\t%(message)s",
                    handlers=[file_logger, stream_logger])
logging.debug('Initialize')
try:    
    #########################
    # input Parameters
    #########################
    # Enterprise Geodatabase Connection File
    targetWorkspace = "C:/apps/Data/UPDM_Migration/AssetPackage_AZGas.gdb" # r"C:\Users\tom\Documents\ArcGIS\Projects\UPDM2018\UPDM2018.sde"    
    # SQL Server Database Name
    #SQLDatabaseName = "UPDM2018"
    # SQL Server Database Gas Domain Data Owner
    #SQLDatabaseOwner = "GIS"
    # SQL Server Data Prefix
    SQLPrefix = "/" # "\\" + SQLDatabaseName + "." + SQLDatabaseOwner + "."
    # Utility Network Name
    utilityNetworkName = "UtilityNetwork" # "PipeSystem"
    # Utility Network Gas Domain Name
    DomainName = "Pipeline"
    # Aggregated PipeSystem featureDataset Name
    featureDataset = SQLPrefix + utilityNetworkName
    # Aggregated P_Integrity featureDataset Name
    IntegrityfeatureDataset = SQLPrefix + "P_Integrity"
    # Aggregated Integrity Path
    IntegrityPath = targetWorkspace + IntegrityfeatureDataset

    ################################
    # Auto-defined script variables: Do Not Modify
    #################################
    UPDMAssembly = targetWorkspace + featureDataset + SQLPrefix + DomainName + "Assembly"
    UPDMDevice = targetWorkspace + featureDataset + SQLPrefix + DomainName + "Device"
    UPDMJunction = targetWorkspace + featureDataset + SQLPrefix + DomainName + "Junction"
    UPDMLine = targetWorkspace + featureDataset + SQLPrefix + DomainName + "Line"
    UPDMSubNetLine = targetWorkspace + featureDataset + SQLPrefix + DomainName + "SubnetLine"

    structureJunction = targetWorkspace + featureDataset + SQLPrefix + "StructureJunction"
    structureEdge = targetWorkspace + featureDataset + SQLPrefix + "StructureLine"
    structureBoundary = targetWorkspace + featureDataset + SQLPrefix + "StructureBoundary"
    
    #Auto-define new variables, because some tools don't like paths

    roleUPDMAssembly = DomainName + "Assembly"
    roleUPDMLine = DomainName + "Line"
    roleUPDMDevice = DomainName + "Device"
    roleUPDMJunction = DomainName + "Junction"
    serviceTerritoryName = "ServiceArea"
    roleStructureJunction = "StructureJunction"
    roleStructureEdge = "StructureLine"
    roleStructureBoundary = "StructureBoundary"

    # Environment valiables
    arcpy.env.workspace = targetWorkspace
    arcpy.env.preserveGlobalIds = True

    startTime = timer()

    #############################################################
    # Create Integrity Feature Dataset
    #############################################################
    logging.debug("Creating feature dataset P_Integrity...")
    arcpy.management.CreateFeatureDataset(targetWorkspace, "P_Integrity", featureDataset)
    logging.debug("Completed creation of feature dataset P_Integrity...")

    ########################################
    #Add Domains into the Geodatabase
    ########################################
    logging.debug("Creating Domains in the Geodatabase")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_AnomalyPriority", "List of valid priority status for identified anomaly", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyPriority", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyPriority", "Immediate", "Immediate")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyPriority", "Scheduled", "Scheduled")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyPriority", "Monitored", "Monitored")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_AnomalyRemediation", "List of valid remediations for identified anomaly", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyRemediation", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyRemediation", "Composite Sleeve", "Composite Sleeve")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyRemediation", "Coupling Reinforcement Sleeve", "Coupling Reinforcement Sleeve")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyRemediation", "Full Encirclement Welded Split Sleeve", "Full Encirclement Welded Split Sleeve")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyRemediation", "Pipe Cutout", "Pipe Cutout")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyRemediation", "Saddle Reinforcement Sleeve", "Saddle Reinforcement Sleeve")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyRemediation", "Weld Reinforcement Sleeve", "Weld Reinforcement Sleeve")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_AnomalySeverity", "List of valid rating of severity of identified anomaly", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalySeverity", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalySeverity", "High", "High")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalySeverity", "Medium", "Medium")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalySeverity", "Low", "Low")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_AnomalyStatus", "List of states of identified anomaly", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyStatus", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyStatus", "Previously Excavated", "Previously Excavated")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyStatus", "Proposed", "Proposed")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyStatus", "Postponed", "Postponed")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyStatus", "Pending Review", "Pending Review")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyStatus", "In Progress", "In Progress")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyStatus", "Scheduled", "Scheduled")
 
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_AnomalyType", "List of identified anomaly", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyType", "External Corrosion", "External Corrosion")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyType", "Internal Corrosion", "Internal Corrosion")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyType", "Dent", "Dent")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyType", "Gouge", "Gouge")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AnomalyType", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_APRActivityType", "List of valid types of Pipeline Referencing edit activities", "SHORT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_APRActivityType", 1, "Create Route")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_APRActivityType", 2, "Calibrate Route")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_APRActivityType", 3, "Reverse Route")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_APRActivityType", 4, "Retire Route")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_APRActivityType", 5, "Extend Route")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_APRActivityType", 6, "Reassign Route")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_APRActivityType", 7, "Realign Route")
                    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_APRNetworks", "List of valid types of Pipeline Referencing Networks", "SHORT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_APRNetworks", 1, "P_ContinuousNetwork")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_APRNetworks", 2, "P_EngineeringNetwork")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ConsequenceAreaType", "List of valid Consequence Area types", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ConsequenceAreaType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ConsequenceAreaType", "High", "High")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ConsequenceAreaType", "Medium", "Medium")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_CouldAffectIntersection", "Type of impact the pipe spillage could have on a transportation intersection", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectIntersection", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectIntersection", "Direct", "Direct")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectIntersection", "Indirect", "Indirect")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectIntersection", "Potential", "Potential")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_CouldAffectType", "List of valid areas impacted by spillage", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectType", "High Population", "High Population")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectType", "Other Population", "Other Population")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectType", "Ecological Area", "Ecological Area")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectType", "Drinking Water", "Drinking Water")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CouldAffectType", "Navigable Waterway", "Navigable Waterway")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_DASurveyType", "List of valid types of direct assessment", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DASurveyType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DASurveyType", "Close Interval Potential Survey", "Close Interval Potential Survey")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DASurveyType", "Direct Current Voltage Gradient", "Direct Current Voltage Gradient")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DASurveyType", "Pipeline Current Mapper", "Pipeline Current Mapper")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DASurveyType", "Pearson Survey", "Pearson Survey")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DASurveyType", "Alternate Current Voltage Gradient", "Alternate Current Voltage Gradient")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_DocumentMaturityIndex", "List of valid ratings of the quality of the documentation", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentMaturityIndex", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentMaturityIndex", "High", "High")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentMaturityIndex", "Medium", "Medium")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentMaturityIndex", "Low", "Low")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_DocumentType", "List of valid types of document format", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "Adobe Acrobat", "Adobe Acrobat (PDF)")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "Autocad Drawing", "Autocad Drawing (DWG)")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "Bitmap", "Bitmap (BMP)")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "GIF", "GIF")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "HTML", "HTML (HTM)")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "JPEG", "JPEG (JPG)")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "Microsoft Excel", "Microsoft Excel(XLS)")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "Microsoft Word", "Microsoft Word (DOC)")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "Microstation Drawing", "Microstation (DGN)")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "Text", "Text")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DocumentType", "TIFF", "TIFF")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_DOTClassSource", "List of methods for determining DOT classification", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DOTClassSource", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DOTClassSource", "Unknown (Verified)", "Unknown (Verified)")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DOTClassSource", "Calculated", "Calculated")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DOTClassSource", "Manual", "Manual")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_DOTClassType", "List of valid types of pipeline classification", "SHORT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DOTClassType", 0, "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DOTClassType", 1, "Class 1")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DOTClassType", 2, "Class 2")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DOTClassType", 3, "Class 3")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_DOTClassType", 4, "Class 4")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_HCAAreaType", "List of valid types of High Consequence Areas", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAAreaType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAAreaType", "20 or More Persons", "20 or More Persons")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAAreaType", "DOT Class 3", "DOT Class 3")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAAreaType", "DOT Class 4", "DOT Class 4")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAAreaType", "Limited Mobility", "Limited Mobility")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_HCAProvenance", "List of valid methods for defining consequence segments", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAProvenance", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAProvenance", "Class 3 or 4 Designation", "Class 3 or 4 Designation")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAProvenance", "Identified Site", "Identified Site")    
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAProvenance", "Sliding Circle and Class Designation", "Sliding Circle and Class Designation")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAProvenance", "Sliding Circle and Identified Site", "Sliding Circle and Identified Site")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_HCAProvenance", "Engineering Assessment", "Engineering Assessment")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "List of valid types of outside Areas for High Consequence Areas", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Assembly Area", "Assembly Area")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Beach", "Beach")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Campground", "Campground")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Cemetary", "Cemetary")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Outside Theatre", "Outside Theatre")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Park", "Park")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Parking Lot", "Parking Lot")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Playground", "Playground")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Recreational Area", "Recreational Area")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Amusement Park", "Amusement Park")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Athletic Field", "Athletic Field")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedSiteOutside", "Drive-In Theater", "Drive-In Theater")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ILISurveyMarkerType", "List of valid types of ground reference markers for inline inspections", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyMarkerType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyMarkerType", "AGR Timer Box", "AGR Time Box")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyMarkerType", "AGR Valve", "AGR Valve")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyMarkerType", "Monument", "Monument")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyMarkerType", "Crossing", "Crossing")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyMarkerType", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ILISurveyType", "List of valid types of ILI Surveys", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyType", "Metal Loss", "Metal Loss")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyType", "Crack", "Crack")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyType", "Mechanical Damage", "Mechanical Damage")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyType", "Material Defect", "Meterial Defect")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyType", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ILISurveyIntExtIndicator", "Indicator of whether the ILI Survey readings were internal or external", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyType", "Internal", "Internal")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ILISurveyType", "External", "External")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Type of inspection note captured during an inspection", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Environmental", "Environmental")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Gas Facility", "Gas Facility")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Hydrology", "Hydrology")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Line Crossing", "Line Crossing")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Maintenance", "Maintentance")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_InspectionRangeType", "List of Valid types of inspection ", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Close Interval Survey", "Close Interval Survey")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Exposed Pipe", "Exposed Pipe")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Aerial Survey", "Aerial Survey")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Visual Survey", "Visual Survey")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Cathodic Protection", "Cathodic Protection")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Inline", "Inline")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Gas Leak", "Gas Leak")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_InspectionNoteType", "Other", "Other")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LRSNetwork", "List of valid Linear Referencing Network Types for APR", "SHORT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LRSNetwork", 0, "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LRSNetwork", 1, "P_ContinuousNetwork")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LRSNetwork", 2, "P_EngineeringNetwork")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "List of Valid methods to establish a pipe system pressure", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "Design", "Design")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "Certificate", "Certificate")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "Grandfather", "Grandfather")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "Special Permit", "Special Permit")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "Pressure Type", "Pressure Type")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "Operator Assigned", "Operator Assigned")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "Historical", "Historical")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MAOPPressureEstabBy", "Other", "Other")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ObjectStatus_Integrity", "List of valid lifecycle status for a non-asset Integrity objects", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus_Integrity", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus_Integrity", "Conceptual", "Conceptual")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus_Integrity", "Proposed", "Proposed")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus_Integrity", "Active", "Active")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus_Integrity", "Inactive", "Inactive")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PressureTestMedium", "List of Valid Materials used to test pressure in a pipe system", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestMedium", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestMedium", "Air", "Air")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestMedium", "Gas", "Gas")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestMedium", "Nitrogen", "Nitrogen")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestMedium", "Inert Gas", "Inert Gas")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestMedium", "Water", "Water")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestMedium", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PressureTestType", "List of Valid types of pressure tests used on pipe system", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestType", "Strength", "Strength")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestType", "Spike", "Spike")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestType", "Yield", "Yield")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestType", "Uprating", "Uprating")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PressureTestType", "Other", "Other")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_DaysPerWeek_Integrity", "Valid Range of values for the number of days per week", "DOUBLE", "RANGE", "GEOMETRY_RATIO", "DEFAULT")
    arcpy.SetValueForRangeDomain_management(targetWorkspace, "UPDM_DaysPerWeek_Integrity", 0, 7)

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_WeeksPerYear_Integrity", "Valid Range of values for the number of weeks per year", "DOUBLE", "RANGE", "GEOMETRY_RATIO", "DEFAULT")
    arcpy.SetValueForRangeDomain_management(targetWorkspace, "UPDM_DaysPerWeek_Integrity", 0, 52)
    logging.debug("Completed creating Domains in the Geodatabase")

    #############################################################
    # Append onto UPDM Core Feature class UPDMAssembly
    #############################################################
    logging.debug("     Adding 13 Attributes to Assembly")
    arcpy.management.AddField(UPDMAssembly, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("      Set 1 Done")     
    arcpy.management.AddField(UPDMAssembly, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMAssembly, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("     Successfully Added 13 Attributes to Assembly")

    #############################################################
    # Append onto UPDM Core Feature class UPDMDevice
    #############################################################
    logging.debug("     Adding 13 Attributes to Device")
    arcpy.management.AddField(UPDMDevice, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMDevice, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMDevice, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMDevice, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)                             
    arcpy.management.AddField(UPDMDevice, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)   
    arcpy.management.AddField(UPDMDevice, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMDevice, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMDevice, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMDevice, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMDevice, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("      Set 1 Done")     
    arcpy.management.AddField(UPDMDevice, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMDevice, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMDevice, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("     Successfully Added 13 Attributes to Device")

    #############################################################
    # Append onto UPDM Core Feature class UPDMJunction
    #############################################################
    logging.debug("     Adding 13 Attributes to Junction")
    arcpy.management.AddField(UPDMJunction, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMJunction, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMJunction, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)                             
    arcpy.management.AddField(UPDMJunction, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMJunction, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)     
    arcpy.management.AddField(UPDMJunction, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)  
    arcpy.management.AddField(UPDMJunction, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMJunction, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMJunction, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMJunction, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("      Set 1 Done")     
    arcpy.management.AddField(UPDMJunction, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMJunction, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMJunction, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None) 
    logging.debug("     Successfully Added 13 Attributes to Junction")

    #############################################################
    # Append onto UPDM Core Feature class UPDMLine
    #############################################################
    logging.debug("     Adding 20 Attributes to Line")
    arcpy.management.AddField(UPDMLine, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None) 
    arcpy.management.AddField(UPDMLine, "ENGROUTEID", "TEXT", None, None, 38, "Enginering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "ENGROUTENAME", "TEXT", None, None, 100, "Enginering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "ENGTOROUTEID", "TEXT", None, None, 38, "Enginering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "ENGTOROUTENAME", "TEXT", None, None, 100, "Enginering To Route Name", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(UPDMLine, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("      Set 1 Done")       
    arcpy.management.AddField(UPDMLine, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(UPDMLine, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(UPDMLine, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(UPDMLine, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("     Successfully Added 20 Attributes to Line")

    #############################################################
    # Append onto UPDM Core Feature class StructureJunction
    #############################################################
    logging.debug("     Adding 14 Attributes to StructureJunction")
    arcpy.management.AddField(structureJunction, "ROTATION", "SHORT", None, None, None, "Rotation", "NULLABLE", "NON_REQUIRED", None) 
    arcpy.management.AddField(structureJunction, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(structureJunction, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureJunction, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureJunction, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureJunction, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureJunction, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None) 
    arcpy.management.AddField(structureJunction, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureJunction, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureJunction, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("       Set 1 Done")    
    arcpy.management.AddField(structureJunction, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(structureJunction, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureJunction, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureJunction, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("     Successfully Added 14 Attributes to StructureJunction")

    #############################################################
    # Append onto UPDM Core Feature class StructureLine
    #############################################################
    logging.debug("     Adding 20 Attributes to StructureLine")
    arcpy.management.AddField(structureEdge, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "ENGROUTEID", "TEXT", None, None, 38, "Enginering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "ENGROUTENAME", "TEXT", None, None, 100, "Enginering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "ENGTOROUTEID", "TEXT", None, None, 38, "Enginering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "ENGTOROUTENAME", "TEXT", None, None, 100, "Enginering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("       Set 1 Done")    
    arcpy.management.AddField(structureEdge, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(structureEdge, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    logging.debug("     Successfully Added 20 Attributes to StructureLine")
    
    ##############################################################
    # Defining P_Anomaly
    ##############################################################
    logging.debug("Create Point featureclass P_Anomaly class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_Anomaly", "POINT", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_Anomaly"

    #Adding Attributes to featureclass
    logging.debug("     Adding 43 Attribute to P_Anomaly")
    arcpy.management.AddField(InputDataset, "INSPECTIONDATE", "DATE", None, None, None, "Inspection Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ANOMALYTYPE", "TEXT", None, None, 50, "Anomaly Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ANOMALYSTATUS", "TEXT", None, None, 20, "Anomaly Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PRIORITY", "TEXT", None, None, 10, "Priority", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SEVERITY", "TEXT", None, None, 20, "Severity", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "DATECLOSED", "DATE", None, None, 20, "Date Closed", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATION", "TEXT", None, None, 255, "Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEPTH", "DOUBLE", 8, 3, None, "Depth", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LENGTH", "DOUBLE", 8, 3, None, "Length", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WIDTH", "DOUBLE", 8, 3, None, "Width", "NULLABLE", "NON_REQUIRED", None)   
    arcpy.management.AddField(InputDataset, "MAXIMUMDIAMETER", "DOUBLE", 8, 3, None, "Maximum Diameter", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MINIMUMDIAMETER", "DOUBLE", 8, 3, None, "Minimum Diameter", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ORIENTATION", "TEXT", None, None, 5, "Orientation", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OVALITY", "DOUBLE", 8, 3, None, "Ovality", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RECOMMENDEDREMEDIATION", "TEXT", None, None, 40, "Recommended Remediation", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RPRCALCULATED", "DOUBLE", 12, 3, None, "RPR Calculated", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RPRPIG", "DOUBLE", 12, 3, None, "RPR Pig", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RPRVARIANCE", "DOUBLE", 12, 3, None, "RPR Variance", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEPTHOFCOVERMIN", "DOUBLE", 12, 3, None, "Depth of Cover Min", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEPTHOFCOVERMAX", "DOUBLE", 12, 3, None, "Depth of Cover Max", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPRCALCULATED", "DOUBLE", 12, 3, None, "BPR Calculated", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPRPIG", "DOUBLE", 12, 3, None, "BPR Pig", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPRVARIANCE", "DOUBLE", 12, 3, None, "BPR Variance", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ANOMALYGROUP_GlobalID", "GUID", None, None, None, "Anomaly Group GlobalID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 43 Attributes to P_Anomaly")

    #Add Domains to Featureclass
    logging.debug("     Assigning 5 Domains to P_Anomaly")
    arcpy.management.AssignDomainToField(InputDataset, "ANOMALYTYPE", "UPDM_AnomalyType", None)
    arcpy.management.AssignDomainToField(InputDataset, "ANOMALYSTATUS", "UPDM_AnomalyStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "PRIORITY", "UPDM_AnomalyPriority", None)
    arcpy.management.AssignDomainToField(InputDataset, "SEVERITY", "UPDM_AnomalySeverity", None)
    arcpy.management.AssignDomainToField(InputDataset, "RECOMMENDEDREMEDIATION", "UPDM_AnomalyRemediation", None)
    logging.debug("     Successfully Assigned 5 Domains to P_Anomaly")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 0 Default Values to P_Anomaly")
    logging.debug("     Successfully Assigned 0 Default Values to P_Anomaly")
    logging.debug("Completed setting up the P_Anomaly featureclass...")
  
    ##############################################################
    # Defining P_AnomalyGroup
    ##############################################################    
    logging.debug("Create Point featureclass P_AnomalyGroup class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_AnomalyGroup", "POINT", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_AnomalyGroup"

    #Adding Attributes to featureclass
    logging.debug("     Adding 32 Attribute to P_AnomalyGroup")
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 15, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPRCALCULATEDAVERAGE", "DOUBLE", 12, 5, None, "Average BPR Calculated", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPRPIGAVERAGE", "DOUBLE", 12, 5, None, "BPR Pig Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPRVARIANCEAVERAGE", "DOUBLE", 12, 5, None, "BPR Pig Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEPTHAVERAGE", "DOUBLE", 8, 4, None, "Average Depth", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LENGTHAVERAGE", "DOUBLE", 8, 4, None, "Average Length", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WIDTHAVERAGE", "DOUBLE", 8, 4, None, "Average Width", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAXDIAMETERAVERAGE", "DOUBLE", 8, 4, None, "Average Max Diameter", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MINDIAMETERAVERAGE", "DOUBLE", 8, 4, None, "Average Min Diameter", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ORIENTATIONAVERAGE", "TEXT", None, None, 5, "Average Orientation", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RPRCALCULATEDAVERAGE", "DOUBLE", 8, 4, None, "Average Calculated RPR", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RPRPIGDAVERAGE", "DOUBLE", 8, 4, None, "Average Pig RPR", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RPRVARIANCEAVERAGE", "DOUBLE", 8, 4, None, "Average Variance RPR", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONRANGE_GlobalID", "GUID", None, None, None, "InspectionRange GlobalID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 32 Attributes to P_AnomalyGroup")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_AnomalyGroup")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", None)
    logging.debug("     Successfully Assigned 1 Domains to P_AnomalyGroup")

    #Add Relationship Class
    RelName = IntegrityPath + SQLPrefix + "P_AnomalyGroup_Anomaly"
    AnomalyPath = IntegrityPath + SQLPrefix + "P_Anomaly"
    arcpy.management.CreateRelationshipClass(InputDataset, AnomalyPath, RelName, "SIMPLE", "P_Anomaly", "P_AnomalyGroup", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "ANOMALYGROUP_GlobalID", None, None)
    logging.debug("Completed setting up the P_AnomalyGroup featureclass...")

    ##############################################################
    # Defining P_CalibrationPoint
    ##############################################################
    logging.debug("Create Point featureclass P_CalibrationPoint class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_CalibrationPoint", "POINT", None, "DISABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_CalibrationPoint"

    #Adding Attributes to featureclass
    logging.debug("     Adding 10 Attribute to P_CalibrationPoint")
    arcpy.management.AddField(InputDataset, "MEASURE", "DOUBLE", 12, 4, None, "Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ROUTEID", "TEXT", None, None, 38, "RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NETWORKID", "SHORT", None, None, None, "NetworkID", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 10 Attributes to P_CalibrationPoint")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_CalibrationPoint")
    arcpy.management.AssignDomainToField(InputDataset, "NETWORKID", "UPDM_LRSNetwork", None)
    logging.debug("     Successfully Assigned 1 Domains to P_CalibrationPoint")
    
    logging.debug("Completed setting up the P_CalibrationPoint featureclass...")
    
    ##############################################################
    # Defining P_Centerline
    ##############################################################
    logging.debug("Create Line featureclass P_Centerline class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_Centerline", "POLYLINE", None, "DISABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_Centerline"

    #Adding Attributes to featureclass
    logging.debug("     Adding 6 Attribute to P_Centerline")
    arcpy.management.AddField(InputDataset, "CENTERLINEID", "GUID", None, None, None, "Measure", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 6 Attributes to P_Centerline")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 0 Domains to P_Centerline")
    logging.debug("     Successfully Assigned 0 Domains to P_Centerline")
    
    logging.debug("Completed setting up the P_Centerline featureclass...")

    ##############################################################
    # Defining P_Centerline Accuracy
    ##############################################################
    logging.debug("Create Line featureclass P_CenterlineAccuracy class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_CenterlineAccuracy", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_CenterlineAccuracy"

    #Adding Attributes to featureclass
    logging.debug("     Adding 25 Attribute to P_CenterlineAccuracy")
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 25 Attributes to P_CenterlineAccuracy")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_CenterlineAccuracy")
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 1 Domains to P_CenterlineAccuracy")
    
    logging.debug("Completed setting up the P_CenterlineAccuracy featureclass...")

    ##############################################################
    # Defining P_Centerline_Sequence
    ##############################################################
    logging.debug("Create table P_Centerline_Sequence...")
    arcpy.management.CreateTable(targetWorkspace, "P_Centerline_Sequence", None, None)   
    InputDataset = targetWorkspace + SQLPrefix + "P_Centerline_Sequence"

    #Adding Attributes to featureclass
    logging.debug("     Adding 16 Attribute to P_Centerline_Sequence")    
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ROUTEID", "TEXT", None, None, 38, "RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CENTERLINEID", "GUID", None, None, None, "CenterLineIDGUID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NETWORKID", "SHORT", None, None, None, "NetworkID", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_Centerline_Sequence")
    arcpy.management.AssignDomainToField(InputDataset, "NETWORKID", "UPDM_LRSNetwork", None)
    logging.debug("     Successfully Assigned 1 Domains to P_Centerline_Sequence")
    
    logging.debug("Completed setting up the P_Centerline_Sequence table...")
    
    ##############################################################
    # Defining P_ConsequenceSegment
    ##############################################################
    logging.debug("Create Line featureclass P_ConsequenceSegment class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_ConsequenceSegment", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_ConsequenceSegment"

    #Adding Attributes to featureclass
    logging.debug("     Adding 36 Attribute to P_ConsequenceSegment")
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 15, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "HABITABLEBUILDINGCOUNT", "LONG", None, None, None, "Habitable Building Count", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CALCULATEDLENGTH", "DOUBLE", 8, 4, None, "Calculated Length", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATECALCULATED", "DATE", None, None, None, "Date Calculated", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAOP", "DOUBLE", 12, 3, None, "Date Calculated", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PIR", "DOUBLE", 12, 3, None, "Potential Impact Radius", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PIRFACTOR", "DOUBLE", 16, 8, None, "PIR Factor", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "TYPE", "TEXT", None, None, 40, "Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "METHOD", "LONG", None, None, None, "Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OUTSIDEDIAMETER", "DOUBLE", 12, 4, None, "Outside Diameter", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONSEQUENCEAREATYPE", "TEXT", None, None, 30, "Consequence Area Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REGULATORYTYPE", "SHORT", None, None, None, "Regulatory Type", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 36 Attributes to P_ConsequenceSegment")
    
    #Adding Subtype Values
    arcpy.SetSubtypeField_management(InputDataset, "METHOD", "")
    arcpy.SetDefaultSubtype_management(InputDataset, 0)    
    logging.debug("     Adding 3 Subtype Codes to P_ConsequenceSegment")    
    arcpy.management.AddSubtype(InputDataset, 0, "Installed")
    arcpy.management.AddSubtype(InputDataset, 1, "Calculated")
    arcpy.management.AddSubtype(InputDataset, 2, "Approved")

    logging.debug("     3 Subtype Codes created for P_ConsequenceSegment")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 4 Domains to P_ConsequenceSegment")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", "0;1;2")
    arcpy.management.AssignDomainToField(InputDataset, "CONSEQUENCEAREATYPE", "UPDM_ConsequenceAreaType", "0;1;2")
    arcpy.management.AssignDomainToField(InputDataset, "TYPE", "UPDM_HCAProvenance", "0;1;2")
    arcpy.management.AssignDomainToField(InputDataset, "REGULATORYTYPE", "UPDM_RegulatoryType", "0;1;2")
    logging.debug("     Successfully Assigned 4 Domains to P_ConsequenceSegment")
    
    logging.debug("Completed setting up the P_ConsequenceSegment featureclass...")

    ##############################################################
    # Defining P_ContinuousNetwork
    ##############################################################
    logging.debug("Create Line featureclass P_ContinuousNetwork class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_ContinuousNetwork", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_ContinuousNetwork"

    #Adding Attributes to featureclass
    logging.debug("     Adding 10 Attribute to P_ContinuousNetwork")
    arcpy.management.AddField(InputDataset, "ROUTEID", "TEXT", None, None, 38, "RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ROUTENAME", "TEXT", None, None, 100, "Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 10 Attributes to P_ContinuousNetwork")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 0 Domains to P_ContinuousNetwork")
    logging.debug("     Successfully Assigned 0 Domains to P_ContinuousNetwork")
    
    logging.debug("Completed setting up the P_ContinuousNetwork featureclass...")
  
    ##############################################################
    # Defining P_CouldAffectSegment
    ##############################################################
    logging.debug("Create Line featureclass P_CouldAffectSegment class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_CouldAffectSegment", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_CouldAffectSegment"

    #Adding Attributes to featureclass
    logging.debug("     Adding 28 Attribute to P_CouldAffectSegment")
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 30, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERSECTIONTYPE", "TEXT", None, None, 50, "Intersection Type", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "COULDAFFECTSEGMENTTYPE", "TEXT", None, None, 50, "Could Affect Segment Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)


    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 28 Attributes to P_CouldAffectSegment")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 3 Domains to P_CouldAffectSegment")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERSECTIONTYPE", "UPDM_CouldAffectIntersection", None)
    arcpy.management.AssignDomainToField(InputDataset, "COULDAFFECTSEGMENTTYPE", "UPDM_CouldAffectType", None)
    logging.debug("     Successfully Assigned 3 Domains to P_CouldAffectSegment")
    
    logging.debug("Completed setting up the P_CouldAffectSegment featureclass...")
    
    ##############################################################
    # Defining P_DASurveyReadings
    ##############################################################
    logging.debug("Create Point featureclass P_DASurveyReadings class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_DASurveyReadings", "POINT", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_DASurveyReadings"

    #Adding Attributes to featureclass
    logging.debug("     Adding 29 Attribute to P_DASurveyReadings")
    arcpy.management.AddField(InputDataset, "DATYPE", "TEXT", None, None, 50, "Direct Assessment Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONDATE", "DATE", None, None, None, "Inspection Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PSON", "DOUBLE", 12, 6, None, "PS On", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PSOFF", "DOUBLE", 12, 6, None, "PS Off", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STATICON", "DOUBLE", 12, 6, None, "Static On", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STATICOFF", "DOUBLE", 12, 6, None, "Static Off", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DCPOTENTIALVOLTS", "DOUBLE", 8, 4, None, "DC Potential Volts", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ACPOTENTIALVOLTS", "DOUBLE", 8, 4, None, "AC Potential Volts", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PCMCURRENT", "DOUBLE", 12, 6, None, "PCM Current", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "IRPERCENT", "DOUBLE", 12, 6, None, "IR Percent", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 29 Attributes to P_DASurveyReadings")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_DASurveyReadings")
    arcpy.management.AssignDomainToField(InputDataset, "DATYPE", "UPDM_DASurveyType", None)
    logging.debug("     Successfully Assigned 1 Domains to P_DASurveyReadings")

    logging.debug("Completed setting up the P_DASurveyReadings featureclass...")

    ##############################################################
    # Defining P_DocumentPoint
    ##############################################################
    logging.debug("Create Point featureclass P_DocumentPoint class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_DocumentPoint", "POINT", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_DocumentPoint"

    #Adding Attributes to featureclass
    logging.debug("     Adding 21 Attribute to P_DocumentPoint")
    arcpy.management.AddField(InputDataset, "DOCUMENTTYPE", "TEXT", None, None, 30, "Document Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DOCUMENTDESCRIPTION", "TEXT", None, None, 255, "Document Description", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 21 Attributes to P_DocumentPoint")

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_DocumentPoint")
    arcpy.management.AssignDomainToField(InputDataset, "DOCUMENTTYPE", "UPDM_DocumentType", None)
    logging.debug("     Successfully Assigned 1 Domains to P_DocumentPoint")

    logging.debug("Completed setting up the P_DocumentPoint featureclass...")
    
    ##############################################################
    # Defining P_DOTClass
    ##############################################################
    logging.debug("Create Line featureclass P_DOTClass class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_DOTClass", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_DOTClass"

    #Adding Attributes to featureclass
    logging.debug("     Adding 28 Attribute to P_DOTClass")
    arcpy.management.AddField(InputDataset, "CLASSTYPE", "SHORT", None, None, None, "Class Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CLASSSOURCE", "TEXT", None, None, 20, "Class Source", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "CLASSLENGTH", "DOUBLE", 16, 4, None, "Class Length", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CORRIDORWIDTH", "DOUBLE", 12, 4, None, "Corridor Width", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATECALCULATED", "DATE", None, None, None, "Date Calculated", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)


    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 28 Attributes to P_DOTClass")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 2 Domains to P_DOTClass")
    arcpy.management.AssignDomainToField(InputDataset, "CLASSSOURCE", "UPDM_DOTClassSource", None)
    arcpy.management.AssignDomainToField(InputDataset, "CLASSTYPE", "UPDM_DOTClassType", None)
    logging.debug("     Successfully Assigned 2 Domains to P_DOTClass")
    
    logging.debug("Completed setting up the P_DOTClass featureclass...")
    
    ##############################################################
    # Defining P_Elevation
    ##############################################################
    logging.debug("Create Point featureclass P_Elevation class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_Elevation", "POINT", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_Elevation"

    #Adding Attributes to featureclass
    logging.debug("     Adding 30 Attribute to P_Elevation")
    arcpy.management.AddField(InputDataset, "FEATUREELEVATION", "DOUBLE", 12, 4, None, "Feature Elevation", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GROUNDELEVATION", "DOUBLE", 12, 4, None, "Ground Elevation", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "WATERELEVATION", "DOUBLE", 12, 4, None, "Water Elevation", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MEASUREMENTUNITS", "SHORT", None, None, None, "Measurement Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MEASUREMENTDATE", "DATE", None, None, None, "Date Measured", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 30 Attributes to P_Elevation")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domain to P_Elevation")
    arcpy.management.AssignDomainToField(InputDataset, "MEASUREMENTUNITS", "UPDM_UnitsForLength", None)
    logging.debug("     Successfully Assigned 1 Domain to P_Elevation")
    
    logging.debug("Completed setting up the P_Elevation featureclass...")
    
    ##############################################################
    # Defining P_EngineeringNetwork
    ##############################################################
    logging.debug("Create Line featureclass P_EngineeringNetwork class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_EngineeringNetwork", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_EngineeringNetwork"

    #Adding Attributes to featureclass
    logging.debug("     Adding 10 Attribute to P_EngineeringNetwork")
    arcpy.management.AddField(InputDataset, "ROUTEID", "TEXT", None, None, 38, "RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ROUTENAME", "TEXT", None, None, 100, "Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LINEID", "TEXT", None, None, 38, "LineID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LINENAME", "TEXT", None, None, 100, "Line Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ORDERID", "LONG", None, None, None, "OrderID", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 10 Attributes to P_EngineeringNetwork")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 0 Domains to P_EngineeringNetwork")
    logging.debug("     Successfully Assigned 0 Domains to P_EngineeringNetwork")
    
    logging.debug("Completed setting up the P_EngineeringNetwork featureclass...")
    
    ##############################################################
    # Defining P_HighConsequenceArea
    ##############################################################
    logging.debug("Create Polygon featureclass P_HighConsequenceArea class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_HighConsequenceArea", "POLYGON", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_HighConsequenceArea"

    #Adding Attributes to featureclass
    logging.debug("     Adding 11 Attribute to P_HighConsequenceArea")
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 15, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "HCATYPE", "TEXT", None, None, 25, "Area Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONSEQUENCECLASS", "SHORT", None, None, None, "Consequence Class", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 255, "Comments", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 11 Attributes to P_HighConsequenceArea")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 3 Domains to P_HighConsequenceArea")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", None)
    arcpy.management.AssignDomainToField(InputDataset, "HCATYPE", "UPDM_HCAAreaType", None)
    arcpy.management.AssignDomainToField(InputDataset, "CONSEQUENCECLASS", "UPDM_DOTClassType", None)
    logging.debug("     Successfully Assigned 3 Domains to P_HighConsequenceAreat")
    
    logging.debug("Completed setting up the P_HighConsequenceArea featureclass...")
    
    ##############################################################
    # Defining P_ILIGroundRefMarkers
    ##############################################################
    logging.debug("Create Point featureclass P_ILIGroundRefMarkers class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_ILIGroundRefMarkers", "POINT", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_ILIGroundRefMarkers"

    #Adding Attributes to featureclass
    logging.debug("     Adding 27 Attribute to P_ILIGroundRefMarkers")
    arcpy.management.AddField(InputDataset, "MARKERTYPE", "TEXT", None, None, 50, "Marker Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ALTRFERENCE", "TEXT", None, None, 50, "ALternative Reference", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "CHAINAGESOURCE", "TEXT", None, None, 50, "Water Elevation", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATION", "TEXT", None, None, 50, "Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OFFSET", "DOUBLE", 12, 4, None, "Offset", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "OFFSETUNITS", "SHORT", None, None, None, "Offset Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFERENCENUMBER", "TEXT", None, None, 50, "Reference Number", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RUNDISTANCE", "DOUBLE", 12, 4, None, "Run Distance", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONRANGE_GlobalID", "GUID", None, None, None, "Inspection Range GlobalID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering Route ID", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 27 Attributes to P_ILIGroundRefMarkers")

    #Add Domains to Featureclass
    logging.debug("     Assigning 2 Domains to P_ILIGroundRefMarkers")
    arcpy.management.AssignDomainToField(InputDataset, "MARKERTYPE", "UPDM_ILISurveyMarkerType", None)
    arcpy.management.AssignDomainToField(InputDataset, "OFFSETUNITS", "UPDM_UnitsForLength", None)
    logging.debug("     Successfully Assigned 2 Domains to P_ILIGroundRefMarkers")

    logging.debug("Completed setting up the P_ILIGroundRefMarkers featureclass...")
    
    ##############################################################
    # Defining P_ILIInspectionRange
    ##############################################################
    logging.debug("Create Line featureclass P_ILIInspectionRange class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_ILIInspectionRange", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_ILIInspectionRange"

    #Adding Attributes to featureclass
    logging.debug("     Adding 10 Attribute to P_ILIInspectionRange")
    arcpy.management.AddField(InputDataset, "STARTODO", "DOUBLE", 16, 5, None, "Start ODO", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENDODO", "DOUBLE", 16, 5, None, "End ODO", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SEQUENCE", "LONG", None, None, None, "Sequence", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 255, "Comments", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INLINEINSPECTIONID", "GUID", None, None, None, "Inline Inspection ID", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "INSPECTIONYEAR", "SHORT", None, None, None, "Inspection Year", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CORROSIONMETALLOSSCHECK", "SHORT", None, None, None, "Corrosion and Metal Loss Check", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DENTDEFORMATIONCHECK", "SHORT", None, None, None, "Dent and Deformation Check", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CRACKLONGSEAMDEFECTCHECK", "SHORT", None, None, None, "Crack and Long Seam Defect Check", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OTHERINSPECTIONCHECK", "SHORT", None, None, None, "Other Inspection Check", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OTHERINSPECTIONTYPE", "TEXT", None, None, 50, "Other Inspection Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 10 Attributes to P_ILIInspectionRange")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 4 Domains to P_ILIInspectionRange")
    arcpy.management.AssignDomainToField(InputDataset, "CORROSIONMETALLOSSCHECK", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "DENTDEFORMATIONCHECK", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "CRACKLONGSEAMDEFECTCHECK", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "OTHERINSPECTIONCHECK", "UPDM_YesNoIndicator", None)
    logging.debug("     Successfully Assigned 4 Domains to P_ILIInspectionRange")
    
    #Assign Default values to Featureclass
    logging.debug("     Assigning 4 Defaults to P_ILIInspectionRange")
    arcpy.management.AssignDefaultToField(InputDataset, "CORROSIONMETALLOSSCHECK", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "DENTDEFORMATIONCHECK", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "CRACKLONGSEAMDEFECTCHECK", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "OTHERINSPECTIONCHECK", 0, None, False)
    logging.debug("     Successfully Assigned 4 Defaults to P_ILIInspectionRange")
    
    logging.debug("Completed setting up the P_ILIInspectionRange featureclass...")
    
    ##############################################################
    # Defining P_ILISurveyGroup
    ##############################################################
    logging.debug("Create Point featureclass P_ILISurveyGroup class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_ILISurveyGroup", "POINT", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_ILISurveyGroup"

    #Adding Attributes to featureclass
    logging.debug("     Adding 42 Attribute to P_ILISurveyGroup")
    arcpy.management.AddField(InputDataset, "ILISURVEYGROUPTYPE", "TEXT", None, None, 30, "ILI Survey Group Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ANOMALYCOUNT", "LONG", None, None, None, "Anomaly Count", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "RELDISTANCE", "DOUBLE", 12, 5, None, "Relative Distance", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RUNDISTANCE", "DOUBLE", 12, 5, None, "Run Distance", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SAFETYFACTOR", "DOUBLE", 12, 4, None, "Safety Factor", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "MAXDEPTHPERCENT", "DOUBLE", 12, 4, None, "Max Depth Percent", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAXDEPTH", "DOUBLE", 12, 5, None, "Max Depth", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAXDEPTHUNITS", "SHORT", None, None, None, "Max Depth Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GROUPLENGTH", "DOUBLE", 12, 5, None, "Group Length", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GROUPWIDTH", "DOUBLE", 12, 5, None, "Group Width", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GROUPAREA", "DOUBLE", 12, 5, None, "Group Area", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPRCALCULATEDAVERAGE", "DOUBLE", 12, 5, None, "BPR Calculated Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPRPIGAVERAGE", "DOUBLE", 12, 5, None, "BPR PIG Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPRVARIENCEAVERAGE", "DOUBLE", 12, 5, None, "BPR Varience Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RPRCALCULATEDAVERAGE", "DOUBLE", 12, 5, None, "RPR Calculated Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RPRPIGAVERAGE", "DOUBLE", 12, 5, None, "RPR Pig Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RPRVARIANCEAVERAGE", "DOUBLE", 12, 5, None, "RPR Variance Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WIDTHAVERAGE", "DOUBLE", 12, 5, None, "Width Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LENGTHAVERAGE", "DOUBLE", 12, 5, None, "Length Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEPTHAVERAGE", "DOUBLE", 12, 5, None, "Depth Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAXDIAMETERAVERAGE", "DOUBLE", 12, 5, None, "Max Diameter Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MINDIAMETERAVERAGE", "DOUBLE", 12, 5, None, "Min Diameter Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ORIENTATIONAVERAGE", "DOUBLE", 12, 5, None, "Orientation Average", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "R85BURSTPRESSURE", "DOUBLE", 12, 5, None, "R85 Burst Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering Route ID", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 42 Attributes to P_ILISurveyGroup")

    #Add Domains to Featureclass
    logging.debug("     Assigning 2 Domains to P_ILISurveyGroup")
    arcpy.management.AssignDomainToField(InputDataset, "ILISURVEYGROUPTYPE", "UPDM_ILISurveyType", None)
    arcpy.management.AssignDomainToField(InputDataset, "MAXDEPTHUNITS", "UPDM_UnitsForDepth", None)
    logging.debug("     Successfully Assigned 2 Domains to P_ILISurveyGroup")

    logging.debug("Completed setting up the P_ILISurveyGroup featureclass...")
    
    ##############################################################
    # Defining P_ILISurveyReadings
    ##############################################################
    logging.debug("Create Point featureclass P_ILISurveyReadings class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_ILISurveyReadings", "POINT", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_ILISurveyReadings"

    #Adding Attributes to featureclass
    logging.debug("     Adding 42 Attribute to P_ILISurveyReadings")
    arcpy.management.AddField(InputDataset, "SURVEYTYPE", "TEXT", None, None, 30, "ILI Survey Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FEATURECODE", "LONG", None, None, None, "Feature Count", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "RELDISTANCE", "DOUBLE", 12, 5, None, "Relative Distance", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RUNDISTANCE", "DOUBLE", 12, 5, None, "Run Distance", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEFECTORIENTATION", "LONG", None, None, None, "Defect Orientation", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "DEPTH", "DOUBLE", 12, 4, None, "Depth", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEPTHUNITS", "SHORT", None, None, None, "Depth Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LENGTH", "DOUBLE", 12, 5, None, "Length", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LENGTHUNITS", "SHORT", None, None, None, "Length Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LONGSEAMORIENTATION", "LONG", None, None, None, "Long Seam Orientation", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WALLTHICKNESS", "DOUBLE", 12, 5, None, "Wall Thickness", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WIDTH", "DOUBLE", 12, 5, None, "Width", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WIDTHUNITS", "SHORT", None, None, None, "Width Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEEPESTPOINTDEGREES", "LONG", None, None, None, "Deepest Point Degrees", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CLUSTERNO", "LONG", None, None, None, "Cluster Number", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CLUSTERRPR", "DOUBLE", 12, 5, None, "Cluster RPR", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PITRPR", "DOUBLE", 12, 5, None, "Pit RPR", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REMAININGWT", "DOUBLE", 12, 5, None, "Remaining WT", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RSTRENGTHRPR", "DOUBLE", 12, 5, None, "R Strength RPR", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTEXTINDICATOR", "TEXT", None, None, 10, "Internal External Indicator", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "USAGMDISTANCE", "DOUBLE", 12, 5, None, "US AGM Distance", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "USAGMREFERENCE", "TEXT", None, None, 50, "US AGM Reference", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DSAGMDISTANCE", "DOUBLE", 12, 5, None, "US AGM Distance", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DSAGMREFERENCE", "TEXT", None, None, 50, "DS AGM Reference", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ERF", "DOUBLE", 12, 5, None, "ERF", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BPR", "DOUBLE", 12, 5, None, "BPR", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LONGITUDE", "DOUBLE", 12, 8, None, "Longitude", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LATITUDE", "DOUBLE", 12, 8, None, "Latitude", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ILISURVEYGROUP_GlobalID", "GUID", None, None, None, "ILI Survey Group GlobalID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering Route ID", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 42 Attributes to P_ILISurveyReadings")

    #Add Domains to Featureclass
    logging.debug("     Assigning 5 Domains to P_ILISurveyReadings")
    arcpy.management.AssignDomainToField(InputDataset, "SURVEYTYPE", "UPDM_ILISurveyType", None)
    arcpy.management.AssignDomainToField(InputDataset, "DEPTHUNITS", "UPDM_UnitsForDepth", None)
    arcpy.management.AssignDomainToField(InputDataset, "LENGTHUNITS", "UPDM_UnitsForDiameter", None)
    arcpy.management.AssignDomainToField(InputDataset, "WIDTHUNITS", "UPDM_UnitsForDiameter", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTEXTINDICATOR", "UPDM_ILISurveyIntExtIndicator", None)
    logging.debug("     Successfully Assigned 5 Domains to P_ILISurveyReadings")
    
    #Add Relationship Class    
    RelName = IntegrityPath + SQLPrefix + "P_ILISurveyGroup_P_ILISurveyReading"
    ILISurveyGroup = IntegrityPath + SQLPrefix + "P_ILISurveyGroup"
    arcpy.management.CreateRelationshipClass(ILISurveyGroup, InputDataset, RelName, "SIMPLE", "P_ILISurveyReading", "P_ILISurveyGroup", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "ILISURVEYGROUP_GlobalID", None, None)

    logging.debug("Completed setting up the P_ILISurveyReadings featureclass...")
    
    ##############################################################
    # Defining P_InlineInspection
    ##############################################################
    logging.debug("Create Line featureclass P_InlineInspection class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_InlineInspection", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_InlineInspection"

    #Adding Attributes to featureclass
    logging.debug("     Adding 10 Attribute to P_InlineInspection")
    arcpy.management.AddField(InputDataset, "STARTDATE", "DATE", None, None, None, "Start Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENDDATE", "DATE", None, None, None, "End Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ILIVENDOR", "TEXT", None, None, 50, "ILI Vendor", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOOLTYPE", "TEXT", None, None, 50, "Tool Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STARTODO", "DOUBLE", 16, 5, None, "Start Odometer", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ENDODO", "DOUBLE", 16, 5, None, "End Odometer", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 255, "Comments", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 10 Attributes to P_InlineInspection")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 0 Domains to P_InlineInspection")
    logging.debug("     Successfully Assigned 0 Domains to P_InlineInspection")
    
    logging.debug("Completed setting up the P_InlineInspection featureclass...")
    
    ##############################################################
    # Defining P_InspectionNote
    ##############################################################
    logging.debug("Create Point featureclass P_InspectionNote class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_InspectionNote", "POINT", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_InspectionNote"

    #Adding Attributes to featureclass
    logging.debug("     Adding 22 Attribute to P_InspectionNote")
    arcpy.management.AddField(InputDataset, "INSPECTIONDATE", "DATE", None, None, None, "Inspection Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTOR", "TEXT", None, None, 30, "Inspector", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "NOTETYPE", "TEXT", None, None, 30, "Note Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 255, "Comments", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering Route ID", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 22 Attributes to P_InspectionNote")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_InspectionNote")
    arcpy.management.AssignDomainToField(InputDataset, "NOTETYPE", "UPDM_InspectionNoteType", None)
    logging.debug("     Successfully Assigned 1 Domains to P_InspectionNote")

    logging.debug("Completed setting up the P_InspectionNote featureclass...")
    
    ##############################################################
    # Defining P_InspectionRange
    ##############################################################
    logging.debug("Create Line featureclass P_InspectionRange class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_InspectionRange", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_InspectionRange"

    #Adding Attributes to featureclass
    logging.debug("     Adding 31 Attribute to P_InspectionRange")
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 15, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 255, "Comments", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONSTARTDATE", "DATE", None, None, None, "Inspection Start Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONENDDATE", "DATE", None, None, None, "Inspection End Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONRANGENAME", "TEXT", None, None, 50, "Inspection Range Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONTYPE", "TEXT", None, None, 30, "Inspection Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 31 Attributes to P_InspectionRange")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domain to P_InspectionRange")
    arcpy.management.AssignDomainToField(InputDataset, "INSPECTIONTYPE", "UPDM_InspectionRangeType", None)
    logging.debug("     Successfully Assigned 1 Domain to P_InspectionRange")
    
    #Add Relationship Class
    RelName = IntegrityPath + SQLPrefix + "P_InspRange_AnomalyGroup"
    DestinationGroupPath = IntegrityPath + SQLPrefix + "P_AnomalyGroup"
    arcpy.management.CreateRelationshipClass(InputDataset, DestinationGroupPath, RelName, "SIMPLE", "P_AnomalyGroup", "P_InspectionRange", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "INSPECTIONRANGE_GlobalID", None, None)
    logging.debug("Completed setting up the P_InspectionRange featureclass...")
    
    ##############################################################
    # Defining P_MAOPCalcRange
    ##############################################################
    logging.debug("Create Line featureclass P_MAOPCalcRange class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_MAOPCalcRange", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_MAOPCalcRange"

    #Adding Attributes to featureclass
    logging.debug("     Adding 31 Attribute to P_MAOPCalcRange")
    arcpy.management.AddField(InputDataset, "PRESSUREESTABLISHEDBY", "TEXT", None, None, 50, "Pressure Established By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DOCUMENTMATURITYINDEX", "TEXT", None, None, 50, "Document Maturity Index", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAOPDESIGN", "DOUBLE", 12, 4, None, "MAOP Design", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAOPTEST", "DOUBLE", 12, 4, None, "MAOP Test", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAOPRECORD", "DOUBLE", 12, 4, None, "MAOP Record", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAOPUNITOFMEASURE", "SHORT", None, None, None, "MAOP Unit of Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 31 Attributes to P_MAOPCalcRange")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 3 Domains to P_MAOPCalcRange")
    arcpy.management.AssignDomainToField(InputDataset, "PRESSUREESTABLISHEDBY", "UPDM_MAOPPressureEstabBy", None)
    arcpy.management.AssignDomainToField(InputDataset, "DOCUMENTMATURITYINDEX", "UPDM_DocumentMaturityIndex", None)
    arcpy.management.AssignDomainToField(InputDataset, "MAOPUNITOFMEASURE", "UPDM_UnitsForPressure", None)
    logging.debug("     Successfully Assigned 3 Domains to P_MAOPCalcRange")
    
    logging.debug("Completed setting up the P_MAOPCalcRange featureclass...")
    
    ##############################################################
    # Defining P_OperatingPressureRange
    ##############################################################
    logging.debug("Create Line featureclass P_OperatingPressureRange class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_OperatingPressureRange", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_OperatingPressureRange"

    #Adding Attributes to featureclass
    logging.debug("     Adding 27 Attribute to P_OperatingPressureRange")
    arcpy.management.AddField(InputDataset, "PRESSURETYPE", "TEXT", None, None, 50, "Pressure Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PRESSUREVALUE", "DOUBLE", 12, 4, None, "Pressure Value", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UNITOFMEASURE", "SHORT", None, None, None, "Unit of Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATEASSIGNED", "DATE", None, None, None, "Date Assigned", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 27 Attributes to P_OperatingPressureRange")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 3 Domains to P_OperatingPressureRange")
    arcpy.management.AssignDomainToField(InputDataset, "PRESSURETYPE", "UPDM_MAOPPressureEstabBy", None)
    arcpy.management.AssignDomainToField(InputDataset, "UNITOFMEASURE", "UPDM_UnitsForPressure", None)
    logging.debug("     Successfully Assigned 3 Domains to P_OperatingPressureRange")
    
    logging.debug("Completed setting up the P_OperatingPressureRange featureclass...")
    
    ##############################################################
    # Defining P_PipeExposure
    ##############################################################
    logging.debug("Create Line featureclass P_PipeExposure class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_PipeExposure", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_PipeExposure"

    #Adding Attributes to featureclass
    logging.debug("     Adding 29 Attribute to P_PipeExposure")
    arcpy.management.AddField(InputDataset, "LENGTHEXPOSED", "DOUBLE", 12, 4, None, "Length Exposed", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LENGTHUNITS", "SHORT", None, None, None, "Length Units", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "LOCATIONDESCRIPTION", "TEXT", None, None, 50, "Location Description", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONRANGE_GlobalID", "GUID", None, None, None, "Inspection Range GlobalID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 29 Attributes to P_PipeExposure")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_PipeExposure")
    arcpy.management.AssignDomainToField(InputDataset, "LENGTHUNITS", "UPDM_UnitsForLength", None)
    logging.debug("     Successfully Assigned 1 Domains to P_PipeExposure")

    #Add Relationship Class
    RelName = IntegrityPath + SQLPrefix + "P_InspRange_PipeExposure"
    DestinationGroupPath = IntegrityPath + SQLPrefix + "P_InspectionRange"
    arcpy.management.CreateRelationshipClass(DestinationGroupPath, InputDataset, RelName, "SIMPLE", "P_PipeExposure", "P_InspectionRange", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "INSPECTIONRANGE_GlobalID", None, None)    

    logging.debug("Completed setting up the P_PipeExposure featureclass...")
    
    ##############################################################
    # Defining P_Redline
    ##############################################################
    logging.debug("Create Line featureclass P_Redline class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_Redline", "POLYLINE", None, "DISABLED", "DISABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_Redline"

    #Adding Attributes to featureclass
    logging.debug("     Adding 12 Attribute to P_Redline")
    arcpy.management.AddField(InputDataset, "EFFECTIVEDATE", "DATE", None, None, None, "Effective Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NETWORKID", "SHORT", None, None, None, "NetworkID", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "ROUTEID", "TEXT", None, None, 38, "RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ACTIVITYTYPE", "SHORT", None, None, None, "Activity Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ROUTENAME", "TEXT", None, None, 100, "Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMMEASURE", "DOUBLE", None, None, None, "From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOMEASURE", "DOUBLE", None, None, None, "To Measure", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 12 Attributes to P_Redline")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 2 Domains to P_Redline")
    arcpy.management.AssignDomainToField(InputDataset, "NETWORKID", "UPDM_APRNetworks", None)
    arcpy.management.AssignDomainToField(InputDataset, "ACTIVITYTYPE", "UPDM_APRActivityType", None)
    logging.debug("     Successfully Assigned 2 Domains to P_Redline")
    
    logging.debug("Completed setting up the P_Redline featureclass...")
    
    ##############################################################
    # Defining P_TestPressureRange
    ##############################################################
    logging.debug("Create Line featureclass P_TestPressureRange class...")
    arcpy.management.CreateFeatureclass(IntegrityPath, "P_TestPressureRange", "POLYLINE", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = IntegrityPath + SQLPrefix + "P_TestPressureRange"

    #Adding Attributes to featureclass
    logging.debug("     Adding 29 Attribute to P_TestPressureRange")
    arcpy.management.AddField(InputDataset, "PRESSURETEST", "DOUBLE", 12, 4, None, "Pressure Test", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MINDESIGNPRESSURE", "DOUBLE", 12, 4, None, "Minimum Design Pressure", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "MINADJUSTEDPRESSURE", "DOUBLE", None, None, 38, "Minimum Adjusted Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UNITOFMEASURE", "SHORT", None, None, None, "Unit of Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PRETEST", "SHORT", None, None, None, "PreTest", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TESTDATE", "DATE", None, None, None, "Test Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TESTMEDIUM", "TEXT", None, None, 25, "Test Medium", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TESTNAME", "TEXT", None, None, 50, "Test Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TESTTYPE", "TEXT", None, None, 25, "Test Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 29 Attributes to P_TestPressureRange")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 4 Domains to P_TestPressureRange")
    arcpy.management.AssignDomainToField(InputDataset, "UNITOFMEASURE", "UPDM_UnitsForPressure", None)
    arcpy.management.AssignDomainToField(InputDataset, "PRETEST", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "TESTMEDIUM", "UPDM_PressureTestMedium", None)
    arcpy.management.AssignDomainToField(InputDataset, "TESTTYPE", "UPDM_PressureTestType", None)
    logging.debug("     Successfully Assigned 4 Domains to P_TestPressureRange")

    #Assign Default values to Featureclass
    logging.debug("     Assigning 4 Defaults to P_ILIInspectionRange")
    arcpy.management.AssignDefaultToField(InputDataset, "PRETEST", 0, None, False)
    logging.debug("     Successfully Assigned 4 Defaults to P_ILIInspectionRange")
    
    logging.debug("Completed setting up the P_TestPressureRange featureclass...")
    
    ##############################################################
    # Defining P_DrinkingWater
    ##############################################################
    logging.debug("Create Polygon featureclass P_DrinkingWater class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_DrinkingWater", "POLYGON", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_DrinkingWater"

    #Adding Attributes to featureclass
    logging.debug("     Adding 11 Attribute to P_DrinkingWater")
    arcpy.management.AddField(InputDataset, "DRINKINGWATERNAME", "TEXT", None, None, 50, "Drinking Water Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DRINKINGWATERTYPE", "TEXT", None, None, 50, "Drinking Water Type", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 20, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DISCOVERYDATE", "DATE", None, None, None, "Discovery Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOURCE", "TEXT", None, None, 50, "Source", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 11 Attributes to P_DrinkingWater")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_DrinkingWater")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", None)
    logging.debug("     Successfully Assigned 1 Domains to P_DrinkingWater")
    
    logging.debug("Completed setting up the P_DrinkingWater featureclass...")
    
    ##############################################################
    # Defining P_EcologicalArea
    ##############################################################
    logging.debug("Create Polygon featureclass P_EcologicalArea class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_EcologicalArea", "POLYGON", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_EcologicalArea"

    #Adding Attributes to featureclass
    logging.debug("     Adding 11 Attribute to P_EcologicalArea")
    arcpy.management.AddField(InputDataset, "AREANAME", "TEXT", None, None, 50, "Area Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ECOLOGICALAREATYPE", "TEXT", None, None, 50, "Ecological Area Type", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 20, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DISCOVERYDATE", "DATE", None, None, None, "Discovery Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOURCE", "TEXT", None, None, 50, "Source", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 11 Attributes to P_EcologicalArea")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_EcologicalArea")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", None)
    logging.debug("     Successfully Assigned 1 Domains to P_EcologicalArea")
    
    logging.debug("Completed setting up the P_EcologicalArea featureclass...")
    
    ##############################################################
    # Defining P_HighPopulatedArea
    ##############################################################
    logging.debug("Create Polygon featureclass P_HighPopulatedArea class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_HighPopulatedArea", "POLYGON", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_HighPopulatedArea"

    #Adding Attributes to featureclass
    logging.debug("     Adding 11 Attribute to P_HighPopulatedArea")
    arcpy.management.AddField(InputDataset, "AREANAME", "TEXT", None, None, 50, "Area Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "AREATYPE", "TEXT", None, None, 50, "Ecological Area Type", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 20, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DISCOVERYDATE", "DATE", None, None, None, "Discovery Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOURCE", "TEXT", None, None, 50, "Source", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 11 Attributes to P_HighPopulatedArea")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_HighPopulatedArea")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", None)
    logging.debug("     Successfully Assigned 1 Domains to P_HighPopulatedArea")
    
    logging.debug("Completed setting up the P_HighPopulatedArea featureclass...")
    
    ##############################################################
    # Defining P_NavigableWaterway
    ##############################################################
    logging.debug("Create Polygon featureclass P_NavigableWaterway class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_NavigableWaterway", "POLYGON", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_NavigableWaterway"

    #Adding Attributes to featureclass
    logging.debug("     Adding 11 Attribute to P_NavigableWaterway")
    arcpy.management.AddField(InputDataset, "WATERWAYNAME", "TEXT", None, None, 50, "Waterway Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WATERWAYTYPE", "TEXT", None, None, 50, "Waterway Type", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 20, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DISCOVERYDATE", "DATE", None, None, None, "Discovery Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOURCE", "TEXT", None, None, 50, "Source", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 11 Attributes to P_NavigableWaterway")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_NavigableWaterway")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", None)
    logging.debug("     Successfully Assigned 1 Domains to P_NavigableWaterway")
    
    logging.debug("Completed setting up the P_NavigableWaterway featureclass...")
    
    ##############################################################
    # Defining P_OtherPopulatedArea
    ##############################################################
    logging.debug("Create Polygon featureclass P_OtherPopulatedArea class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_OtherPopulatedArea", "POLYGON", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_OtherPopulatedArea"

    #Adding Attributes to featureclass
    logging.debug("     Adding 12 Attribute to P_OtherPopulatedArea")
    arcpy.management.AddField(InputDataset, "POPULATEDAREANAME", "TEXT", None, None, 50, "Waterway Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TYPE", "TEXT", None, None, 50, "Waterway Type", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 20, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OCCUPANTCOUNT", "SHORT", None, None, None, "Occupant Count", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "DISCOVERYDATE", "DATE", None, None, None, "Discovery Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOURCE", "TEXT", None, None, 50, "Source", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 12 Attributes to P_OtherPopulatedArea")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_OtherPopulatedArea")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", None)
    logging.debug("     Successfully Assigned 1 Domains to P_OtherPopulatedArea")
    
    logging.debug("Completed setting up the P_OtherPopulatedArea featureclass...")
    
    ##############################################################
    # Defining P_OutsideArea
    ##############################################################
    logging.debug("Create Polygon featureclass P_OutsideArea class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_OutsideArea", "POLYGON", None, "ENABLED", "ENABLED", None, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_OutsideArea"
    
    logging.debug("     Adding 15 Attribute to P_OutsideArea")
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 20, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "IDENTIFIEDSITE", "SHORT", None, None, None, "Identified Site", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "IDENTIFIEDSITETYPE", "TEXT", None, None, 30, "Identified Site Type", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "DAYSPERWEEK", "SHORT", None, None, None, "Days Per Week", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WEEKSPERYEAR", "SHORT", None, None, None, "Weeks Per Year", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "IMPAIREDMOBILITY", "SHORT", None, None, None, "Impaired Mobility", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "GATHERINGPLACE", "SHORT", None, None, None, "Gathering Place", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DISCOVERYDATE", "DATE", None, None, None, "Discovery Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOURCE", "TEXT", None, None, 50, "Source", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 15 Attributes to P_OutsideArea")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 7 Domains to P_OutsideArea")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus_Integrity", None)
    arcpy.management.AssignDomainToField(InputDataset, "IDENTIFIEDSITE", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "IDENTIFIEDSITETYPE", "UPDM_IdentifiedSiteOutside", None)
    arcpy.management.AssignDomainToField(InputDataset, "DAYSPERWEEK", "UPDM_DaysPerWeek_Integrity", None)
    arcpy.management.AssignDomainToField(InputDataset, "IMPAIREDMOBILITY", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "GATHERINGPLACE", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "WEEKSPERYEAR", "UPDM_WeeksPerYear_Integrity", None)
    logging.debug("     Successfully Assigned 7 Domains to P_OutsideArea")

    #Assign Default values to Featureclass
    logging.debug("     Assigning 3 Defaults to P_P_OutsideArea")
    arcpy.management.AssignDefaultToField(InputDataset, "IDENTIFIEDSITE", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "IMPAIREDMOBILITY", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "GATHERINGPLACE", 0, None, False)
    logging.debug("     Successfully Assigned 3 Defaults to P_OutsideArea")
    
    logging.debug("Completed setting up the P_OutsideArea featureclass...")
    
    endTime = timer()
    totalElapsedTime = endTime - startTime
    logging.debug("OVERALL PROCESS COMPLETE in : " + str(totalElapsedTime))

    print(arcpy.GetMessages())
    logging.shutdown()
except:
    logging.debug("Exception occured")
    logging.shutdown()
