﻿# Migrate_assembly.py [Python 3.6]

# Feature classes migrated [-> PipelineAssembly]: 
#   TownBorderStation [except POC Valves]
#   RegulatorStation
#   RuralTap
#   MeterSetting
# Tables migrated:
#   METER -> METER

print("Migrate_assembly.py")
print("Initalizing...")

import arcpy
from datetime import datetime
import traceback
import uuid
from Migrate_helper import MigrateHelper

class MigrateAssembly(object):
    # Constants
    _bSkipProposed = True

    # Private fields
    __helper = None
    __bNewAssetGroup = False
    __sSourceGDB = ""
    __sTargetGDB = ""
    __sTempGDB = arcpy.env.scratchGDB
    __sTargetFC = ""
    __sLineFC = ""
    __sDeviceFC = ""
    __sJunctionFC = ""
    __sAssociationTab = ""
    __sControllerTab = ""
    __sMeterTab = ""
    __cursor = None
    __cursorJunction = None
    __cursorDevice = None
    __cursorAssociation = None
    __cursorController = None
    __Towns = {}
    __TownSubstitutes = {}
    __OutlierSubstitutes = {}
    __MeterOffsets = {}

    def __init__(self):
        self.__helper = MigrateHelper()
        self.__bNewAssetGroup = self.__helper._bNewAssetGroup
        self.__sSourceGDB = self.__helper._sSourceGDB
        self.__sTargetGDB = self.__helper._sWorkingDir + "/" + self.__helper._sTargetGDBName
        self.__sTargetFC = self.__sTargetGDB + "/PipelineAssembly"
        self.__sLineFC = self.__sTargetGDB + "/PipelineLine"
        self.__sDeviceFC = self.__sTargetGDB + "/PipelineDevice"
        self.__sJunctionFC = self.__sTargetGDB + "/PipelineJunction"
        self.__sAssociationTab = self.__sTargetGDB + "/C_Associations"
        self.__sControllerTab = self.__sTargetGDB + "/C_SubnetworkControllers"
        self.__sMeterTab = self.__sTargetGDB + "/METER"
        return

    def DoIt(self):
        print("Running...")
        dtStart = datetime.now()

        # Set up town system names
        self.__GetGeneralTowns()

        # Populate town border stations
        with arcpy.da.Editor(self.__sTargetGDB) as edit:
            self.__MigrateTownBorderStation()

        # Populate regulator stations
        with arcpy.da.Editor(self.__sTargetGDB) as edit:
            self.__MigrateRegulatorStation()

        # Populate rural taps
        with arcpy.da.Editor(self.__sTargetGDB) as edit:
            self.__MigrateRuralTap()

        # Populate meter settings
        with arcpy.da.Editor(self.__sTargetGDB) as edit:
            self.__MigrateMeterSetting()

        # Populate meters
        with arcpy.da.Editor(self.__sTargetGDB) as edit:
            self.__MigrateMeter()

        dtEnd = datetime.now()
        print("Done.")
        print("Elapsed time: " + str(dtEnd - dtStart))
        return

    def __GetGeneralTowns(self):
        # Get general town limit polygons
        print("Getting general towns...")
        self.__Towns = {}
        sTownGDB = self.__helper._sWorkingDir + "/" + self.__helper._sUTM84GDBName
        sTownFC = sTownGDB + "/general_town_limit"
        in_fields = ["TOWN_NAME", "SHAPE@"]
        with arcpy.da.SearchCursor(sTownFC, in_fields) as cursorIn:
            for in_row in cursorIn:
                self.__Towns[in_row[0]] = in_row[1]
        self.__TownSubstitutes = {"SNOWFLAKE":"SHOW LOW",
                           "TAYLOR":"SHOW LOW",
                           "PINETOP/LAKESIDE":"SHOW LOW",
                           "DEWEY":"PRESCOTT",
                           "PRESCOTT VALLEY":"PRESCOTT",
                           "CHINO VALLEY":"PRESCOTT",
                           "PAULDEN":"PRESCOTT",
                           "SEDONA":"COTTONWOOD",
                           "VILLAGE OF OAK CREEK":"COTTONWOOD",
                           "CLARKDALE":"COTTONWOOD",
                           "JEROME":"COTTONWOOD",
                           "CAMP VERDE":"COTTONWOOD",
                           "SLEEPY HOLLOW":"ASH FORK"}
        self.__OutlierSubstitutes = {"1ST CUT SYSTEM 7":"SHOW LOW",
                           "BLOCK VALVE #1":"SHOW LOW",
                           "GRIFFITH EL PASO":"GOLDEN VALLEY",
                           "I-40 & HIGHWAY 95":"LAKE HAVASU CITY",
                           "SEDONA":"COTTONWOOD",
                           "VERDE VALLEY H.P. SUPPLY":"COTTONWOOD"}
        return

    def __MigrateTownBorderStation(self):
        sFCName = "TownBorderStation"
        print("Migrating " + sFCName + "...")

        # Create insert cursors
        out_fields = ["ASSETGROUP", "ASSETTYPE", "CREATIONDATE", "CREATOR", 
                      "LASTUPDATE", "UPDATEDBY", "INSERVICEDATE", "ASSETID", 
                      "NAME", "LIFECYCLESTATUS", "ROTATION", "ODORIZERINDICATOR", 
                      "ASSETUNITCODE", "WORKORDERID", "TYPE", "STATION_SUPPLIER", 
                      "SUPPLIER_IDENTIFICATION_NUMBER", "SEQUENTIAL_FILE_NUMBER", "PHOTOS", "CHART_DATE", 
                      "SHAPE@", "LEGACY_OID", "GLOBALID"
                      ]
        self.__cursor = arcpy.da.InsertCursor(self.__sTargetFC, out_fields)
        out_fields = ["ASSETGROUP", "ASSETTYPE", "SHAPE@", "GLOBALID"]
        self.__cursorJunction = arcpy.da.InsertCursor(self.__sJunctionFC, out_fields)
        out_fields = ["ASSETGROUP", "ASSETTYPE", "CREATIONDATE", "CREATOR", 
                        "LASTUPDATE", "UPDATEDBY", "INSERVICEDATE", "ASSETID", 
                        "LOCATIONDESCRIPTION", "LIFECYCLESTATUS", "ROTATION", "WORKORDERID",  
                        "SEQUENTIAL_FILE_NUMBER", "CHART_DATE", "SHAPE@", "LEGACY_OID",
                        "GLOBALID"
                        ]
        self.__cursorDevice = arcpy.da.InsertCursor(self.__sDeviceFC, out_fields)
        out_fields = ["ASSOCIATION_TYPE", "FROM_DOMAIN_NETWORK", "FROM_FEATURE_CLASS", "FROM_ASSET_GROUP",
                      "FROM_ASSET_TYPE", "FROM_GLOBAL_ID", "FROM_TERMINAL", "TO_DOMAIN_NETWORK", 
                      "TO_FEATURE_CLASS", "TO_ASSET_GROUP", "TO_ASSET_TYPE", "TO_GLOBAL_ID", 
                      "TO_TERMINAL", "CONTENT_VISIBLE"
                      ]
        self.__cursorAssociation = arcpy.da.InsertCursor(self.__sAssociationTab, out_fields)
        out_fields = ["CONTROLLER_NAME", "GLOBAL_ID", "DOMAIN_NETWORK", "ASSET_GROUP",
                      "ASSET_TYPE", "TERMINAL", "TIER_NAME", "SUBNETWORK_NAME"
                      ]
        self.__cursorController = arcpy.da.InsertCursor(self.__sControllerTab, out_fields)

        # Get projected shapes
        print("   Getting projected shapes...")
        ProjectedShapes = self.__helper.GetProjectedShapes(sFCName)

        # Get connected lines
        print("   Getting connected lines...")
        ConnectedLines, LineGeoms = self.__helper.GetConnectedLines(sFCName)

        # Create SearchCursor
        print("   Processing rows...")
        sSourceFC = self.__sSourceGDB + "/" + sFCName
        in_fields = ["DATECREATED", "CREATIONUSER", "DATEMODIFIED", "LASTUSER", 
                     "INSERVICEDATE", "FACILITYID", "NAME", "WORKFUNCTION", 
                     "SYMBOLROTATION", "ODORIZER", "PROPERTYUNITCODE", "WORKORDERID", 
                     "TYPE", "SUPPLIER", "SUPPLIER_IDENTIFICATION_NUMBER", "SEQUENTIAL_FILE_NUMBER", 
                     "PHOTOS", "CHART_DATE", "GLOBALID", "OBJECTID"
                     ]
        iCount = 0
        with arcpy.da.SearchCursor(sSourceFC, in_fields) as cursorIn:
            for in_row in cursorIn:
                iWorkFunction = in_row[7]
                if self._bSkipProposed and iWorkFunction == 1:
                    continue
                sGlobalID = in_row[18]
                if sGlobalID not in ProjectedShapes:
                    continue
                shape = ProjectedShapes[sGlobalID]
                iLineAssetGroup = 0
                if sGlobalID in ConnectedLines:
                    LineRecs = ConnectedLines[sGlobalID]
                    LineRec = LineRecs[0]
                    sLineGID = LineRec[0]
                    iLineAssetGroup = LineRec[1]
                    bTransmission = None
                    if iLineAssetGroup == 2:
                        bTransmission = False
                    elif iLineAssetGroup == 3:
                        bTransmission = True
                    sPressureName = LineRec[3]

                # Process row
                self.__ProcessTBSRow(in_row, shape, bTransmission, sPressureName)
                # Fewer than 1000 records
        del self.__cursor
        del self.__cursorJunction
        del self.__cursorDevice
        del self.__cursorAssociation
        del self.__cursorController
        del ProjectedShapes
        del ConnectedLines
        del LineGeoms
        return

    def __ProcessTBSRow(self, in_row, shape, bTransmission, sPressureName):
        # Get TBS attributes
        iAssetGroup = 5 # "Town Border Station"
        iAssetType = 161 # "Town Border Station"
        dtCreated = in_row[0]
        sCreationUser = in_row[1]
        dtModified = in_row[2]
        sLastUser = in_row[3]
        dtInService = in_row[4]
        sFacilityID = in_row[5]
        sName = in_row[6]

        # Domain: UPDM_LifeCycleStatus
        iLifeCycle = 3 # "In Service"
        iWorkFunction = in_row[7]
        if iWorkFunction == 1:
            iLifeCycle = 1 # "Proposed"

        dSymbolRotation = in_row[8]

        # Domain: UPDM_YesNoIndicator
        iOdorizer = None
        sOdorizer = in_row[9]
        if sOdorizer == "Yes":
            iOdorizer = 1
        elif sOdorizer == "No":
            iOdorizer = 2

        sUnitCode = in_row[10]
        sWorkOrderID = in_row[11]
        sType = in_row[12]
        bPOCV = (sType == "Point Of Custody Valve (POCV)")
        sSupplier = in_row[13]
        sSupplierID = in_row[14]
        sSFN = in_row[15]
        sPhotos = in_row[16]
        dtChart = in_row[17]
        sAssemblyGID = in_row[18]
        iAssemblyOID = in_row[19]

        dtNow = datetime.now()
        sMigrationUser = "UPDM Migration"
        if not bPOCV:
            # Create TBS row
            out_row = [iAssetGroup, iAssetType, dtCreated, sCreationUser, 
                        dtModified, sLastUser, dtInService, sFacilityID, 
                        sName, iLifeCycle, dSymbolRotation, iOdorizer,
                        sUnitCode, sWorkOrderID, sType, sSupplier, 
                        sSupplierID, sSFN, sPhotos, dtChart, 
                        shape, iAssemblyOID, sAssemblyGID
                        ]
            self.__cursor.insertRow(out_row)

        # Create offset shapes
        dZ = 0.25
        env = shape.extent
        dX = env.XMax
        dY = env.YMax
        sr = shape.spatialReference
        pt = arcpy.Point(dX, dY, dZ)
        shapeSystem = arcpy.PointGeometry(pt, sr, True, True)
        pt = arcpy.Point(dX, dY, -dZ)
        shapePressure = arcpy.PointGeometry(pt, sr, True, True)

        # Create system junction
        sJunctionGID = "{" + str(uuid.uuid4()).upper() + "}"
        iAssetGroup = 21 # Connection Point
        iAssetType = 803 # System Connection
        out_row = [iAssetGroup, iAssetType, shape, sJunctionGID]
        self.__cursorJunction.insertRow(out_row)

        # Create system device row and associations
        sNewAssetGroup = self.__helper._sNewAssetGroupName
        if bPOCV:
            iSystemAssetGroup = 3 # "Controllable Valve"
            sSystemAssetGroup = "Controllable Valve"
            iSystemAssetType = 485 # "System"
            sSystemAssetType = "System"
            iObjectID = iAssemblyOID
            sSystemGID = sAssemblyGID
        else:
            if self.__bNewAssetGroup:
                iSystemAssetGroup = 101 # "Bogus Controller"
                sSystemAssetGroup = sNewAssetGroup
                iSystemAssetType = 1001 # "System"
                sSystemAssetType = "System"
            else:
                iSystemAssetGroup = 3 # "Controllable Valve"
                sSystemAssetGroup = "Controllable Valve"
                iSystemAssetType = 485 # "System"
                sSystemAssetType = "System"
            iObjectID = None
            sSystemGID = "{" + str(uuid.uuid4()).upper() + "}"
            dtCreated = dtNow
            sCreationUser = sMigrationUser
            dtModified = dtNow
            sLastUser = sMigrationUser
            sFacilityID = None
            sWorkOrderID = None
            sSFN = None
            dtChart = None
        out_row = [iSystemAssetGroup, iSystemAssetType, dtCreated, sCreationUser, 
                    dtModified, sLastUser, dtInService, sFacilityID, 
                    sName, iLifeCycle, dSymbolRotation, sWorkOrderID, 
                    sSFN, dtChart, shapeSystem, iObjectID, sSystemGID
                    ]
        self.__cursorDevice.insertRow(out_row)
        sSystemPort = "Port Two"
        out_row = ["Junction Junction Connectivity", 1, "Device", sSystemAssetGroup,
                   sSystemAssetType, sSystemGID, sSystemPort, 1, 
                   "Junction", "Connection Point", "System Connection", sJunctionGID, 
                   "Single Terminal", None
                   ]
        self.__cursorAssociation.insertRow(out_row)
        if not bPOCV:
            out_row = ["Containment", 1, "Assembly", "Town Border Station",
                       "Town Border Station", sAssemblyGID, None, 1, 
                       "Device", sSystemAssetGroup, sSystemAssetType, sSystemGID, 
                       None, 0
                       ]
            self.__cursorAssociation.insertRow(out_row)

        # Create pressure device row and associations
        if self.__bNewAssetGroup:
            iPressureAssetGroup = 101 # "Bogus Controller"
            sPressureAssetGroup = sNewAssetGroup
            iPressureAssetType = 1002 # "Pressure"
            sPressureAssetType = "Pressure"
        else:
            iPressureAssetGroup = 19 # "Regulator"
            sPressureAssetGroup = "Regulator"
            iPressureAssetType = 521 # "Regulator"
            sPressureAssetType = "Regulator"
        iObjectID = None
        sPressureGID = "{" + str(uuid.uuid4()).upper() + "}"
        dtCreated = dtNow
        sCreationUser = sMigrationUser
        dtModified = dtNow
        sLastUser = sMigrationUser
        sFacilityID = None
        sWorkOrderID = None
        sSFN = None
        dtChart = None
        out_row = [iPressureAssetGroup, iPressureAssetType, dtCreated, sCreationUser, 
                    dtModified, sLastUser, dtInService, sFacilityID, 
                    sName, iLifeCycle, dSymbolRotation, sWorkOrderID, 
                    sSFN, dtChart, shapePressure, iObjectID, sPressureGID
                    ]
        self.__cursorDevice.insertRow(out_row)
        sPressurePort = "Low Pressure Out"
        out_row = ["Junction Junction Connectivity", 1, "Device", sPressureAssetGroup,
                   sPressureAssetType, sPressureGID, sPressurePort, 1, 
                   "Junction", "Connection Point", "System Connection", sJunctionGID, 
                   "Single Terminal", None
                   ]
        self.__cursorAssociation.insertRow(out_row)
        if not bPOCV:
            out_row = ["Containment", 1, "Assembly", "Town Border Station",
                       "Town Border Station", sAssemblyGID, None, 1, 
                       "Device", sPressureAssetGroup, sPressureAssetType, sPressureGID, 
                       None, 0
                       ]
            self.__cursorAssociation.insertRow(out_row)

        # Create system and pressure controller rows
        if bTransmission is None:
            return # This should never happen
        sSystemName = self.__GetSystemName(shape, sName)
        sSubnetwork = ""
        if bTransmission:
            sSubnetwork = "Pipe Transmission System"
            sSystemName += "-T"
        else:
            sSubnetwork = "Pipe Distribution System"
        out_row = [sSystemGID.strip("{}"), sSystemGID, 1, sSystemAssetGroup,
                    sSystemAssetType, sSystemPort, sSubnetwork, sSystemName
                    ]
        self.__cursorController.insertRow(out_row)
        if bTransmission:
            sSubnetwork = "Pipe Transmission Pressure"
        else:
            sSubnetwork = "Pipe Distribution Pressure"
        out_row = [sPressureGID.strip("{}"), sPressureGID, 1, sPressureAssetGroup,
                    sPressureAssetType, sPressurePort, sSubnetwork, sPressureName
                    ]
        self.__cursorController.insertRow(out_row)
        return

    def __GetSystemName(self, geom, sName):

        # Get general town
        sSystemName = ""
        for sKey in self.__Towns:
            shpTown = self.__Towns[sKey]
            if shpTown.disjoint(geom):
                continue
            if not shpTown.contains(geom):
                continue
            if sKey in self.__TownSubstitutes:
                sSystemName = self.__TownSubstitutes[sKey]
            else:
                sSystemName = sKey
            break;
        if sSystemName == "":
            sSystemName = sName
            Replace = ["INTERCONNECT", "REGULATOR", "CITY GATE"]
            for sReplace in Replace:
                if sSystemName.find(sReplace) == -1:
                    continue
                sSystemName = sSystemName.replace(sReplace, "").rstrip(" ")
            if sSystemName in self.__TownSubstitutes:
                sSystemName = self.__TownSubstitutes[sSystemName]
            elif sSystemName in self.__OutlierSubstitutes:
                sSystemName = self.__OutlierSubstitutes[sSystemName]
        return sSystemName

    def __MigrateRegulatorStation(self):

        # [Assumes no attachments to migrate]
        sFCName = "RegulatorStation"
        print("Migrating " + sFCName + "...")

        # Create insert cursors
        out_fields = ["ASSETGROUP", "ASSETTYPE", "CREATIONDATE", "CREATOR", 
                      "LASTUPDATE", "UPDATEDBY", "INSERVICEDATE", "ASSETID", 
                      "NAME", "LIFECYCLESTATUS", "SOPIN", "SOPOUT",
                      "ROTATION", "PIPELINEOPERATOR", "ODORIZERINDICATOR", "ASSETUNITCODE", 
                      "WORKORDERID", "TYPE", "SEQUENTIAL_FILE_NUMBER", "PHOTOS", 
                      "CHART_DATE", "SHAPE@", "LEGACY_OID", "GLOBALID"
                      ]
        self.__cursor = arcpy.da.InsertCursor(self.__sTargetFC, out_fields)
        out_fields = ["ASSETGROUP", "ASSETTYPE", "CREATIONDATE", "CREATOR", 
                      "LASTUPDATE", "UPDATEDBY", "ASSETID", "LOCATIONDESCRIPTION", 
                      "LIFECYCLESTATUS", "ROTATION", "SHAPE@", "GLOBALID"
                      ]
        self.__cursorDevice = arcpy.da.InsertCursor(self.__sDeviceFC, out_fields)
        out_fields = ["ASSETGROUP", "ASSETTYPE", "SHAPE@", "GLOBALID"]
        self.__cursorJunction = arcpy.da.InsertCursor(self.__sJunctionFC, out_fields)
        out_fields = ["ASSOCIATION_TYPE", "FROM_DOMAIN_NETWORK", "FROM_FEATURE_CLASS", "FROM_ASSET_GROUP",
                      "FROM_ASSET_TYPE", "FROM_GLOBAL_ID", "TO_DOMAIN_NETWORK", "TO_FEATURE_CLASS",
                      "TO_ASSET_GROUP", "TO_ASSET_TYPE", "TO_GLOBAL_ID", "CONTENT_VISIBLE"
                      ]
        self.__cursorAssociation = arcpy.da.InsertCursor(self.__sAssociationTab, out_fields)
        out_fields = ["CONTROLLER_NAME", "GLOBAL_ID", "DOMAIN_NETWORK", "ASSET_GROUP",
                      "ASSET_TYPE", "TERMINAL", "TIER_NAME", "SUBNETWORK_NAME"
                      ]
        self.__cursorController = arcpy.da.InsertCursor(self.__sControllerTab, out_fields)

        # Get projected shapes
        print("   Getting projected shapes...")
        ProjectedShapes = self.__helper.GetProjectedShapes(sFCName)

        # Get connected lines
        print("   Getting connected lines...")
        ConnectedLines, LineGeoms = self.__helper.GetConnectedLines(sFCName)

        # Create SearchCursor
        print("   Processing rows...")
        sSourceFC = self.__sSourceGDB + "/" + sFCName
        in_fields = ["DATECREATED", "CREATIONUSER", "DATEMODIFIED", "LASTUSER", 
                     "INSERVICEDATE", "FACILITYID", "NAME", "WORKFUNCTION", 
                     "SOPIN", "SOPOUT", "SYMBOLROTATION", "OWNER",
                     "ODORIZER", "PROPERTYUNITCODE", "WORKORDERID", "TYPE", 
                     "SEQUENTIAL_FILE_NUMBER", "PHOTOS", "CHART_DATE", "GLOBALID", 
                     "OBJECTID"
                     ]
        TerminalLines = set()
        RegInTerminals = {}
        RegOutTerminals = {}
        ValveOneTerminals = {}
        ValveTwoTerminals = {}
        iControllerCount = 0
        with arcpy.da.SearchCursor(sSourceFC, in_fields) as cursorIn:
            for in_row in cursorIn:
                iWorkFunction = in_row[7]
                if self._bSkipProposed and iWorkFunction == 1:
                    continue
                sGlobalID = in_row[19]
                if sGlobalID not in ProjectedShapes:
                    continue
                shape = ProjectedShapes[sGlobalID]

                # Determine device type and terminal assignments
                if sGlobalID not in ConnectedLines:
                    continue # This should never happen
                LineRecs = ConnectedLines[sGlobalID]
                LineRec0 = LineRecs[0]
                sLineGID0 = LineRec0[0]
                iAssetGroup0 = LineRec0[1]
                dMAOP0 = LineRec0[2]
                sSystemName0 = LineRec0[3]
                LineRec1 = LineRecs[1]
                sLineGID1 = LineRec1[0]
                iAssetGroup1 = LineRec1[1]
                dMAOP1 = LineRec1[2]
                sSystemName1 = LineRec1[3]
                sInGID = ""
                sOutGID = ""
                sPressureName = ""
                bController = True
                if dMAOP0 > dMAOP1:
                    sInGID = sLineGID0
                    sOutGID = sLineGID1
                    sPressureName = sSystemName1
                elif dMAOP1 > dMAOP0:
                    sInGID = sLineGID1
                    sOutGID = sLineGID0
                    sPressureName = sSystemName0
                else:
                    bController = False
                bTransmission = (iAssetGroup0 == 3 and iAssetGroup1 == 3)
                bSystem = (iAssetGroup0 != iAssetGroup1)

                # Assign device terminals
                if bController:
                    iControllerCount += 1
                    TerminalLines.add(sInGID)
                    TerminalLines.add(sOutGID)
                    if bSystem:
                        # The reg station acts as a distribution system controller
                        # [It will need to be edited manually to add a regulator
                        # in order to control a pressure subnetwork]
                        ValveOneTerminals[sInGID] = shape
                        ValveTwoTerminals[sOutGID] = shape
                    else:
                        RegInTerminals[sInGID] = shape
                        RegOutTerminals[sOutGID] = shape

                # Process row
                self.__ProcessRSRow(in_row, shape, bSystem, bTransmission, bController, sPressureName)
                # Fewer than 1000 records

        del self.__cursor
        del self.__cursorDevice
        del self.__cursorJunction
        del self.__cursorAssociation
        del self.__cursorController
        del ProjectedShapes
        del ConnectedLines
        if iControllerCount == 0:
            return

        # Update terminal assignments
        print("   Updating terminals...")
        iPortIn = 2
        iPortOut = 3
        iPortOne = 8
        iPortTwo = 9
        Fields = ["FROMDEVICETERMINAL", "TODEVICETERMINAL", "GLOBALID"]
        with arcpy.da.UpdateCursor(self.__sLineFC, Fields) as cursor:
            for row in cursor:
                sLineGID = row[2]
                if sLineGID not in TerminalLines:
                    continue
                if sLineGID not in LineGeoms:
                    continue # This should never happen
                shape = LineGeoms[sLineGID]
                if sLineGID in RegInTerminals:
                    geomDevice = RegInTerminals[sLineGID]
                    iFromOrTo = self.__helper.FromOrTwo(shape, geomDevice)
                    row[iFromOrTo] = iPortIn
                if sLineGID in RegOutTerminals:
                    geomDevice = RegOutTerminals[sLineGID]
                    iFromOrTo = self.__helper.FromOrTwo(shape, geomDevice)
                    row[iFromOrTo] = iPortOut
                if sLineGID in ValveOneTerminals:
                    geomDevice = ValveOneTerminals[sLineGID]
                    iFromOrTo = self.__helper.FromOrTwo(shape, geomDevice)
                    row[iFromOrTo] = iPortOne
                if sLineGID in ValveTwoTerminals:
                    geomDevice = ValveTwoTerminals[sLineGID]
                    iFromOrTo = self.__helper.FromOrTwo(shape, geomDevice)
                    row[iFromOrTo] = iPortTwo
                cursor.updateRow(row)
        del LineGeoms
        del TerminalLines
        del RegInTerminals
        del RegOutTerminals
        del ValveOneTerminals
        del ValveTwoTerminals
        return

    def __ProcessRSRow(self, in_row, shape, bSystem, bTransmission, bController, sPressureName):
        iAssetGroup = 3 # "Regulator Station"
        iAssetType = 81 # "Regulator Station"
        dtCreated = in_row[0]
        sCreationUser = in_row[1]
        dtModified = in_row[2]
        sLastUser = in_row[3]
        dtInService = in_row[4]
        sFacilityID = in_row[5]
        sName = in_row[6]

        # Domain: UPDM_LifeCycleStatus
        iLifeCycle = 3 # "In Service"
        iWorkFunction = in_row[7]
        if iWorkFunction == 1:
            iLifeCycle = 1 # "Proposed"

        dSOPIn = in_row[8]
        dSOPOut = in_row[9]
        dSymbolRotation = in_row[10]
        sOwner = in_row[11]

        # Domain: UPDM_YesNoIndicator
        iOdorizer = None
        sOdorizer = in_row[12]
        if sOdorizer == "Yes":
            iOdorizer = 1
        elif sOdorizer == "No":
            iOdorizer = 2

        sUnitCode = in_row[13]
        sWorkOrderID = in_row[14]
        sType = in_row[15]
        if sType == "Town Border (01)":
            # This is still a type of regulator station
            sType = "City Gate (01)"  
        sSFN = in_row[16]
        sPhotos = in_row[17]
        dtChart = in_row[18]
        sAssemblyGID = in_row[19]
        iObjectID = in_row[20]

        # Create assembly row
        out_row = [iAssetGroup, iAssetType, dtCreated, sCreationUser, 
                    dtModified, sLastUser, dtInService, sFacilityID, 
                    sName, iLifeCycle, dSOPIn, dSOPOut,
                    dSymbolRotation, sOwner, iOdorizer, sUnitCode, 
                    sWorkOrderID, sType, sSFN, sPhotos, 
                    dtChart, shape, iObjectID, sAssemblyGID
                    ]
        self.__cursor.insertRow(out_row)

        # Create connection point for non-controlling reg stations
        # [This eliminates the need to manually assign terminals]
        sJunctionGID = "{" + str(uuid.uuid4()).upper() + "}"
        if not bController:
            iAssetGroup = 21 # Connection Point
            iAssetType = 801 # Connection Point
            out_row = [iAssetGroup, iAssetType, shape, sJunctionGID]
            self.__cursorJunction.insertRow(out_row)
            return

        # Create device row
        sSubnetName = sPressureName
        if bSystem:
            iAssetGroup = 3 # "Controllable Valve"
            sAssetGroup = "Controllable Valve"
            iAssetType = 485 # "System"
            sAssetType = "System"
            sAssetID = "System Valve"
            sOutTerminal = "Port Two"
            sSubnetName = self.__GetSystemName(shape, sName)
        else:
            iAssetGroup = 19 # "Regulator"
            sAssetGroup = "Regulator"
            iAssetType = 521 # "Regulator"
            sAssetType = "Regulator"
            sAssetID = "Regulator"
            sOutTerminal = "Low Pressure Out"
        dtNow = datetime.now()
        sUser = "UPDM Migration"
        sDeviceGID = "{" + str(uuid.uuid4()).upper() + "}"
        out_row = [iAssetGroup, iAssetType, dtNow, sUser,
                   dtNow, sUser, "Regulator", sName,
                   iLifeCycle, dSymbolRotation, shape, sDeviceGID
                   ]
        self.__cursorDevice.insertRow(out_row)
            
        # Create association row
        out_row = ["Containment", 1, "Assembly", "Regulator Station",
                   "Regulator Station", sAssemblyGID, 1, "Device",
                   sAssetGroup, sAssetType, sDeviceGID, 0
                   ]
        self.__cursorAssociation.insertRow(out_row)

        # Create controller row
        sTier = "Pipe Distribution Pressure"
        if bTransmission:
            sTier = "Pipe Transmission Pressure"
        elif bSystem:
            sTier = "Pipe Distribution System"
        out_row = [sDeviceGID.strip("{}"), sDeviceGID, 1, sAssetGroup,
                    sAssetType, sOutTerminal, sTier, sSubnetName
                    ]
        self.__cursorController.insertRow(out_row)
        return

    def __MigrateRuralTap(self):
        sFCName = "RuralTap"
        print("Migrating " + sFCName + "...")

        # Create InsertCursor
        out_fields = ["ASSETGROUP", "ASSETTYPE", "CREATIONDATE", "CREATOR", 
                      "LASTUPDATE", "UPDATEDBY", "NAME", "LIFECYCLESTATUS", 
                      "ROTATION", "ODORIZERINDICATOR", "STATION_NUMBER", "STATION_SUPPLIER",
                      "SUPPLIER_IDENTIFICATION_NUMBER", "PHOTOS", "SHAPE@", "LEGACY_OID",
                      "GLOBALID"
                      ]
        self.__cursor = arcpy.da.InsertCursor(self.__sTargetFC, out_fields)

        # Get projected shapes
        print("   Getting projected shapes...")
        ProjectedShapes = self.__helper.GetProjectedShapes(sFCName)

        # Create SearchCursor
        # [Assumes WORKFUNCTION, WORKORDERID, SEQUENTIAL_FILE_NUMBER, and CHART_DATE are not populated]
        print("   Processing rows...")
        sSourceFC = self.__sSourceGDB + "/" + sFCName
        in_fields = ["DATECREATED", "CREATIONUSER", "DATEMODIFIED", "LASTUSER",
                     "STATION_NAME", "SYMBOLROTATION", "ODORIZERINDICATOR", "STATION_NUMBER", 
                     "SUPPLIER", "SUPPLIER_IDENTIFICATION_NUMBER", "PHOTOS", "GLOBALID", 
                     "OBJECTID"
                     ]
        iCount = 0
        with arcpy.da.SearchCursor(sSourceFC, in_fields) as cursorIn:
            for in_row in cursorIn:
                sGlobalID = in_row[11]
                if sGlobalID not in ProjectedShapes:
                    continue
                shape = ProjectedShapes[sGlobalID]
                self.__ProcessRTRow(in_row, shape)
                # Fewer than 1000 records
        del self.__cursor
        return

    def __ProcessRTRow(self, in_row, shape):
        iAssetGroup = 4 # "Rural Tap"
        iAssetType = 121 # "Rural Tap"
        dtCreated = in_row[0]
        sCreationUser = in_row[1]
        dtModified = in_row[2]
        sLastUser = in_row[3]
        sName = in_row[4]

        # Domain: UPDM_LifeCycleStatus
        iLifeCycle = 3 # "In Service"

        dSymbolRotation = in_row[5]

        # Domain: UPDM_YesNoIndicator
        iOdorizer = None
        sOdorizer = in_row[6]
        if sOdorizer == "Yes":
            iOdorizer = 1
        elif sOdorizer == "No":
            iOdorizer = 2

        sStationNumber = in_row[7]
        sSupplier = in_row[8]
        sSupplierID = in_row[9]
        sPhotos = in_row[10]
        sGlobalID = in_row[11]
        iObjectID = in_row[12]
        out_row = [iAssetGroup, iAssetType, dtCreated, sCreationUser, 
                    dtModified, sLastUser, sName, iLifeCycle, 
                    dSymbolRotation, iOdorizer, sStationNumber, sSupplier, 
                    sSupplierID, sPhotos, shape, iObjectID, 
                    sGlobalID
                    ]
        try:
            self.__cursor.insertRow(out_row)
        except Exception as ErrorDesc:
            sMsg = "Feature creation failed:"
            sMsg += "\n" + str(ErrorDesc)
            sMsg += "\n" + traceback.format_exc()
            print(sMsg)
        return

    def __MigrateMeterSetting(self):
        sFCName = "MeterSetting"
        print("Migrating " + sFCName + "...")

        # Get rural tap global IDs
        RuralTaps = {}
        in_fields = ["LEGACY_OID", "GLOBALID"]
        sWhere = "assetgroup = 4 AND assettype = 121"
        with arcpy.da.SearchCursor(self.__sTargetFC, in_fields, sWhere) as cursorIn:
            for in_row in cursorIn:
                RuralTaps[in_row[0]] = in_row[1]

        # Create InsertCursor
        out_fields = ["ASSETGROUP", "ASSETTYPE", "CREATIONDATE", "CREATOR", 
                      "LASTUPDATE", "UPDATEDBY", "COMMENTS", "METERSETTING_STATUS",
                      "FARM_TAP_GID", "STATUS_DATE", "LABEL_TEXT", "SHAPE@", 
                      "LEGACY_OID", "GLOBALID"
                      ]
        self.__cursor = arcpy.da.InsertCursor(self.__sTargetFC, out_fields)

        # Get projected shapes
        print("   Getting projected shapes...")
        ProjectedShapes = self.__helper.GetProjectedShapes(sFCName)

        # Create SearchCursor
        print("   Processing rows...")
        sSourceFC = self.__sSourceGDB + "/" + sFCName
        in_fields = ["DATECREATED", "CREATIONUSER", "DATEMODIFIED", "LASTUSER",
                     "COMMENTS", "SUBTYPECD", "FARM_TAP_ID", "STATUS_DATE", 
                     "LABEL_TEXT", "GLOBALID", "OBJECTID"
                     ]
        iCount = 0
        with arcpy.da.SearchCursor(sSourceFC, in_fields) as cursorIn:
            for in_row in cursorIn:
                sGlobalID = in_row[9]
                if sGlobalID not in ProjectedShapes:
                    continue
                shape = ProjectedShapes[sGlobalID]
                sFarmTapGID = None
                iFarmTapID = in_row[6]
                if iFarmTapID in RuralTaps:
                    sFarmTapGID = RuralTaps[iFarmTapID]
                self.__ProcessMSRow(in_row, shape, sFarmTapGID)
                iCount += 1
                if iCount % 1000 == 0:
                    print("   MeterSetting row " + str(iCount) + "...")

        del self.__cursor
        return

    def __ProcessMSRow(self, in_row, shape, sFarmTapGID):
        iAssetGroup = 2 # "Meter Setting"
        iAssetType = 41 # "Meter Set"
        dtCreated = in_row[0]
        sCreationUser = in_row[1]
        dtModified = in_row[2]
        sLastUser = in_row[3]
        sComments = in_row[4]
        iStatus = in_row[5]
        dtStatus = in_row[7]
        sLabelText = in_row[8]
        sGlobalID = in_row[9]
        iObjectID = in_row[10]
        out_row = [iAssetGroup, iAssetType, dtCreated, sCreationUser, 
                    dtModified, sLastUser, sComments, iStatus,
                    sFarmTapGID, dtStatus, sLabelText, shape, 
                    iObjectID, sGlobalID
                    ]
        try:
            self.__cursor.insertRow(out_row)
        except Exception as ErrorDesc:
            sMsg = "Feature creation failed:"
            sMsg += "\n" + str(ErrorDesc)
            sMsg += "\n" + traceback.format_exc()
            print(sMsg)
        return

    def __MigrateMeter(self):
        sTabName = "METER"
        print("Migrating " + sTabName + "...")

        # Get meter setting global IDs and shapes
        # and create riser connection points
        AssemblyLookup = {}
        RiserLookup = {}
        print("   Creating riser connection points...")
        in_fields = ["LEGACY_OID", "GLOBALID", "SHAPE@"]
        out_fields = ["ASSETGROUP", "ASSETTYPE", "SHAPE@", "GLOBALID"]
        out_cursor = arcpy.da.InsertCursor(self.__sJunctionFC, out_fields)
        iCount = 0
        sWhere = "assetgroup = 2" # "Meter Setting"
        with arcpy.da.SearchCursor(self.__sTargetFC, in_fields, sWhere) as cursorIn:
            for in_row in cursorIn:
                # Add assembly lookup
                iLegacyOID = in_row[0]
                sAssemblyGID = in_row[1]
                shape = in_row[2]
                AssemblyLookup[iLegacyOID] = [sAssemblyGID, shape]

                # Create riser connection point
                uid = uuid.uuid4()
                sRiserGID = "{" + str(uid).upper() + "}"
                RiserLookup[sAssemblyGID] = sRiserGID
                iAssetGroup = 21 # Connection Point
                iAssetType = 802 # Riser Connection
                out_row = [iAssetGroup, iAssetType, shape, sRiserGID]
                out_cursor.insertRow(out_row)
                iCount += 1
                if iCount % 1000 == 0:
                    print("   Junction row " + str(iCount) + "...")
        del out_cursor

        # Create insert cursors
        out_fields = ["CREATIONDATE", "CREATOR", "LASTUPDATE", "UPDATEDBY", 
                      "DEVICE_GID", "METER_NUMBER", "METER_INSTALL_DATE", "METER_CYCLE", 
                      "ROUTE_NUMBER", "STOP_NUMBER", "LOCATION_ON_PREMISE", "PREMISE_NUMBER", 
                      "OUTAGE_STATUS", "REFUNDED", "CSLA", "IMPORT_DATE", 
                      "PREMISE_STATUS", "STREET_ADDRESS", "CITY", "ZIP_CODE", 
                      "TAXING_CITY", "COMMENTS", "COMMENT_FLAG", "GLOBALID"
                      ]
        self.__cursor = arcpy.da.InsertCursor(self.__sMeterTab, out_fields)
        out_fields = ["ASSETGROUP", "ASSETTYPE", "CREATIONDATE", "CREATOR", 
                      "LASTUPDATE", "UPDATEDBY", "ASSETID", "LOCATIONDESCRIPTION", 
                      "LIFECYCLESTATUS", "ROTATION", "SHAPE@", "GLOBALID"
                      ]
        self.__cursorDevice = arcpy.da.InsertCursor(self.__sDeviceFC, out_fields)
        out_fields = ["ASSOCIATION_TYPE", "FROM_DOMAIN_NETWORK", "FROM_FEATURE_CLASS", "FROM_ASSET_GROUP",
                      "FROM_ASSET_TYPE", "FROM_GLOBAL_ID", "FROM_TERMINAL", "TO_DOMAIN_NETWORK", 
                      "TO_FEATURE_CLASS", "TO_ASSET_GROUP", "TO_ASSET_TYPE", "TO_GLOBAL_ID", 
                      "TO_TERMINAL", "CONTENT_VISIBLE"
                      ]
        self.__cursorAssociation = arcpy.da.InsertCursor(self.__sAssociationTab, out_fields)

        # Create SearchCursor
        sSourceTab = self.__sSourceGDB + "/" + sTabName
        in_fields = ["DATECREATED", "CREATIONUSER", "DATEMODIFIED", "LASTUSER", 
                     "METERSETTINGOBJECTID", "METER_NUMBER", "METER_INSTALL_DATE", "METER_CYCLE", 
                     "ROUTE_NUMBER", "STOP_NUMBER", "LOCATION_ON_PREMISE", "PREMISE_NUMBER", 
                     "OUTAGE_STATUS", "REFUNDED", "CSLA", "IMPORT_DATE", 
                     "PREMISE_STATUS", "STREET_ADDRESS", "CITY", "ZIP_CODE", 
                     "TAXING_CITY", "COMMENTS", "GLOBALID"
                     ]
        self.__MeterOffsets = {}
        iCount = 0
        iNull = 0
        iMismatch = 0
        bShortTest = self.__helper._bShortTest
        with arcpy.da.SearchCursor(sSourceTab, in_fields) as cursorIn:
            for in_row in cursorIn:
                sMeterSettingGID = None
                iMeterSettingID = in_row[4]
                if iMeterSettingID is None:
                    if not bShortTest:
                        print("   Null meter setting ID at meter: " + in_row[22])
                        iNull += 1
                    continue
                if iMeterSettingID not in AssemblyLookup:
                    if not bShortTest:
                        print("   Mismatch at meter: " + in_row[22])
                        iMismatch += 1
                    continue
                entry = AssemblyLookup[iMeterSettingID]
                sMeterSettingGID = entry[0]
                shape = entry[1]
                sRiserGID = RiserLookup[sMeterSettingGID]
                self.__ProcessMeterRow(in_row, shape, sMeterSettingGID, sRiserGID)
                iCount += 1
                if iCount % 1000 == 0:
                    print("   Meter row " + str(iCount) + "...")
        del self.__cursor
        del self.__cursorDevice
        del self.__cursorAssociation
        if not bShortTest:
            print("Total null meter setting IDs: " + str(iNull))
            print("Total meter mismatches: " + str(iMismatch))
        return

    def __ProcessMeterRow(self, in_row, shape, sMeterSettingGID, sRiserGID):
        # Get meter attributes
        dtCreated = in_row[0]
        sCreationUser = in_row[1]
        dtModified = in_row[2]
        sLastUser = in_row[3]
        sMeterNumber = in_row[5]
        dtInstall = in_row[6]
        sMeterCycle = in_row[7]
        sRouteNumber = in_row[8]
        iStopNumber = in_row[9]
        sLocation = in_row[10]
        sPremiseNumber = in_row[11]
        sOutageStatus = in_row[12]

        # Domain: UPDM_YesNoIndicator
        iRefunded = None
        sRefunded = in_row[13]
        if sRefunded == "Yes":
            iRefunded = 1
        elif sRefunded == "No":
            iRefunded = 2

        sCSLA = in_row[14]
        dtImport = in_row[15]
        sPremiseStatus = in_row[16]
        sAddress = in_row[17]
        sCity = in_row[18]
        sZipCode = in_row[19]
        sTaxingCity = in_row[20]

        sComments = in_row[21]
        iCommentFlag = None
        if sComments is not None:
            iCommentFlag = 1
        
        sGlobalID = in_row[22]

        # Create meter table row
        sDeviceGlobalID = "{" + str(uuid.uuid4()).upper() + "}"
        out_row = [dtCreated, sCreationUser, dtModified, sLastUser, 
                    sDeviceGlobalID, sMeterNumber, dtInstall, sMeterCycle,
                    sRouteNumber, iStopNumber, sLocation, sPremiseNumber,
                    sOutageStatus, iRefunded, sCSLA, dtImport,
                    sPremiseStatus, sAddress, sCity, sZipCode,
                    sTaxingCity, sComments, iCommentFlag, sGlobalID
                    ]
        self.__cursor.insertRow(out_row)

        # Create offset shape
        dZ = 0.5
        if sRiserGID in self.__MeterOffsets:
            dZ += self.__MeterOffsets[sRiserGID]
        self.__MeterOffsets[sRiserGID] = dZ
        env = shape.extent
        dX = env.XMax
        dY = env.YMax
        sr = shape.spatialReference
        pt = arcpy.Point(dX, dY, dZ)
        shapeNew = arcpy.PointGeometry(pt, sr, True, True)

        # Create meter device row
        iAssetGroup = 2 # "Meter"
        iAssetType = 42 # "Customer"
        iLifeCycle = 3 # "In Service"
        dSymbolRotation = 0.0
        dtNow = datetime.now()
        sUser = "UPDM Migration"
        out_row = [iAssetGroup, iAssetType, dtNow, sUser,
                   dtNow, sUser, sMeterNumber, sAddress,
                   iLifeCycle, dSymbolRotation, shapeNew, sDeviceGlobalID
                   ]
        self.__cursorDevice.insertRow(out_row)
            
        # Create containment and connection association rows
        out_row = ["Containment", 1, "Assembly", "Meter Setting",
                   "Meter Set", sMeterSettingGID, None, 1, 
                   "Device", "Meter", "Customer", sDeviceGlobalID, 
                   None, 0
                   ]
        self.__cursorAssociation.insertRow(out_row)
        out_row = ["Junction Junction Connectivity", 1, "Device", "Meter",
                   "Customer", sDeviceGlobalID, "Single Terminal", 1, 
                   "Junction", "Connection Point", "Riser Connection", sRiserGID, 
                   "Single Terminal", None
                   ]
        self.__cursorAssociation.insertRow(out_row)
        return

print("Ready.")
if __name__ == "__main__":
    ma = MigrateAssembly()
    ma.DoIt()
