################################################################################################
#  Create UPDM 2018 Edition Inspection Module
#   CreateInspectionModule_2018.py
#
#  Created on: 2018-03-08
#
#  Description: Purpose of this python script is to add the portion of the Utility and
#  Pipeline Data Model (UPDM) whose purpose is to support inspections and operational data collection
#  activities.
#
################################################################################################
import arcpy
from timeit import default_timer as timer
import logging
import sys
import os
arcpy.SetLogHistory(False)

file_logger = logging.FileHandler(filename=os.path.join(os.path.dirname(__file__), 'log_UPDM2018_Inspection.txt'), mode='w')
stream_logger = logging.StreamHandler(stream=sys.stdout)

logging.basicConfig(level=logging.DEBUG,
                    format="%(asctime)s\t%(message)s",
                    handlers=[file_logger, stream_logger])
logging.debug('Initialize')
try:    
    #########################
    # input Parameters
    #########################
    # Enterprise Geodatabase Connection File
    targetWorkspace = "C:/apps/Data/UPDM_Migration/AssetPackage_AZGas.gdb" # r"C:\Users\tom\Documents\ArcGIS\Projects\UPDM2018\UPDM2018.sde"    
    # SQL Server Database Name
    #SQLDatabaseName = "UPDM2018"
    # SQL Server Database Gas Domain Data Owner
    #SQLDatabaseOwner = "GIS"
    # SQL Server Data Prefix
    SQLPrefix = "/" # "\\" + SQLDatabaseName + "." + SQLDatabaseOwner + "."
    # Utility Network Name
    utilityNetworkName = "UtilityNetwork" # "PipeSystem"
    # Utility Network Gas Domain Name
    DomainName = "Pipeline"
    # Aggregated featureDataset Name
    featureDataset = SQLPrefix + utilityNetworkName
    # Aggregated Utility Network Path
    utilityNetworkPath = targetWorkspace + featureDataset + SQLPrefix + utilityNetworkName
    #Assign Service Territory polygon featureclass
    serviceTerritoryFeatureClass = targetWorkspace + featureDataset + SQLPrefix + "ServiceArea"
    
    ################################
    # Auto-defined script variables
    #################################
    UPDMAssembly = targetWorkspace + featureDataset + SQLPrefix + DomainName + "Assembly"
    UPDMDevice = targetWorkspace + featureDataset + SQLPrefix + DomainName + "Device"
    UPDMJunction = targetWorkspace + featureDataset + SQLPrefix + DomainName + "Junction"
    UPDMLine = targetWorkspace + featureDataset + SQLPrefix + DomainName + "Line"
    UPDMSubNetLine = targetWorkspace + featureDataset + SQLPrefix + DomainName + "SubnetLine"
    
    structureJunction = targetWorkspace + featureDataset + SQLPrefix + "StructureJunction"
    structureLine = targetWorkspace + featureDataset + SQLPrefix + "StructureLine"
    structureBoundary = targetWorkspace + featureDataset + SQLPrefix + "StructureBoundary"

    #Auto-define new variables, because some tools don't like paths
    roleStructureJunction = "StructureJunction"
    roleStructureLine = "StructureLine"
    roleStructureBoundary = "StructureBoundary"

    roleUPDMAssembly = DomainName + "Assembly"
    roleUPDMLine = DomainName + "Line"
    roleUPDMDevice = DomainName + "Device"
    roleUPDMJunction = DomainName + "Junction"

    # Environment valiables
    arcpy.env.workspace = targetWorkspace
    arcpy.env.preserveGlobalIds = True

    startTime = timer()

    ########################################
    #Add Domains into the Geodatabase
    ########################################
    logging.debug("Creating Domains in the Geodatabase")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_AlignmentSheetType", "List of valid types of map sheets in the UPDM_alignment sheet featureclass", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AlignmentSheetType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AlignmentSheetType", "Class Location", "Class Location")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AlignmentSheetType", "Construction", "Construction")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AlignmentSheetType", "Detail Sheet", "Detail Sheet")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AlignmentSheetType", "Engineering", "Engineering")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AlignmentSheetType", "Integrity", "Integrity")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_AlignmentSheetType", "New Construction", "New Construction")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_CoatingCondition", "List of valid current states of the gas asset coating", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CoatingCondition", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CoatingCondition", "No Coating", "No Coating")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CoatingCondition", "Completely Disbonded", "Completely Disbonded")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CoatingCondition", "Completely Intact", "Completely Intact")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CoatingCondition", "Extensive Disbonding", "Extensive Disbonding")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CoatingCondition", "Isolated Disbonding", "Isolated Disbonding")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ControlLineManufacturer", "List of valid type of manufacturers of control lines of strainers", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ControlLineManufacturer", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ControlLineManufacturer", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ControlLineModel", "List of the types of manufacturer models of control lines for strainers", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ControlLineModel", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ControlLineModel", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_CorrosionCondition", "List of valid current states of the condition of corrosion", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionCondition", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionCondition", "Non-Metallic", "Non-Metallic")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionCondition", "None", "None")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionCondition", "Light", "Light")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionCondition", "Moderate", "Moderate")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionCondition", "Heavy", "Heavy")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_CorrosionExtent", "List of valid descriptions of the extent of corrosion", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionExtent", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionExtent", "General", "General")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionExtent", "Localized", "Localized")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_CorrosionExtent", "None", "None")
        
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ExcavDamDamageType", "List of valid types of damages to the gas pipe system caused by excavation", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamDamageType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamDamageType", "Dent", "Dent")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamDamageType", "Gauge", "Gauge")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamDamageType", "Line Cut", "Line Cut")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamDamageType", "Puncture", "Puncture")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamDamageType", "Pulled", "Pulled")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamDamageType", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ExcavEquipCausingDamage", "List of valid types of equipment responsible for causing damage to the gas pipe system", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavEquipCausingDamage", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavEquipCausingDamage", "Auger", "Auger")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavEquipCausingDamage", "Backhoe", "Backhoe")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavEquipCausingDamage", "Bore", "Bore")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavEquipCausingDamage", "Shovel", "Shovel")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavEquipCausingDamage", "Trencher", "Trencher")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavEquipCausingDamage", "Vehicle", "Vehicle")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavEquipCausingDamage", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ExcavDamRespPartyType", "List of valid types of entities who are responsible for excavation damage", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRespPartyType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRespPartyType", "Company", "Company")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRespPartyType", "Homeowner", "Homeowner")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRespPartyType", "Other Utility", "Other Utility")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRespPartyType", "Local Government", "Local Government")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRespPartyType", "State Government", "State Government")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRespPartyType", "Federal Government", "Federal Government")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRespPartyType", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "List of underlying causes of the excavation damage", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Clearance Not Maintained", "Clearance Not Maintained")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Failure to Mark", "Failure to Mark")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Hand Digging", "Hand Digging")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Incorrect Records", "Incorrect Records")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Incorrect Ticket Info", "Incorrect Ticket Info")    
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Locate Not Requested", "Locate Not Requested")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Locate Time Exceeded", "Locate Time Exceeded")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Locate Markings Incorrect", "Locate Markings Incorrect")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Locating Wire Missing Broken", "Locating Wire Missing Broken")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Marks Destroyed", "Marks Destroyed")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Mech Equip Within 2ft", "Mech Equip Within 2ft")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "No Probable Violation", "No Probable Violation")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Ticket Expired", "Ticket Expired")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Trenchless Excav Bore Stakes", "Trenchless Excav Bore Stakes")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Trenchless Excav Ground Rod", "Trenchless Excav Ground Rod")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Trenchless Excav Expose Util", "Trenchless Excav Expose Util")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Trenchless Excav Drill Head", "Trenchless Excav Drill Head")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamRootCause", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "List of the types of work responsible for causing excavation damage", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Cut and Cap Gas Service", "Cut and Cap Gas Service")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Commercial Construction", "Commercial Construction")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Demolition", "Demolition")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Foundation Excavation", "Foundation Excavation")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Install Irrigation System", "Install Irrigation System")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Install Fence", "Install Fence")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Landscaping", "Landscaping")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Residential Construction", "Residential Construction")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Replace Curb", "Replace Curb")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Road Construction", "Road Construction")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Soil Boring", "Soil Boring")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Utility Install", "Utility Install")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamWorkType", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ExcavDamageType", "List of the types of valid types of excavation damage", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamageType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamageType", "Dent", "Dent")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamageType", "Gouge", "Gouge")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamageType", "Line Cut", "Line Cut")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamageType", "Puncture", "Puncture")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamageType", "Pulled", "Pulled")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ExcavDamageType", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_Flow", "Description of whether the device is considered upstream or downstream within the gas facility", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Flow", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Flow", "Upstream", "Upstream")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Flow", "Downstream", "Downstream")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_IdentifiedIssue", "List of the types of work responsible for causing excavation damage", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedIssue", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedIssue", "Corrosion", "Corrosion")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedIssue", "Damaged Meter", "Damaged Meter")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedIssue", "Dead Vegetation", "Dead Vegetation")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedIssue", "No Access", "No Access")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedIssue", "Odor", "Odor")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_IdentifiedIssue", "Other", "Other")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakClass", "List of the types of valid classes of leak", "Short", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakClass", 0, "No Leak")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakClass", 1, "Class 1")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakClass", 2, "Class 2")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakClass", 3, "Class 3")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakCauseCorrosion", "List of the types of valid causes of gas leaks due to Corrosion", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseCorrosion", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseCorrosion", "Internal", "Internal")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseCorrosion", "External", "External")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseCorrosion", "Stress Cracking", "Stress Cracking") 

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakCauseExcavation", "List of the types of valid causes of gas leaks due to Excavation Damage", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseExcavation", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseExcavation", "Dent", "Dent")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseExcavation", "Gouge", "Gouge")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseExcavation", "Puncture", "Puncture")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseExcavation", "Other", "Other")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakCauseEquipment", "List of the types of valid causes of gas leaks due to incorrect operations", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseEquipment", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseEquipment", "Malfunctioning Relief Valve", "Malfunctioning Relief Valve")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseEquipment", "Malfunctioning Regulator", "Malfunctioning Regulator")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseEquipment", "Mechanical Fitting", "Mechanical Fitting")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseEquipment", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "List of the types of valid causes of gas leaks due to Material", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "Excessive Stress", "Excessive Stress")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "Faulty Field Weld", "Faulty Field Weld")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "Faulty Manufacture Weld", "Faulty Manufacture Weld")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "Faulty Assembly by Manufacturer", "Faulty Assembly by Manufacturer")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "Faulty Assembly by Construction", "Faulty Assembly by Construction")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "Manufacture Defect", "Manufacture Defect")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "Excessive Stress", "Excessive Stress")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseMaterial", "Other", "Other")                                        

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakCauseNatural", "List of the types of valid causes of gas leaks due to Natural Forces", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseNatural", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseNatural", "Lightning", "Lightning")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseNatural", "Soil Erosion", "Soil Erosion")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseNatural", "Flooding", "Flooding")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseNatural", "High Winds", "High Winds")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseNatural", "Tree Roots", "Tree Roots")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseNatural", "Animal", "Animal")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseNatural", "Other", "Other")    

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakCauseOperations", "List of the types of valid causes of gas leaks due to Incorrect Operations", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOperations", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOperations", "Failure to follow procedure", "Failure to follow procedure")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOperations", "Inadequate safety procedures", "Inadequate safety procedures")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOperations", "Operation error", "Operation error")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOperations", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakCauseOutsideForce", "List of the types of valid causes of gas leaks due to outside forces", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOutsideForce", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOutsideForce", "Fire", "Fire")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOutsideForce", "Previous Damage", "Previous Damage")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOutsideForce", "Vandalism", "Vandalism")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOutsideForce", "Vehicle Damage", "Vehicle Damage")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakCauseOutsideForce", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakClosedStatus", "List of the types of valid status for a gas leak", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakClosedStatus", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakClosedStatus", "Active", "Active")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakClosedStatus", "Cleared", "Cleared")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakClosedStatus", "Repaired", "Repaired")
                                           
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "List of the types of gas system componentsr damaged by excavation", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Distribution Line", "Distribution Line")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Service Line", "Service Line")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Onshore Transmission", "Onshore Transmission")    
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Offshore Transmission", "Offshore Transmission")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Onshore Gathering", "Onshore Gathering")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Offshore Gathering", "Offshore Gathering")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Valve", "Valve")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Fitting", "Fitting")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Meter", "Meter")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Regulator Station", "Regulator Station")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Compressor Station", "Compressor Station")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Wellhead", "Wellhead")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakFacilityType", "Other", "Other")
                                           
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakInspectFrequency", "List of the gas leak inspection frequencies", "SHORT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectFrequency", 0, "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectFrequency", 1, "1 Month")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectFrequency", 3, "3 Month")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectFrequency", 6, "6 Month")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectFrequency", 12, "12 Month")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakInspectGasIn", "List of the valid types of locations where leaking gas is detected", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectGasIn", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectGasIn", "Air", "Air")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectGasIn", "Building", "Building")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectGasIn", "Soil", "Soil")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectGasIn", "Manhole", "Manhole")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectGasIn", "Test Box", "Test Box")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectGasIn", "Catch Basin", "Catch Basin")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakInspectGasIn", "Other", "Other")
                                           
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakMethodDetected", "List of the types of methods used to detect leaking gas", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakMethodDetected", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakMethodDetected", "Customer Reported", "Customer Reported")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakMethodDetected", "Leak Survey", "Leak Survey")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakMethodDetected", "Odor", "Odor")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakMethodDetected", "Vegetation", "Vegetation")
                                           
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakLocation", "List of the locations where a leak has been determined", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Pipe", "Pipe")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Weld", "Weld")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Joint", "Joint")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Leak Clamp", "Leak Clamp")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Flange Connection", "Flange Connection")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Valve Body", "Valve Body")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Valve Stem", "Valve Stem")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Service Riser", "Service Riser")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Cap", "Cap")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakLocation", "Other", "Other")                                           
                                           
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakRepairType", "List of the valid type of leak repair", "TEXT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakRepairType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakRepairType", "Permanent", "Permanent")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakRepairType", "Temporary", "Temporary")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakRepairType", "Not Applicable", "Not Applicable")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakSurveyFrequency", "List of the valid leak survey methods", "SHORT", "CODED", "DUPLICATE", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyFrequency", 0, "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyFrequency", 3, "3 Months")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyFrequency", 4, "4 Months")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyFrequency", 6, "6 Months")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyFrequency", 12, "12 Months")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyFrequency", 36, "36 Months")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyFrequency", 60, "60 Months")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakSurveyMethod", "List of the valid leak survey methods", "TEXT", "CODED", "DUPLICATE", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyMethod", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyMethod", "Flame Pack", "Flame Pack")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyMethod", "CGI", "CGI")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyMethod", "Odor", "Odor")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyMethod", "Vegation", "Vegation")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyMethod", "Visual", "Visual")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakSurveyStatus", "List of the valid leak survey status", "TEXT", "CODED", "DUPLICATE", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyStatus", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyStatus", "Assigned", "Assigned")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyStatus", "In Progress", "In Progress")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyStatus", "Completed", "Completed")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyStatus", "Reassign", "Reassign")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyStatus", "No Access", "No Access")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyStatus", "Not Assigned", "Not Assigned")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "List of the valid leak survey types", "TEXT", "CODED", "DUPLICATE", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Aerial", "Aerial")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Mobile Truck", "Mobile Truck")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Walking", "Walking")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Bridge", "Bridge")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Pre Pave", "Pre Pave")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Public Building", "Public Building")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Special", "Special")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Non-Survey", "Non-Survey")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Business District", "Business District")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Cast Iron", "Cast Iron")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Transmission", "Transmission")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakSurveyType", "Feeder", "Feeder")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "List of the work performed to repair a leak", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Leak Clamp", "Leak Clamp")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Avon Seal", "Avon Seal")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Electro-Fuse Fitting", "Electro-Fuse Fitting")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Fused Fitting", "Fused Fitting")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Grease Valve", "Grease Valve")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Turn Valve", "Turn Valve")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Tighten Bolts/Nuts", "Tighten Bolts/Nuts")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Negative Report", "Negative Report")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Replaced Clamp", "Replaced Clamp")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Replaced Fitting", "Replaced Fitting")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Replaced Pipe", "Replaced Pipe")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Replaced Regulator", "Replaced Pipe")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Retired Drop", "Retired Drop")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LeakWorkPerformed", "Retired Pipe", "Retired Pipe")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_LineValveConnection", "List of the type of connections used for Line Valves", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_LineValveConnection", "Unknown", "Unknown")
                                           
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_MeasurementUnits", "List of the units of measurement of leaking gas", "SHORT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MeasurementUnits", 0, "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MeasurementUnits", 1, "Parts Per Million")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_MeasurementUnits", 2, "Percent Gas") 
                                           
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ObjectStatus", "List of valid lifecycle status for a non-asset object", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus", "Conceptual", "Conceptual")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus", "Proposed", "Proposed")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus", "Active", "Active")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ObjectStatus", "Inactive", "Inactive")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_OnOffStatus", "Indicate whether a device is on or off", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_OnOffStatus", "U", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_OnOffStatus", "On", "On")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_OnOffStatus", "Off", "Off")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PassFailStatus", "Indicate whether the inspection characteristic passed or failed the inspection criteria", "SHORT", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PassFailStatus", 0, "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PassFailStatus", 1, "Pass")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PassFailStatus", 2, "Fail")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PassFailStatus", 3, "Not Inspected")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PilotConnectionType", "Method used to connect a pilot", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PilotConnectionType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PilotConnectionType", "Screw", "Screw")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PilotConnectionType", "Flange", "Flange")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PipeCondition", "List of valid observations of the gas asset", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCondition", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCondition", "Normal", "Normal")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCondition", "Fair", "Fair")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCondition", "Poor", "Poor")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PipeConnectionType", "Method used to connect a device to a pipe ", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeConnectionType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeConnectionType", "Thread", "Thread")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeConnectionType", "Flange", "Flange")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeConnectionType", "Fuse", "Fuse")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeConnectionType", "Weld", "Weld")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PipeCrossingLocation", "Indicator of whether the foreign object crosses above or below the pipe", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingLocation", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingLocation", "Above", "Above")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingLocation", "Below", "Below")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PipeCrossingTopographic", "Type of topographic features crossing the pipeline", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTopographic", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTopographic", "Fault Line", "Fault Line")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTopographic", "Levee", "Levee")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTopographic", "Water", "Water")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTopographic", "Wetlands", "Wetlands")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTopographic", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Type of transportation features crossing the pipeline", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Bicycle Trail", "Bicycle Trail")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Local Road", "Local Road")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Major Road", "Major Road")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Highway", "Highway")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Interstate", "Interstate")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Private Road", "Private Road")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Driveway", "Driveway")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Railroad", "Railroad")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Subway", "Subway")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Airport Runway", "Airport Runway")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingTransportation", "Unknown", "Unknown")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PipeCrossingPipeUtility", "Type of piped utility crossing the pipeline", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingPipeUtility", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingPipeUtility", "Petroleum Pipeline", "Petroleum Pipeline")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingPipeUtility", "Natural Gas Pipeline", "Natural Gas Pipeline")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingPipeUtility", "Sewer", "Sewer")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingPipeUtility", "Storm Sewer", "Storm Sewer")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingPipeUtility", "Water", "Water")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingPipeUtility", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_PipeCrossingWiredUtility", "Type of wired utility crossing the pipeline", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingWiredUtility", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingWiredUtility", "Telecommunication", "Telecommunication")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingWiredUtility", "Fiber", "Fiber")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingWiredUtility", "Electric Overhead", "Electric Overhead")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingWiredUtility", "Electric Buried", "Electric Buried")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingWiredUtility", "Cable", "Cable")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_PipeCrossingWiredUtility", "Other", "Other")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_Region", "List of Regions/Providences/States", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "U", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "AL", "Alabama")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "AK", "Alaska")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "AR", "Arkansas")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "AZ", "Arizona")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "CA", "California")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "CO", "Colorado")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "CT", "Connecticut")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "DE", "Delaware")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "FL", "Florida")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "GA", "Georgia")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "HI", "Hawaii")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "ID", "Idaho")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "IL", "Illinois")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "IN", "Indiana")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "IA", "Iowa")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "KS", "Kansas")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "KY", "Kentucky")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "LA", "Louisiana")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "MA", "Massachusetts")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "ME", "Maine")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "MD", "Maryland")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "MI", "Michigan")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "MN", "Minnesota")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "MO", "Missouri")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "MS", "Mississippi")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "MT", "Montana")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "NE", "Nebraska")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "NV", "Nevada")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "NH", "New Hampshire")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "NJ", "New Jersey")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "NM", "New Mexico")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "NY", "New York")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "NC", "North Carolina")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "ND", "North Dakota")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "OH", "Ohio")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "OK", "Oklahoma")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "OR", "Oregon")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "PA", "Pennsylvania")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "RI", "Rhode Island")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "SC", "South Carolina")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "SD", "South Dakota")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "TN", "Tennessee")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "TX", "Texas")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "UT", "Utah")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "VT", "Vermont")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "VA", "Virginia")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "WA", "Washington")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "WV", "West Virginia")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "WI", "Wisconsin")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_Region", "WY", "Wyoming")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "List of valid manufacturers of regulators", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "American", "American")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "Fisher", "Fisher")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "Grove", "Grove")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "Reliance", "Reliance")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "Rockwell", "Rockwell")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "Singer", "Singer")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "Sprague", "Sprague")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "Universal Lancaster", "Universal Lancaster")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorManufacturer", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_RegulatorModel", "List of valid type of manufacturer models of regulators", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorModel", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorModel", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_RegulatorType", "List of valid type functions of regulators", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorType", "Controller", "Controller")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_RegulatorType", "Monitor", "Monitor")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_SoilType", "List of predominant type of soil located at the depth of the buried gas asset", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_SoilType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_SoilType", "Cinders", "Cinders")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_SoilType", "Clay", "Clay")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_SoilType", "Gravel", "Gravel")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_SoilType", "Loam", "Loam")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_SoilType", "Rock", "Rock")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_SoilType", "Sand", "Sand")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_SoilType", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_StrainerDeviceType", "List of valid type of manufacturer models of strainers", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerDeviceType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerDeviceType", "Filter", "Filter")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerDeviceType", "Strainer", "Strainer")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "List of valid type of manufacturer models of strainers", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "Eaton", "Eaton")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "IMAC Systems", "IMAC Systems")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "JORC Industrial", "JORC Industrial")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "KADANT", "KADANT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "KITZ Corp", "KITZ Corp")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "Mueller", "Mueller")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "Spirax-Sarco", "Spirax-Sarco")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerManufacturer", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_StrainerModel", "List of the types of manufacturer models of strainers", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StrainerModel", "Unknown", "Unknown")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_DaysPerWeek", "Valid Range of values for the number of days per week", "DOUBLE", "RANGE", "GEOMETRY_RATIO", "DEFAULT")
    arcpy.SetValueForRangeDomain_management(targetWorkspace, "UPDM_DaysPerWeek", 0, 7)

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_WeeksPerYear", "Valid Range of values for the number of weeks per year", "DOUBLE", "RANGE", "GEOMETRY_RATIO", "DEFAULT")
    arcpy.SetValueForRangeDomain_management(targetWorkspace, "UPDM_DaysPerWeek", 0, 52)

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_StructureLimitedMobility", "List of reasons a structure is designated as Limited Mobility", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureLimitedMobility", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureLimitedMobility", "Registered", "Registered")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureLimitedMobility", "Agency Map", "Agency Map")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureLimitedMobility", "Visibly Marked", "Visibly Marked")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureLimitedMobility", "On Agency Map and Visibly Marked", "On Agency Map and Visibly Marked")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureLimitedMobility", "Visibly Marked and Registered", "Visibly Marked and Registered")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureLimitedMobility", "Registered and Agency Map and Visibly Marked", "Registered and Agency Map and Visibly Marked")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureLimitedMobility", "Registered and Agency Map", "Registered and Agency Map")
    
    arcpy.CreateDomain_management(targetWorkspace, "UPDM_StructureType", "List of the types of human occupied structures", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Apartment", "Apartment")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Arena", "Arena")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Assisted Living", "Assisted Living")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Barracks", "Barracks")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Business", "Business")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Daycare Facility", "Daycare Facility")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Fire Station", "Fire Station")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Garage", "Garage")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Hospital", "Hospital")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Hotel", "Hotel")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Industrial", "Industrial")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Manufacturing", "Manufacturing")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Nursing Home", "Nursing Home")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Prison", "Prison")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Recreational Facility", "Recreational Facility")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Religious Facility", "Religious Facility")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Residence", "Residence")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "School", "School")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_StructureType", "Shopping Center", "Shopping Center")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "List of the types of manufacturer of valves", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Unknown", "Unknown")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Apollo", "Apollo")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Balon", "Balon")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Dresser-Rand", "Dresser-Rand")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Georg Fischer", "Georg Fischer")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Jomar", "Jomar")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Kerotest", "Kerotest")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Mueller", "Mueller")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Rockford", "Rockford")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveManufacturer", "Other", "Other")

    arcpy.CreateDomain_management(targetWorkspace, "UPDM_ValveModel", "List of the types of manufacturer models of valves", "Text", "CODED", "DEFAULT", "DEFAULT")
    arcpy.AddCodedValueToDomain_management(targetWorkspace, "UPDM_ValveModel", "Unknown", "Unknown")
    
    logging.debug("Completed creating Domains in the Geodatabase")


    ##############################################################
    # Defining P_AlignmentSheet
    ##############################################################
    logging.debug("Create Polygon featureclass P_AlignmentSheet class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_AlignmentSheet", "POLYGON", None, "DISABLED", "DISABLED", featureDataset, None, 0, 0, 0)
    #arcpy.management.CreateFeatureclass(targetWorkspace, "P_AlignmentSheet", "POLYGON", None, "DISABLED", "DISABLED", None, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_AlignmentSheet"

    #Adding Attributes to featureclass
    logging.debug("     Adding 8 Attribute to P_AlignmentSheet")
    arcpy.management.AddField(InputDataset, "SHEETNAME", "TEXT", None, None, 45, "Sheet Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SHEETNUMBER", "TEXT", None, None, 45, "Sheet Number", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "SHEETTYPE", "TEXT", None, None, 45, "Sheet Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 15, "Status", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 8 Attributes to P_AlignmentSheet")

    #Add Domains to Featureclass
    logging.debug("     Assigning 2 Domains to P_AlignmentSheet")
    arcpy.management.AssignDomainToField(InputDataset, "SHEETTYPE", "UPDM_AlignmentSheetType", None)
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus", None)
    logging.debug("     Successfully Assigned 2 Domains to P_AlignmentSheet")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 2 Default Values to P_AlignmentSheet")
    arcpy.management.AssignDefaultToField(InputDataset, "SHEETTYPE", "Unknown", None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "STATUS", "Active", None, False)
    logging.debug("     Successfully Assigned 2 Default Values to P_AlignmentSheet")
    logging.debug("Completed setting up the P_AlignmentSheet featureclass...")
    
    ##############################################################
    # Defining P_CapitalProject
    ##############################################################
    logging.debug("Create Polygon featureclass P_CapitalProject class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_CapitalProject", "POLYGON", None, "DISABLED", "DISABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_CapitalProject"

    #Adding Attributes to featureclass
    logging.debug("     Adding 13 Attribute to P_CapitalProject")
    arcpy.management.AddField(InputDataset, "PROJECTNAME", "TEXT", None, None, 50, "Project Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PROJECTID", "SHORT", None, None, None, "ProjectID", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 15, "Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ASSIGNEDTO", "TEXT", None, None, 50, "Assigned To", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PERCOMPLETE", "DOUBLE", 8, 5, None, "Percent Complete", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ESTMATERIALCOST", "DOUBLE", 8, 5, None, "Estimated Material Cost", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ESTLABOREQPTCOST", "DOUBLE", 8, 5, None, "Estimated Labor and Equipment Cost", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ESTTOTALOCST", "DOUBLE", 8, 5, None, "Estimated Total Cost", "NULLABLE", "NON_REQUIRED", None)    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 13 Attributes to P_CapitalProject")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_CapitalProject")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus", None)
    logging.debug("     Successfully Assigned 1 Domains to P_CapitalProject")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 1 Default Values to P_CapitalProject")
    arcpy.management.AssignDefaultToField(InputDataset, "STATUS", "Active", None, False)
    logging.debug("     Successfully Assigned 1 Default Values to P_CapitalProject")
    logging.debug("Completed setting up the P_CapitalProject featureclass...")
    
    ##############################################################
    # Defining P_CasingInspection
    ##############################################################
    logging.debug("Create table P_CasingInspection class...")
    arcpy.management.CreateTable(targetWorkspace, "P_CasingInspection", None, None)   
    InputDataset = targetWorkspace + SQLPrefix + "P_CasingInspection"

    #Adding Attributes to featureclass
    logging.debug("     Adding 16 Attribute to P_CasingInspection")    
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 50, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATERECORDED", "DATE", None, None, None, "Date Recorded", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CARRIERPIPEPSON", "DOUBLE", 16, 6, None, "Carrier Pipe PS On", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CARRIERPIPEPSOFF", "DOUBLE", 16, 6, None, "Carrier Pipe PS Off", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CASINGPIPEPSON", "DOUBLE", 16, 6, None, "Casing Pipe PS On", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CASINGPIPEPSOFF", "DOUBLE", 16, 6, None, "Casing Pipe PS Off", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SHORTED", "SHORT", None, None, None, "Shorted", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSTRUMENT", "TEXT", None, None, 30, "Instrument", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEREQUIRED", "TEXT", None, None, 255, "Maintenance Required", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEPERFORMED", "TEXT", None, None, 255, "Maintenance Performed", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STRUCTURELINE_GlobalID", "GUID", None, None, None, "Structure Line GlobalID", "NULLABLE", "NON_REQUIRED", None)
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 16 Attributes to P_CasingInspection")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_CasingInspection")
    arcpy.management.AssignDomainToField(InputDataset, "SHORTED", "UPDM_YesNoIndicator", None)
    logging.debug("     Successfully Assigned 1 Domains to P_CasingInspection")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 1 Default Values to P_CasingInspection")
    arcpy.management.AssignDefaultToField(InputDataset, "SHORTED", 0, None, False)
    logging.debug("     Successfully Assigned 1 Default Values to P_CasingInspection")

    #Add Relationship Class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "StructureLine_P_CasingInspection"
    arcpy.management.CreateRelationshipClass(structureLine, InputDataset, RelName, "SIMPLE", "P_CasingInspection", "StructureLine", "NONE", "ONE_TO_MANY", "NONE", "GLOBALID", "STRUCTURELINE_GlobalID", None, None)

    logging.debug("Completed setting up the P_CasingInspection table...")
    
    ##############################################################
    # Defining P_Coupon
    ##############################################################
    logging.debug("Create Point featureclass P_Coupon class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_Coupon", "POINT", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_Coupon"

    #Adding Attributes to featureclass
    logging.debug("     Adding 7 Attribute to P_Coupon")
    arcpy.management.AddField(InputDataset, "PRECENTOFGRAPH", "DOUBLE", 8, 5, None, "Percent of Graph", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WALLTHICKNESS", "DOUBLE", 16, 6, None, "Wall Thickness", "NULLABLE", "NON_REQUIRED", None)
   
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 7 Attributes to P_Coupon")

    #Add Domains to Featureclass
    logging.debug("     Assigning 0 Domains to P_Coupon")
    logging.debug("     Successfully Assigned 0 Domains to P_Coupon")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 0 Default Values to P_Coupon")
    logging.debug("     Successfully Assigned 0 Default Values to P_Coupon")
    logging.debug("Completed setting up the P_Coupon featureclass...")
    
    ##############################################################
    # Defining P_CPBondInspection
    ##############################################################
    logging.debug("Create table P_CPBondInspection class...")
    arcpy.management.CreateTable(targetWorkspace, "P_CPBondInspection", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_CPBondInspection"

    #Adding Attributes to featureclass
    logging.debug("     Adding 7 Attribute to P_CPBondInspection")
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 50, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATEINSPECTED", "DATE", None, None, None, "Date Inspected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BONDEDPSON", "DOUBLE", 8, 5, None, "Bonded PS On", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DISBONDEDPSON", "DOUBLE", 8, 5, None, "Disbonded PS On", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FOREIGNSTRUCTUREDISBONDEDPSON", "DOUBLE", 8, 5, None, "Foreign Structure Disbonded PS On", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DCAMPS", "DOUBLE", 8, 5, None, "DC Amps", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSTRUMENT", "TEXT", None, None, 30, "Instrument", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEREQUIRED", "TEXT", None, None, 255, "Maintenance Required", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEPERFORMED", "TEXT", None, None, 255, "Maintenance Performed", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UPDMJunction_GlobalID", "GUID", None, None, None, "UPDMJunction GlobalID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UPDMLine_GlobalID", "GUID", None, None, None, "UPDMLine GlobalID", "NULLABLE", "NON_REQUIRED", None)
  
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 7 Attributes to P_CPBondInspection")

    #Add Domains to Featureclass
    logging.debug("     Assigning 0 Domains to P_CPBondInspection")
    logging.debug("     Successfully Assigned 0 Domains to P_CPBondInspection")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 0 Default Values to P_CPBondInspection")
    logging.debug("     Successfully Assigned 0 Default Values to P_CPBondInspection")

    #Add Relationship Class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMJunction_P_CPBondInspection"
    arcpy.management.CreateRelationshipClass(UPDMJunction, InputDataset, RelName, "SIMPLE", "P_CPBondInspection", "UPDMJunction", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMJunction_GlobalID", None, None)
    logging.debug("Completed setting up the P_CPBondInspection table...")

    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMLine_P_CPBondInspection"
    arcpy.management.CreateRelationshipClass(UPDMLine, InputDataset, RelName, "SIMPLE", "P_CPBondInspection", "UPDMLine", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMLine_GlobalID", None, None)
    logging.debug("Completed setting up the P_CPBondInspection table...")
 
    ##############################################################
    # Defining P_CPRectifierInspection
    ##############################################################
    logging.debug("Create table P_CPRectifierInspection class...")
    arcpy.management.CreateTable(targetWorkspace, "P_CPRectifierInspection", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_CPRectifierInspection"

    #Adding Attributes to featureclass
    logging.debug("     Adding 21 Attribute to P_CPRectifierInspection")
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 50, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATEINSPECTED", "DATE", None, None, None, "Date Inspected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PSON", "DOUBLE", 8, 5, None, "PS On", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PSOFF", "DOUBLE", 8, 5, None, "PS Off", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DCVOLTAGEFOUND", "DOUBLE", 8, 5, None, "DC Voltage Found", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DCAMPSFOUND", "DOUBLE", 8, 5, None, "DC Amps Found", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STATUSASFOUND", "TEXT", None, None, 5, "On Off Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DCVOLTAGELEFT", "DOUBLE", 8, 5, None, "DC Voltage Left", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DCAMPSLEFT", "DOUBLE", 8, 5, None, "DC Amperage Left", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STATUSASLEFT", "TEXT", None, None, 5, "Status as Left", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TAPTYPE", "TEXT", None, None, 15, "Tap Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TAPSETTING", "TEXT", None, None, 15, "Tap Setting", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSTRUMENT", "TEXT", None, None, 30, "Instrument", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEREQUIRED", "TEXT", None, None, 255, "Maintenance Required", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEPERFORMED", "TEXT", None, None, 255, "Maintenance Performed", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UPDMDevice_GlobalID", "GUID", None, None, None, "UPDMDevice GlobalID", "NULLABLE", "NON_REQUIRED", None)
  
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 21 Attributes to P_CPRectifierInspection")

    #Add Domains to Featureclass
    logging.debug("     Assigning 2 Domains to P_CPRectifierInspection")
    arcpy.management.AssignDomainToField(InputDataset, "STATUSASFOUND", "UPDM_OnOffStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "STATUSASLEFT", "UPDM_OnOffStatus", None)
    logging.debug("     Successfully Assigned 2 Domains to P_CPRectifierInspection")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 0 Default Values to P_CPRectifierInspection")
    logging.debug("     Successfully Assigned 0 Default Values to P_CPRectifierInspection")

    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMDevice_P_CPRectifierInspection"
    arcpy.management.CreateRelationshipClass(UPDMDevice, InputDataset, RelName, "SIMPLE", roleUPDMDevice, "P_CPRectifierInspection", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMDevice_GlobalID", None, None)
    logging.debug("Completed setting up the P_CPRectifierInspection table...")
    
    ##############################################################
    # Defining P_CPTestPointReading
    ##############################################################
    logging.debug("Create table P_CPTestPointReading class...")
    arcpy.management.CreateTable(targetWorkspace, "P_CPTestPointReading", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_CPTestPointReading"

    #Adding Attributes to featureclass
    logging.debug("     Adding 21 Attribute to P_CPTestPointReading")
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 50, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATEINSPECTED", "DATE", None, None, None, "Date Inspected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PSON", "DOUBLE", 8, 5, None, "PS On", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PSOFF", "DOUBLE", 8, 5, None, "PS Off", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOILRESISTIVITY", "DOUBLE", 8, 5, None, "Soil Resistivity", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SHORTED", "SHORT", None, None, None, "Shorted", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSTRUMENT", "TEXT", None, None, 30, "Instrument", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REASONFORFAILUREREADING", "TEXT", None, None, 30, "Reason For Failed Reading", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CORRECTIVEACTIONTAKEN", "TEXT", None, None, 30, "Corrective Action Taken", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEREQUIRED", "TEXT", None, None, 255, "Maintenance Required", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEPERFORMED", "TEXT", None, None, 255, "Maintenance Performed", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UPDMDevice_GlobalID", "GUID", None, None, None, "CPRectifier GlobalID", "NULLABLE", "NON_REQUIRED", None)
  
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 21 Attributes to P_CPTestPointReading")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_CPTestPointReading")
    arcpy.management.AssignDomainToField(InputDataset, "SHORTED", "UPDM_YesNoIndicator", None)
    logging.debug("     Successfully Assigned 1 Domains to P_CPTestPointReading")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 0 Default Values to P_CPTestPointReading")
    logging.debug("     Successfully Assigned 0 Default Values to P_CPTestPointReading")

    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMDevice_P_CPTestReading"
    arcpy.management.CreateRelationshipClass(UPDMDevice, InputDataset, RelName, "SIMPLE", roleUPDMDevice, "CPTestPointReading", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMDevice_GlobalID", None, None)
    logging.debug("Completed setting up the P_CPTestPointReading featureclass...")
    
    ##############################################################
    # Defining P_CrossingInspection
    ##############################################################
    logging.debug("Create table P_CrossingInspection class...")
    arcpy.management.CreateTable(targetWorkspace, "P_CrossingInspection", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_CrossingInspection"

    #Adding Attributes to featureclass
    logging.debug("     Adding 11 Attribute to P_CrossingInspection")
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 50, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LASTINSPECTIONDATE", "DATE", None, None, None, "Last Inspection Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NEXTINSPECTIONDATE", "DATE", None, None, None, "Next Inspection Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONDESCRIPTION", "TEXT", None, None, 150, "Location Description", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NOTES", "TEXT", None, None, 255, "Notes", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PIPECROSSING_GlobalID", "GUID", None, None, None, "Pipe Crossing GlobalID", "NULLABLE", "NON_REQUIRED", None)
  
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 11 Attributes to P_CrossingInspection")

    #Add Domains to Featureclass
    logging.debug("     Assigning 0 Domains to P_CrossingInspection")
    logging.debug("     Successfully Assigned 0 Domains to P_CrossingInspection")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 0 Default Values to P_CrosingInspection")
    logging.debug("     Successfully Assigned 0 Default Values to P_CrossingInspection")

    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "PipeCrossing_P_CrossingInspection"
    arcpy.management.CreateRelationshipClass(UPDMDevice, InputDataset, RelName, "SIMPLE", roleUPDMDevice, "CrossingInspection", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "PIPECROSSING_GlobalID", None, None)
    logging.debug("Completed setting up the P_CrossingInspection table...")


    ##############################################################
    # Defining P_ElectricSurvey
    ##############################################################
    logging.debug("Create table P_ElectricSurvey class...")
    arcpy.management.CreateTable(targetWorkspace, "P_ElectricSurvey", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_ElectricSurvey"

    #Adding Attributes to featureclass
    logging.debug("     Adding 10 Attribute to P_ElectricSurvey")
    arcpy.management.AddField(InputDataset, "SURVEYDATE", "DATE", None, None, None, "Survey Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SURVEYDUEDATE", "DATE", None, None, None, "Survey Due Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SURVEYFREQUENCY", "SHORT", None, None, None, "Survey Frequency", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "VOLTAGE", "DOUBLE", 8, 4, None, "Voltage", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "AMPERAGE", "DOUBLE", 8, 4, None, "Amperage", "NULLABLE", "NON_REQUIRED", None)
  
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 10 Attributes to P_ElectricSurvey")

    #Add Domains to Featureclass
    logging.debug("     Assigning 0 Domains to P_ElectricSurvey")
    logging.debug("     Successfully Assigned 0 Domains to P_ElectricSurvey")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 0 Default Values to P_ElectricSurvey")
    logging.debug("     Successfully Assigned 0 Default Values to P_ElectricSurvey")
    logging.debug("Completed setting up the P_ElectricSurvey table...")

    ##############################################################
    # Defining P_ExcavationDamage
    ##############################################################
    logging.debug("Create Point featureclass P_ExcavationDamage class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_ExcavationDamage", "POLYLINE", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_ExcavationDamage"

    #Adding Attributes to featureclass
    logging.debug("     Adding 42 Attribute to P_ExcavationDamage")
    arcpy.management.AddField(InputDataset, "DATADAMAGED", "DATE", None, None, None, "Data Damaged", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RESPONSIBLEPARTYNAME", "TEXT", None, None, 50, "Responsible Party Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RESPONSIBLECONTACTNAME", "TEXT", None, None, 50, "Responsible Contact Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RESPONSIBLEPARTYADDRESS", "TEXT", None, None, 50, "Responsible Party Address", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RESPONSIBLEPARTYCITY", "TEXT", None, None, 50, "Responsible Party City", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RESPONSIBLEPARTYSTATE", "TEXT", None, None, 2, "Responsible Party State", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RESPONSIBLEPARTYPHONE", "TEXT", None, None, 20, "Responsible Party Phone", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "RESPONSIBLEPARTYTYPE", "TEXT", None, None, 30, "Responsible Party Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INCIDENTLOCATIONADDRESS", "TEXT", None, None, 50, "Incident Location Address", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INCIDENTLOCATIONCITY", "TEXT", None, None, 50, "Incident Location City", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INCIDENTLOCATIONSTATE", "TEXT", None, None, 2, "Incident Location State", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DAMAGETYPE", "TEXT", None, None, 25, "Damage Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DAMAGEDFACILITYTYPE", "TEXT", None, None, 30, "Damaged Facility Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EQUIPCAUSINGDAMAGE", "TEXT", None, None, 20, "Equipment Causing Damage", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WORKTYPE", "TEXT", None, None, 30, "Work Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ROOTCAUSE", "TEXT", None, None, 30, "Root Cause", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "POLICEREPORT", "SHORT", None, None, None, "Police Report", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REMARKS", "TEXT", None, None, 250, "Remarks", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "GPSX", "DOUBLE", 16, 8, None, "GPS X", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GPSY", "DOUBLE", 16, 8, None, "GPSY", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 42 Attributes to P_ExcavationDamage")

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)

    #Add Domains to Featureclass
    logging.debug("     Assigning 9 Domains to P_ExcavationDamage")
    arcpy.management.AssignDomainToField(InputDataset, "RESPONSIBLEPARTYSTATE", "UPDM_Region", None)
    arcpy.management.AssignDomainToField(InputDataset, "RESPONSIBLEPARTYTYPE", "UPDM_ExcavDamRespPartyType", None)
    arcpy.management.AssignDomainToField(InputDataset, "DAMAGETYPE", "UPDM_ExcavDamDamageType", None)
    arcpy.management.AssignDomainToField(InputDataset, "DAMAGEDFACILITYTYPE", "UPDM_LeakFacilityType", None)
    arcpy.management.AssignDomainToField(InputDataset, "EQUIPCAUSINGDAMAGE", "UPDM_ExcavEquipCausingDamage", None)
    arcpy.management.AssignDomainToField(InputDataset, "WORKTYPE", "UPDM_ExcavDamWorkType", None)
    arcpy.management.AssignDomainToField(InputDataset, "ROOTCAUSE", "UPDM_ExcavDamRootCause", None)
    arcpy.management.AssignDomainToField(InputDataset, "INCIDENTLOCATIONSTATE", "UPDM_Region", None)
    arcpy.management.AssignDomainToField(InputDataset, "POLICEREPORT", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 9 Domains to UPDM_ExcavationDamage")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 1 Default Values to P_ExcavationDamage")
    arcpy.management.AssignDefaultToField(InputDataset, "POLICEREPORT", 1, None, False)
    logging.debug("     Successfully Assigned 1 Default Values to P_ExcavationDamage")
    logging.debug("Completed setting up the P_ExcavationDamage featureclass...")

    ##############################################################
    # Defining P_ExposedPipeInspect
    ##############################################################
    logging.debug("Create Line featureclass P_ExposedPipeInspect class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_ExposedPipeInspect", "POLYLINE", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_ExposedPipeInspect"

    #Adding Attributes to featureclass
    logging.debug("     Adding 40 Attribute to P_ExposedPipeInspect")
    arcpy.management.AddField(InputDataset, "INSPECTIONNUMBER", "TEXT", None, None, 20, "Inspection Number", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONDATE", "DATE", None, None, None, "Inspection Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 20, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LENGTHEXPOSED", "DOUBLE", 16, 5, None, "Length Exposed", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PIPEDEPTH", "DOUBLE", 16, 5, None, "Pipe Depth", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PITTINGDEPTH", "DOUBLE", 16, 5, None, "Pitting Depth", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOILTYPE", "TEXT", None, None, 20, "Soil Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COATINGCONDITION", "TEXT", None, None, 25, "Coating Condition", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CORROSIONCONDITION", "TEXT", None, None, 25, "Corrosion Condition", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CORROSIONEXTENT", "TEXT", None, None, 20, "Corrosion Extent", "NULLABLE", "NON_REQUIRED", None)   
    arcpy.management.AddField(InputDataset, "PIPECONDITION", "TEXT", None, None, 20, "Pipe Condition", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "JOINTTRENCH", "SHORT", None, None, None, "Joint Trench", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TRENCHENCROACHMENT", "SHORT", None, None, None, "Joint Encroachment", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REPAIRORDERREQUIRED", "SHORT", None, None, None, "Repair Order Required", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 255, "COMMENTS", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PIPEEXPOSURE_GlobalID", "GUID", None, None, None, "Pipe Exposure GlobalID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None) 
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 40 Attributes to P_ExposedPipeInspect")

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)

    #Add Domains to Featureclass
    logging.debug("     Assigning 5 Domains to P_ExposedPipeInspect")
    arcpy.management.AssignDomainToField(InputDataset, "SOILTYPE", "UPDM_SoilType", None)
    arcpy.management.AssignDomainToField(InputDataset, "COATINGCONDITION", "UPDM_CoatingCondition", None)
    arcpy.management.AssignDomainToField(InputDataset, "CORROSIONCONDITION", "UPDM_CorrosionCondition", None)
    arcpy.management.AssignDomainToField(InputDataset, "CORROSIONEXTENT", "UPDM_CorrosionExtent", None)
    arcpy.management.AssignDomainToField(InputDataset, "PIPECONDITION", "UPDM_PipeCondition", None)
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 5 Domains to UPDM_ExposedPipeInspect")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 1 Default Values to P_ExposedPipeInspect")
    arcpy.management.AssignDefaultToField(InputDataset, "PIPECONDITION", "Normal", None, False)
    logging.debug("     Successfully Assigned 1 Default Values to P_ExposedPipeInspect")

    #Add Relationship class
    pathPipeExposure = targetWorkspace + SQLPrefix + "P_PipeExposure"
    RelName = targetWorkspace + SQLPrefix + "PipeExposure_P_ExpPipeInspection"
    arcpy.management.CreateRelationshipClass(pathPipeExposure, InputDataset, RelName, "SIMPLE", "P_PipeExposure", "P_ExposedPipeInspect", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "PIPEEXPOSURE_GlobalID", None, None)

    logging.debug("Completed setting up the P_ExposedPipeInspect featureclass...")

    ##############################################################
    # Defining P_GasLeak
    ##############################################################
    logging.debug("Create Point featureclass P_GasLeak class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_GasLeak", "POINT", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_GasLeak"



    #Adding Attributes to featureclass
    logging.debug("     Adding 49 Attribute to P_GasLeak")
    arcpy.management.AddField(InputDataset, "LEAKCAUSE", "LONG", None, None, None, "Leak Cause", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LEAKCAUSETYPE", "TEXT", None, None, 50, "Leak Cause Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LEAKSTATUS", "TEXT", None, None, 15, "Leak Status", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "TIMEREPORTED", "DATE", None, None, None, "Time Reported", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "TIMEDISPATCHED", "DATE", None, None, None, "Time Dispatched", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TIMEARRIVED", "DATE", None, None, None, "Time Arrived", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TIMEMADESAFE", "DATE", None, None, None, "Time Made Safe", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ADDRESS", "TEXT", None, None, 100, "Address", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONDESCRIPTION", "TEXT", None, None, 250, "Location Description", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GASIN", "TEXT", None, None, 25, "Gas In", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ORIGINALLEAKCLASS", "SHORT", None, None, None, "Original Leak Class", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "METHODDETECTED", "TEXT", None, None, 20, "Method Detected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GASMEASUREMENT", "DOUBLE", 10, 4, None, "Gas Measurement", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GASMEASUREMENTUNITS", "SHORT", None, None, None, "Gas Measurement Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SURFACETYPE", "TEXT", None, None, 20, "Surface Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PROBABLESOURCE", "TEXT", None, None, 25, "Probable Source", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REVISEDLEAKCLASS", "SHORT", None, None, None, "Revised Leak Class", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REVISEDLEAKDATE", "DATE", None, None, None, "Revised Leak Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REVISEDLEAKSUPERVISOR", "TEXT", None, None, 50, "Revised Leak Supervisor", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REPORTABLEINCIDENT", "SHORT", None, None, None, "Reportable Incident", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "DOTREPORTEDINDICATOR", "SHORT", None, None, None, "DOT Reported Indicator", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FEDERALLANDINDICATOR", "SHORT", None, None, None, "Federal Land Indicator", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMPDATE", "DATE", None, None, None, "Compliance Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DUEDATE", "DATE", None, None, None, "Due Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FREQUENCY", "SHORT", None, None, None, "Inspection Frequency", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
   
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 49 Attributes to P_GasLeak")

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)

    #Adding Subtype Values
    arcpy.SetSubtypeField_management(InputDataset, "LEAKCAUSE", "")
    arcpy.SetDefaultSubtype_management(InputDataset, 0)
    
    logging.debug("     Adding 9 Subtype Codes to Assembly")
    arcpy.management.AddSubtype(InputDataset, 0, "Unknown")    
    arcpy.management.AddSubtype(InputDataset, 1, "Incorrect Operations")
    arcpy.management.AddSubtype(InputDataset, 2, "Material or Welds")
    arcpy.management.AddSubtype(InputDataset, 3, "Manufacturing")
    arcpy.management.AddSubtype(InputDataset, 4, "Construction")
    arcpy.management.AddSubtype(InputDataset, 5, "Equipment")
    arcpy.management.AddSubtype(InputDataset, 6, "Natural Forces")
    arcpy.management.AddSubtype(InputDataset, 7, "Corrosion")
    arcpy.management.AddSubtype(InputDataset, 8, "Other Outside Force Damage")
    arcpy.management.AddSubtype(InputDataset, 9, "Excavation Damage")
    arcpy.management.AddSubtype(InputDataset, 10, "Other")
    logging.debug("     9 Subtype Codes created for Assembly")

    #Add Domains to Featureclass
    logging.debug("     Assigning 17 Domains to P_GasLeak")
    arcpy.management.AssignDomainToField(InputDataset, "LEAKCAUSETYPE", "UPDM_LeakCauseOperations", "1")
    arcpy.management.AssignDomainToField(InputDataset, "LEAKCAUSETYPE", "UPDM_LeakCauseMaterial", "2")
    arcpy.management.AssignDomainToField(InputDataset, "LEAKCAUSETYPE", "UPDM_LeakCauseEquipment", "5")
    arcpy.management.AssignDomainToField(InputDataset, "LEAKCAUSETYPE", "UPDM_LeakCauseNatural", "6")
    arcpy.management.AssignDomainToField(InputDataset, "LEAKCAUSETYPE", "UPDM_LeakCauseCorrosion", "7")
    arcpy.management.AssignDomainToField(InputDataset, "LEAKCAUSETYPE", "UPDM_LeakCauseOutsideForce", "8")
    arcpy.management.AssignDomainToField(InputDataset, "LEAKCAUSETYPE", "UPDM_LeakCauseExcavation", "9")
    arcpy.management.AssignDomainToField(InputDataset, "LEAKSTATUS", "UPDM_LeakClosedStatus", "0;1;2;3;4;5;6;7;8;9;10")
    arcpy.management.AssignDomainToField(InputDataset, "ORIGINALLEAKCLASS", "UPDM_LeakClass", "0;1;2;3;4;5;6;7;8;9;10")
    arcpy.management.AssignDomainToField(InputDataset, "GASIN", "UPDM_LeakInspectGasIn", "0;1;2;3;4;5;6;7;8;9;10")
    arcpy.management.AssignDomainToField(InputDataset, "METHODDETECTED", "UPDM_LeakMethodDetected", "0;1;2;3;4;5;6;7;8;9;10")
    arcpy.management.AssignDomainToField(InputDataset, "GASMEASUREMENTUNITS", "UPDM_MeasurementUnits", "0;1;2;3;4;5;6;7;8;9;10")
    arcpy.management.AssignDomainToField(InputDataset, "SURFACETYPE", "UPDM_SurfaceType", "0;1;2;3;4;5;6;7;8;9;10")
    arcpy.management.AssignDomainToField(InputDataset, "PROBABLESOURCE", "UPDM_LeakFacilityType", "0;1;2;3;4;5;6;7;8;9;10")                                           
    arcpy.management.AssignDomainToField(InputDataset, "REVISEDLEAKCLASS", "UPDM_LeakClass", "0;1;2;3;4;5;6;7;8;9;10")                                           
    arcpy.management.AssignDomainToField(InputDataset, "REPORTABLEINCIDENT", "UPDM_YesNoIndicator", "0;1;2;3;4;5;6;7;8;9;10")
    arcpy.management.AssignDomainToField(InputDataset, "DOTREPORTEDINDICATOR", "UPDM_YesNoIndicator", "0;1;2;3;4;5;6;7;8;9;10")
    arcpy.management.AssignDomainToField(InputDataset, "FEDERALLANDINDICATOR", "UPDM_YesNoIndicator", "0;1;2;3;4;5;6;7;8;9;10")
    logging.debug("     Successfully Assigned 17 Domains to P_GasLeak")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 3 Default Values to P_GasLeak")
    arcpy.management.AssignDefaultToField(InputDataset, "DOTREPORTEDINDICATOR", 2, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "FEDERALLANDINDICATOR", 2, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "REPORTABLEINCIDENT", 0, None, False)
    logging.debug("     Successfully Assigned 3 Default Values to P_GasLeak")

    #Add Relationship class
    logging.debug("Completed setting up the P_GasLeak featureclass...")
  
    ##############################################################
    # Defining P_GasLeakInspect
    ##############################################################
    logging.debug("Create Table P_GasLeakInspect class...")
    arcpy.management.CreateTable(targetWorkspace, "P_GasLeakInspect", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_GasLeakInspect"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 29 Attribute to P_GasLeakInspect")
    arcpy.management.AddField(InputDataset, "DATEINSPECTED", "DATE", None, None, None, "Date Inspected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 50, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SURFACETYPE", "TEXT", None, None, 20, "Surface Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GASIN", "TEXT", None, None, 25, "Gas In", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PROBABLESOURCE", "TEXT", None, None, 25, "Facility", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LEAKCLASS", "SHORT", None, None, None, "Original Leak Class", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "METHODDETECTED", "TEXT", None, None, 20, "Method Detected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GASMEASUREMENT", "DOUBLE", 10, 4, None, "Gas Measurement", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GASMEASUREMENTUNITS", "SHORT", None, None, None, "Gas Measurement Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 255, "Comments", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GASLEAK_GlobalID", "GUID", None, None, None, "GasLeak GlobalID", "NULLABLE", "NON_REQUIRED", None)                                           
   
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)
    
    logging.debug("     Successfully Added 29 Attributes to P_GasLeakInspect")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 6 Domains to P_GasLeakInspect")
    arcpy.management.AssignDomainToField(InputDataset, "GASIN", "UPDM_LeakInspectGasIn", None)
    arcpy.management.AssignDomainToField(InputDataset, "SURFACETYPE", "UPDM_SurfaceType", None)
    arcpy.management.AssignDomainToField(InputDataset, "PROBABLESOURCE", "UPDM_LeakFacilityType", None)
    arcpy.management.AssignDomainToField(InputDataset, "LEAKCLASS", "UPDM_LeakClass", None)
    arcpy.management.AssignDomainToField(InputDataset, "METHODDETECTED", "UPDM_LeakMethodDetected", None)
    arcpy.management.AssignDomainToField(InputDataset, "GASMEASUREMENTUNITS", "UPDM_MeasurementUnits", None)
    logging.debug("     Successfully Assigned 6 Domains to P_GasLeakInspect")

    #Add Relationship class
    pathGasLeak = targetWorkspace + SQLPrefix + "P_GasLeak"
    RelName = targetWorkspace + SQLPrefix + "GasLeak_P_LeakInspection"
    arcpy.management.CreateRelationshipClass(pathGasLeak, InputDataset, RelName, "SIMPLE", "P_GasLeak", "P_GasLeakInspect", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "GASLEAK_GlobalID", None, None)
    logging.debug("Completed setting up the P_GasLeakInspect table...")
                                           
    ##############################################################
    # Defining P_IdentifiedIssue
    ##############################################################
    logging.debug("Create Point featureclass P_IdentifiedIssue class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_IdentifiedIssue", "POINT", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_IdentifiedIssue"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 25 Attribute to P_IdentifiedIssue")
    arcpy.management.AddField(InputDataset, "ISSUE", "TEXT", None, None, 50, "Issue", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATEREPORTED", "DATE", None, None, None, "Date Reported", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REPORTEDBY", "TEXT", None, None, 50, "Reported By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 255, "Comments", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "GPSX", "DOUBLE", 16, 8, None, "GPS X", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GPSY", "DOUBLE", 16, 8, None, "GPSY", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
                                           
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 25 Attributes to P_IdentifiedIssue")

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)
                                           
    #Add Domains to Featureclass
    logging.debug("     Assigning 2 Domains to P_IdentifiedIssue")
    arcpy.management.AssignDomainToField(InputDataset, "ISSUE", "UPDM_IdentifiedIssue", None)
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 2 Domains to P_IdentifiedIssue")
                                           
    logging.debug("Completed setting up the P_IdentifiedIssue featureclass...")

    ##############################################################
    # Defining P_IsolatedPipeInspection
    ##############################################################
    logging.debug("Create Table featureclass P_IsolatedPipeInspection class...")
    arcpy.management.CreateTable(targetWorkspace, "P_IsolatedPipeInspection", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_IsolatedPipeInspection"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 13 Attribute to P_IsolatedPipeInspection")
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 50, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATEINSPECTED", "DATE", None, None, None, "Date Inspected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PSON", "DOUBLE", 16, 5, None, "PSON", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SHORTED", "SHORT", None, None, None, "Shorted", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSTRUMENT", "TEXT", None, None, 50, "Instrument", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEREQUIRED", "TEXT", None, None, 255, "Maintenance Required", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAINTENANCEPERFORMED", "TEXT", None, None, 255, "Maintenance Performed", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UPDMLine_GlobalID", "GUID", None, None, None, "UPDMLine GlobalID", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 13 Attributes to P_IsolatedPipeInspection")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_IsolatedPipeInspection")
    arcpy.management.AssignDomainToField(InputDataset, "SHORTED", "UPDM_YesNoIndicator", None)
    logging.debug("     Successfully Assigned 1 Domains to P_IsolatedPipeInspection")
    
    #Add Default Values to Featureclass
    logging.debug("     Assigning 1 Default Values to P_IsolatedPipeInspection")
    arcpy.management.AssignDefaultToField(InputDataset, "SHORTED", 0, None, False)
    
    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMLine_P_IsoPipeInspection"
    arcpy.management.CreateRelationshipClass(UPDMLine, InputDataset, RelName, "SIMPLE", roleUPDMLine, "P_IsolatedPipeInspection", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMLine_GlobalID", None, None)
    logging.debug("Completed setting up the P_IsolatedPipeInspection table...")
                                           
    ##############################################################
    # Defining P_LeakRepairs
    ##############################################################
    logging.debug("Create Linefeatureclass P_LeakRepairs class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_LeakRepairs", "POLYLINE", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_LeakRepairs"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 32 Attribute to P_LeakRepairs")
    arcpy.management.AddField(InputDataset, "LEAKREPAIRTYPE", "TEXT", None, None, 30, "Leak Repair Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REPAIREDBY", "TEXT", None, None, 50, "Repaired By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATEREPAIRED", "DATE", None, None, None, "Date Repaired", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DAMAGETYPE", "TEXT", None, None, 30, "Damage Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LEAKLOCATION", "TEXT", None, None, 30, "Leak Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WORKPERFORMED", "TEXT", None, None, 30, "Work Performed", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "SOILATPIPEDEPTH", "TEXT", None, None, 20, "Soil at Pipe Depth", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SURFACETYPE", "TEXT", None, None, 20, "Surface Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MEASUREDLENGTH", "DOUBLE", 16, 5, None, "Measured Length", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GasLeak_GlobalID", "GUID", None, None, None, "GasLeak_GlobalID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None) 
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGFROMM", "DOUBLE", 16, 5, None, "Engineering From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTEID", "TEXT", None, None, 38, "Engineering To RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOROUTENAME", "TEXT", None, None, 100, "Engineering To Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGTOM", "DOUBLE", 16, 5, None, "Engineering To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINFROMM", "DOUBLE", 16, 5, None, "Continuous From Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINTOM", "DOUBLE", 16, 5, None, "Continuous To Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFMETHOD", "SHORT", None, None, None, "From Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFOFFSET", "TEXT", None, None, 50, "From Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMREFLOCATION", "TEXT", None, None, 50, "From Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFMETHOD", "SHORT", None, None, None, "To Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFOFFSET", "TEXT", None, None, 50, "To Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOREFLOCATION", "TEXT", None, None, 50, "To Reference Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LOCATIONERROR", "TEXT", None, None, 100, "Location Error", "NULLABLE", "NON_REQUIRED", None)
                                           
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 32 Attributes to P_LeakRepairs")

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)
                                         
    #Add Domains to Featureclass
    logging.debug("     Assigning 7 Domains to P_LeakRepairs")
    arcpy.management.AssignDomainToField(InputDataset, "LEAKREPAIRTYPE", "UPDM_LeakRepairType", None)
    arcpy.management.AssignDomainToField(InputDataset, "DAMAGETYPE", "UPDM_ExcavDamageType", None)
    arcpy.management.AssignDomainToField(InputDataset, "LEAKLOCATION", "UPDM_LeakLocation", None)
    arcpy.management.AssignDomainToField(InputDataset, "WORKPERFORMED", "UPDM_LeakWorkPerformed", None)
    arcpy.management.AssignDomainToField(InputDataset, "SOILATPIPEDEPTH", "UPDM_SoilType", None)
    arcpy.management.AssignDomainToField(InputDataset, "SURFACETYPE", "UPDM_SurfaceType", None)
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 7 Domains to P_LeakRepairs")

    #Add Relationship class
    pathGasLeak = targetWorkspace + SQLPrefix + "P_GasLeak"
    RelName = targetWorkspace + SQLPrefix + "Leak_P_LeakRepair"
    arcpy.management.CreateRelationshipClass(pathGasLeak, InputDataset, RelName, "SIMPLE", "P_GasLeak", "P_LeakRepairs", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "GasLeak_GlobalID", None, None)
                                           
    logging.debug("Completed setting up the P_LeakRepairs featureclass...")

    ##############################################################
    # Defining P_LeakSurveyArea
    ##############################################################
    logging.debug("Create Table P_Leak Survey Area featureclass...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_LeakSurveyArea", "POLYGON", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_LeakSurveyArea"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 27 Attribute to P_LeakSurveyArea")
    arcpy.management.AddField(InputDataset, "SURVEYTYPE", "TEXT", None, None, 30, "Survey Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAPGRIDNAME", "TEXT", None, None, 20, "Map Grid Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SURVEYSTATUS", "TEXT", None, None, 15, "Survey Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ASSIGNEDCREWLEADER", "TEXT", None, None, 50, "Assigned Crew Leader", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SURVEYEDBY", "TEXT", None, None, 50, "Surveyed By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STARTDATE", "DATE", None, None, None, "Start Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENDDATE", "DATE", None, None, None, "End Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DUEDATE", "DATE", None, None, None, "Due Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMPDATE", "DATE", None, None, None, "Compliance Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BELOWGRADELEAKS", "SHORT", None, None, None, "Below Grade Leaks", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SURVEYMETHOD", "TEXT", None, None, 30, "Survey Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FOOTAGEMAINS", "DOUBLE", 16, 5, None, "Footage Mains", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NUMBERSERVICES", "LONG", None, None, None, "Number of Services", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DURATION", "DOUBLE", None, None, None, "Duration", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 1000, "Comments", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERVAL", "SHORT", None, None, 1000, "Interval", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ASSIGNEDHELPER1", "TEXT", None, None, 50, "Assigned Helper 1", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ASSIGNEDHELPER2", "TEXT", None, None, 50, "Assigned Helper 2", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ASSIGNEDHELPER3", "TEXT", None, None, 50, "Assigned Helper 3", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REMAININGFOOTAGEMAINS", "DOUBLE", 16, 5, None, "Remaining Footage Mains", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REMAININGSERVICES", "LONG", None, None, None, "Remaining Services", "NULLABLE", "NON_REQUIRED", None)

    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 27 Attributes to P_LeakSurveyArea")

    #Add Domains to Featureclass
    logging.debug("     Assigning 4 Domains to P_LeakSurveyArea")
    arcpy.management.AssignDomainToField(InputDataset, "SURVEYTYPE", "UPDM_LeakSurveyType", None)
    arcpy.management.AssignDomainToField(InputDataset, "SURVEYSTATUS", "UPDM_LeakSurveyStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "SURVEYMETHOD", "UPDM_LeakSurveyMethod", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERVAL", "UPDM_LeakSurveyFrequency", None)
    logging.debug("     Successfully Assigned 4 Domains to P_LeakSurveyArea")

    logging.debug("Completed setting up the P_LeakSurveyArea featureclass...")
    
    ##############################################################
    # Defining P_LineValveInspection
    ##############################################################
    logging.debug("Create Table P_LineValveInspection class...")
    arcpy.management.CreateTable(targetWorkspace, "P_LineValveInspection", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_LineValveInspection"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 17 Attribute to P_LineValveInspection")
    arcpy.management.AddField(InputDataset, "MANUFACTURER", "TEXT", None, None, 50, "Manufacturer", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MANUFACTUREMODEL", "TEXT", None, None, 30, "Manufacturer Model", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "VALVETYPE", "SHORT", None, None, None, "Valve Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FIGURENO", "TEXT", None, None, 5, "Figure No", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "QUANTITY", "LONG", None, None, None, "Quantity", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "VALVEDIAMETER", "DOUBLE", 8, 4, None, "Valve Diameter", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LINECONNECTION", "TEXT", None, None, 20, "Line Connection", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PRESSURE", "LONG", None, None, None, "Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PRESSUREUNITS", "SHORT", None, None, None, "Pressure Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "VALVEPOSITION", "SHORT", None, None, None, "Valve Position", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 500, "Comments", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UPDMAssembly_GlobalID", "GUID", None, None, None, "UPDMAssembly GlobalID", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 17 Attributes to P_LineValveInspection")

    #Add Domains to Featureclass
    logging.debug("     Assigning 7 Domains to P_LineValveInspection")
    arcpy.management.AssignDomainToField(InputDataset, "MANUFACTURER", "UPDM_ValveManufacturer", None)
    arcpy.management.AssignDomainToField(InputDataset, "MANUFACTUREMODEL", "UPDM_ValveModel", None)
    arcpy.management.AssignDomainToField(InputDataset, "VALVETYPE", "UPDM_ValveControllableType", None)
    arcpy.management.AssignDomainToField(InputDataset, "VALVEDIAMETER", "UPDM_ValveDiameter", None)
    arcpy.management.AssignDomainToField(InputDataset, "LINECONNECTION", "UPDM_LineValveConnection", None)
    arcpy.management.AssignDomainToField(InputDataset, "VALVEPOSITION", "UPDM_ValvePosition", None)
    arcpy.management.AssignDomainToField(InputDataset, "PRESSUREUNITS", "UPDM_UnitsForPressure", None)
    logging.debug("     Successfully Assigned 7 Domains to P_LineValveInspection")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 1 Default Values to P_LineValveInspection")
    arcpy.management.AssignDefaultToField(InputDataset, "PRESSUREUNITS", 1, None, False)

    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMAssembly_P_LineValveInspect"
    arcpy.management.CreateRelationshipClass(UPDMAssembly, InputDataset, RelName, "SIMPLE", "P_LineValveInspection", roleUPDMAssembly, "NONE", "ONE_TO_MANY", "NONE", "GLOBALID", "UPDMAssembly_GlobalID", None, None)
    logging.debug("Completed setting up the P_LineValveInspection featureclass...")

    ##############################################################
    # Defining P_PipeCrossing
    ##############################################################
    logging.debug("Create Point featureclass P_PipeCrossing class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_PipeCrossing", "POINT", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_PipeCrossing"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 20 Attribute to P_PipeCrossing")
    arcpy.management.AddField(InputDataset, "STATUS", "TEXT", None, None, 20, "Status", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "CROSSINGTYPE", "LONG", None, None, None, "Crossing Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CROSSINGFEATURETYPE", "TEXT", None, None, 50, "Crossing Feature Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CROSSINGLOCATION", "TEXT", None, None, 10, "Crossing Location", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LINECLEARANCE", "DOUBLE", 8, 3, None, "Line Clearance", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "EASEMENTWIDTH", "DOUBLE", 8, 3, None, "Easement Width", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEPTHOFPIPE", "DOUBLE", 8, 3, None, "Depth of Pipe", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEPTHUNITS", "SHORT", None, None, None, "Depth Units", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "DEPTHOFCROSSINGFEATURE", "DOUBLE", 8, 3, None, "Depth of Crossing Feature", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 1000, "Comments", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "GPSX", "DOUBLE", 16, 8, None, "GPS X", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GPSY", "DOUBLE", 16, 8, None, "GPSY", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 20 Attributes to P_PipeCrossing")

    #Adding Subtype Values
    arcpy.SetSubtypeField_management(InputDataset, "CROSSINGTYPE", "")
    arcpy.SetDefaultSubtype_management(InputDataset, 0)
    
    logging.debug("     Adding 5 Subtype Codes to P_PipeCrossing")
    arcpy.management.AddSubtype(InputDataset, 0, "Unknown")    
    arcpy.management.AddSubtype(InputDataset, 1, "Pipe Utility")
    arcpy.management.AddSubtype(InputDataset, 2, "Wire Utility")
    arcpy.management.AddSubtype(InputDataset, 3, "Transportation")
    arcpy.management.AddSubtype(InputDataset, 4, "Topographic")
    logging.debug("     5 Subtype Codes created for P_PipeCrossing")

    #Add Domains to Featureclass
    logging.debug("     Assigning 7 Domains to P_PipeCrossing")
    arcpy.management.AssignDomainToField(InputDataset, "CROSSINGFEATURETYPE", "UPDM_PipeCrossingPipeUtility", "1: Pipe Utility")
    arcpy.management.AssignDomainToField(InputDataset, "CROSSINGFEATURETYPE", "UPDM_PipeCrossingWiredUtility", "2: Wire Utility")
    arcpy.management.AssignDomainToField(InputDataset, "CROSSINGFEATURETYPE", "UPDM_PipeCrossingTransportation", "3: Transportation")
    arcpy.management.AssignDomainToField(InputDataset, "CROSSINGFEATURETYPE", "UPDM_PipeCrossingTopographic", "4: Topographic")    
    arcpy.management.AssignDomainToField(InputDataset, "CROSSINGLOCATION", "UPDM_PipeCrossingLocation", "0;1;2;3;4")
    arcpy.management.AssignDomainToField(InputDataset, "STATUS", "UPDM_ObjectStatus", "0;1;2;3;4")
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", "0;1;2;3;4")
    arcpy.management.AssignDomainToField(InputDataset, "DEPTHUNITS", "UPDM_UnitsForDepth", "0;1;2;3;4")
    logging.debug("     Successfully Assigned 7 Domains to P_PipeCrossing")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 1 Default Values to P_PipeCrossing")
    arcpy.management.AssignDefaultToField(InputDataset, "DEPTHUNITS", 2, None, False)

    #Add Relationship class
    pathCrossInspect = targetWorkspace + SQLPrefix + "P_CrossingInspection"
    RelName = targetWorkspace + SQLPrefix + "PipeCrossing_P_CrossingInspect"
    arcpy.management.CreateRelationshipClass(InputDataset, pathCrossInspect, RelName, "SIMPLE", "P_PipeCrossing", "P_CrossingInspection", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "PIPECROSSING_GlobalID", None, None)

    logging.debug("Completed setting up the P_PipeCrossing featureclass...")
    
    ##############################################################
    # Defining P_PipeJobSeparator
    ##############################################################
    logging.debug("Create Point featureclass P_PipeJobSeparator class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_PipeJobSeparator", "POINT", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_PipeJobSeparator"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 20 Attribute to P_PipeJobSeparator")
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "GPSX", "DOUBLE", 16, 8, None, "GPS X", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GPSY", "DOUBLE", 16, 8, None, "GPSY", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
                                           
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 20 Attributes to P_PipeJobSeparator")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_PipeJobSeparator")
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 1 Domains to P_PipeJobSeparator")

    logging.debug("Completed setting up the P_PipeJobSeparator featureclass...")

    ##############################################################
    # Defining P_PipelineMarker
    ##############################################################
    logging.debug("Create Point featureclass P_PipelineMarker class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_PipelineMarker", "POINT", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_PipelineMarker"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 30 Attribute to P_PipelineMarker")
    arcpy.management.AddField(InputDataset, "LEGACYID", "TEXT", None, None, 38, "LegacyID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSTALLATIONDATE", "DATE", None, None, None, "Installation Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONDITION", "TEXT", None, None, None, "Installation Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OWNER", "TEXT", None, None, 50, "Owner", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "DATEINSPECTED", "DATE", None, None, None, "Date Inspected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 50, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NEXTINSPECTIONDATE", "DATE", None, None, None, "Next Inspection Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONDUEDATE", "DATE", None, None, None, "Inspection Due Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTIONFREQUENCY", "SHORT", None, None, None, "Inspection Frequency", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WORKORDERID", "TEXT", None, None, 38, "Work OrderID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PROJECTNUMBER", "TEXT", None, None, 38, "Project Number", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ASSETUNITCODE", "TEXT", None, None, 38, "Asset Unit Code", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SYMBOLROTATION", "DOUBLE", 8, 4, None, "Symbol Rotation", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "GPSX", "DOUBLE", 16, 8, None, "GPS X", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GPSY", "DOUBLE", 16, 8, None, "GPSY", "NULLABLE", "NON_REQUIRED", None)      
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
                                           
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 30 Attributes to P_PipelineMarker")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_PipelineMarker")
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 1 Domains to P_PipelineMarker")

    logging.debug("Completed setting up the P_PipelineMarker featureclass...")

    ##############################################################
    # Defining P_RegulatorInspect
    ##############################################################
    logging.debug("Create Table P_RegulatorInspect class...")
    arcpy.management.CreateTable(targetWorkspace, "P_RegulatorInspect", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_RegulatorInspect"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 17 Attribute to P_RegulatorInspect")
    arcpy.management.AddField(InputDataset, "MANUFACTURER", "TEXT", None, None, 50, "Manufacturer", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MANUFACTUREMODEL", "TEXT", None, None, 30, "Manufacturer Model", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REGULATORTYPE", "TEXT", None, None, 30, "Regulator Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REGULATORDIAMETER", "DOUBLE", 8, 4, None, "Regulator Diameter", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REGULATORCONNECTION", "TEXT", None, None, 15, "Regulator Connection", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PRESSURERATING", "LONG", None, None, None, "Pressure Rating", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PRESSUREUNITS", "SHORT", None, None, None, "Pressure Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PILOTMAKE", "LONG", None, None, None, "Pilot Make", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PILOTCONNECTIONTYPE", "TEXT", None, None, 15, "Pilot Connect Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FLOW", "TEXT", None, None, 15, "Flow", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERMEDIATEPRESSURE", "LONG", None, None, None, "Intermediate Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OUTLETPRESSURE", "LONG", None, None, None, "Outlet Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MAXINLETPRESSURE", "LONG", None, None, None, "Max Inlet Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MINOUTLETPRESSURE", "LONG", None, None, None, "Min Outlet Pressure", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "INTERNALINSPECTION", "SHORT", None, None, None, "Internal Inspection", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INNERVALVE", "SHORT", None, None, None, "Inner Valve", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INNERVALVEDIAMETER", "DOUBLE", 8, 4, None, "Inner Valve Diameter", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERNALLOCKUP", "SHORT", None, None, None, "Internal Lockup", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERNALSETPRESSURE", "SHORT", None, None, None, "Internal Set Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERNALDIAPHRAGMPOSITION", "SHORT", None, None, None, "Internal Diaphragm Position", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERNALVENTPOSITION", "SHORT", None, None, None, "Internal Vent Position", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "INTERNALPILOTS", "SHORT", None, None, None, "Internal Pilots", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERNALCONTROLLINESCLEAR", "SHORT", None, None, None, "Internal Control Lines Clear", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERNALVALVESSECURED", "SHORT", None, None, None, "Internal Valve Secured", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 500, "Comments", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "UPDMDevice_GlobalID", "GUID", None, None, None, "UPDMDevice GlobalID", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)
    logging.debug("     Successfully Added 17 Attributes to P_RegulatorInspect")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 7 Domains to P_RegulatorInspect")
    arcpy.management.AssignDomainToField(InputDataset, "MANUFACTURER", "UPDM_RegulatorManufacturer", None)
    arcpy.management.AssignDomainToField(InputDataset, "MANUFACTUREMODEL", "UPDM_RegulatorModel", None)
    arcpy.management.AssignDomainToField(InputDataset, "REGULATORTYPE", "UPDM_RegulatorType", None)
    arcpy.management.AssignDomainToField(InputDataset, "REGULATORDIAMETER", "UPDM_LineDiameterUnknown", None)
    arcpy.management.AssignDomainToField(InputDataset, "REGULATORCONNECTION", "UPDM_PipeConnectionType", None)
    arcpy.management.AssignDomainToField(InputDataset, "PILOTCONNECTIONTYPE", "UPDM_PilotConnectionType", None)
    arcpy.management.AssignDomainToField(InputDataset, "FLOW", "UPDM_Flow", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERNALINSPECTION", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "INNERVALVE", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "INNERVALVEDIAMETER", "UPDM_LineDiameterUnknown", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERNALLOCKUP", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERNALSETPRESSURE", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERNALDIAPHRAGMPOSITION", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERNALVENTPOSITION", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERNALPILOTS", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERNALCONTROLLINESCLEAR", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERNALVALVESSECURED", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "PRESSUREUNITS", "UPDM_UnitsForPressure", None)
    logging.debug("     Successfully Assigned 7 Domains to P_RegulatorInspect")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 1 Default Values to P_RegulatorInspect")
    arcpy.management.AssignDefaultToField(InputDataset, "PRESSUREUNITS", 1, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "INTERNALINSPECTION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "INNERVALVE", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "INTERNALLOCKUP", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "INTERNALSETPRESSURE", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "INTERNALDIAPHRAGMPOSITION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "INTERNALVENTPOSITION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "INTERNALPILOTS", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "INTERNALCONTROLLINESCLEAR", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "INTERNALVALVESSECURED", 0, None, False)

    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMDevice_P_RegulatorInspect"
    arcpy.management.CreateRelationshipClass(UPDMDevice, InputDataset, RelName, "SIMPLE", roleUPDMDevice, "P_RegulatorInspect", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMDevice_GlobalID", None, None)

    logging.debug("Completed setting up the P_RegulatorInspect featureclass...")
 
    ##############################################################
    # Defining P_ReliefValveInspection
    ##############################################################
    logging.debug("Create Table P_ReliefValveInspection class...")
    arcpy.management.CreateTable(targetWorkspace, "P_ReliefValveInspection", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_ReliefValveInspection"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 20 Attribute to P_ReliefValveInspection")
    arcpy.management.AddField(InputDataset, "MANUFACTURER", "TEXT", None, None, 50, "Manufacturer", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "MANUFACTUREMODEL", "TEXT", None, None, 30, "Manufacturer Model", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "VALVETYPE", "TEXT", None, None, 30, "Relief Valve Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INTERNALTOREGULATOR", "SHORT", None, None, None, "Internal to Regulator", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TOKENRELIEF", "SHORT", None, None, None, "Token Relief", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PROPERREPLACEMENT", "SHORT", None, None, None, "Proper Replacement", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PRESSURERATING", "SHORT", None, None, None, "Pressure Rating", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INNERSIZE", "LONG", None, None, None, "Inner Size", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "FLOWCRITICAL", "SHORT", None, None, None, "Flow Critical", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SAFEPROTECTED", "SHORT", None, None, None, "Safe Protected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STACKCOVERS", "SHORT", None, None, None, "Stack Covers", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SETPOINTPRESSURE", "LONG", None, None, None, "Set Point Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEVICEREACTION", "SHORT", None, None, None, "Device Reaction", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CAPACITYMAOP", "LONG", None, None, None, "Capacity MAOP", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UPDMAssembly_GlobalID", "GUID", None, None, None, "UPDMAssembly GlobalID", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)
    logging.debug("     Successfully Added 20 Attributes to P_ReliefValveInspection")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 7 Domains to P_ReliefValveInspection")
    arcpy.management.AssignDomainToField(InputDataset, "MANUFACTURER", "UPDM_ValveManufacturer", None)
    arcpy.management.AssignDomainToField(InputDataset, "MANUFACTUREMODEL", "UPDM_ValveModel", None)
    #arcpy.management.AssignDomainToField(InputDataset, "VALVETYPE", "UPDM_ValveType", None)
    arcpy.management.AssignDomainToField(InputDataset, "INTERNALTOREGULATOR", "UPDM_YesNoIndicator", None)    
    arcpy.management.AssignDomainToField(InputDataset, "TOKENRELIEF", "UPDM_YesNoIndicator", None)   
    arcpy.management.AssignDomainToField(InputDataset, "PROPERREPLACEMENT", "UPDM_YesNoIndicator", None)    
    arcpy.management.AssignDomainToField(InputDataset, "PRESSURERATING", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "FLOWCRITICAL", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "SAFEPROTECTED", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "STACKCOVERS", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "DEVICEREACTION", "UPDM_PassFailStatus", None)
    logging.debug("     Successfully Assigned 7 Domains to P_ReliefValveInspection")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 7 Default Values to P_ReliefValveInspection")
    arcpy.management.AssignDefaultToField(InputDataset, "INTERNALTOREGULATOR", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "TOKENRELIEF", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "PROPERREPLACEMENT", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "PRESSURERATING", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "FLOWCRITICAL", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "SAFEPROTECTED", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "STACKCOVERS", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "DEVICEREACTION", 0, None, False)
    logging.debug("     Successfully Assigned 7 Default Values to P_ReliefValveInspection")

    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMAssembly_P_ReliefValveInspect"
    arcpy.management.CreateRelationshipClass(UPDMAssembly, InputDataset, RelName, "SIMPLE", roleUPDMAssembly, "P_ReliefValveInspection", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMAssembly_GlobalID", None, None)

    logging.debug("Completed setting up the P_ReliefValveInspection featureclass...")

    ##############################################################
    # Defining P_SqueezeOff
    ##############################################################
    logging.debug("Create Point featureclass P_SqueezeOff class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_SqueezeOff", "POINT", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_SqueezeOff"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 30 Attribute to P_SqueezeOff")
    arcpy.management.AddField(InputDataset, "LEGACYID", "TEXT", None, None, 38, "LegacyID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SQUEEZEOFFDATE", "DATE", None, None, None, "Squeeze Off Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SYMBOLROTATION", "DOUBLE", 8, 4, None, "Symbol Rotation", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "GPSX", "DOUBLE", 16, 8, None, "GPS X", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GPSY", "DOUBLE", 16, 8, None, "GPSY", "NULLABLE", "NON_REQUIRED", None)        
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
                                           
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 30 Attributes to P_SqueezeOff")

    #Add Domains to Featureclass
    logging.debug("     Assigning 1 Domains to P_SqueezeOff")
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 1 Domains to P_SqueezeOff")

    logging.debug("Completed setting up the P_SqueezeOff featureclass...")

    ##############################################################
    # Defining P_StationVisualInsp
    ##############################################################
    logging.debug("Create Table P_StationVisualInspection class...")
    arcpy.management.CreateTable(targetWorkspace, "P_StationVisualInspection", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_StationVisualInspection"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 20 Attribute to P_StationVisualInspection")
    arcpy.management.AddField(InputDataset, "TRASHWEEDS", "SHORT", None, None, None, "Trash Weeds", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ATMOSCORROSION", "SHORT", None, None, None, "Atmospheric Corrosion", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PAINTCONDITION", "SHORT", None, None, None, "Paint Condition", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DETECTABLELEAKS", "SHORT", None, None, None, "Detectable Leaks", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DAMAGETOFACILITIES", "SHORT", None, None, None, "Damage to Facilities", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENCLOSURECONDITION", "SHORT", None, None, None, "Enclosure Recondition", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "BOLTS", "SHORT", None, None, None, "Bolts", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SUPPORTPIPINGRIGID", "SHORT", None, None, None, "Support Piping Rigid", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "STATIONGUARDS", "SHORT", None, None, None, "Station Guards", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "VALVEBOXCONDITION", "SHORT", None, None, None, "Valve Box Condition", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WARNINGSIGNSINPLACE", "SHORT", None, None, None, "Warning Signs in Place", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "UPDMAssembly_GlobalID", "GUID", None, None, None, "UPDMAssembly GlobalID", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)
    
    logging.debug("     Successfully Added 20 Attributes to P_StationVisualInspection")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 11 Domains to P_StationVisualInspection")
    arcpy.management.AssignDomainToField(InputDataset, "TRASHWEEDS", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "ATMOSCORROSION", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "PAINTCONDITION", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "DETECTABLELEAKS", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "DAMAGETOFACILITIES", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "ENCLOSURECONDITION", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "BOLTS", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "SUPPORTPIPINGRIGID", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "STATIONGUARDS", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "VALVEBOXCONDITION", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "WARNINGSIGNSINPLACE", "UPDM_PassFailStatus", None)
    
    logging.debug("     Successfully Assigned 11 Domains to P_StationVisualInspection")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 11 Default Values to P_StationVisualInspection")
    arcpy.management.AssignDefaultToField(InputDataset, "TRASHWEEDS", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "ATMOSCORROSION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "PAINTCONDITION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "DETECTABLELEAKS", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "DAMAGETOFACILITIES", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "BOLTS", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "ENCLOSURECONDITION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "SUPPORTPIPINGRIGID", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "STATIONGUARDS", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "VALVEBOXCONDITION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "WARNINGSIGNSINPLACE", 0, None, False)
   
    logging.debug("     Successfully Assigned 11 Default Values to P_StationVisualInspection")

    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMAssembly_P_StatVisInspect"
    arcpy.management.CreateRelationshipClass(UPDMAssembly, InputDataset, RelName, "SIMPLE", roleUPDMAssembly, "P_StationVisualInspection", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMAssembly_GlobalID", None, None)

    logging.debug("Completed setting up the P_StationVisualInspection featureclass...")

    ##############################################################
    # Defining P_StrainerInspect
    ##############################################################
    logging.debug("Create Table P_StrainerInspect class...")
    arcpy.management.CreateTable(targetWorkspace, "P_StrainerInspect", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_StrainerInspect"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 20 Attribute to P_StrainerInspect")
    arcpy.management.AddField(InputDataset, "STRAINERMANUFACTURER", "TEXT", None, None, 50, "Strainer Manufacturer", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STRAINERMODEL", "TEXT", None, None, 30, "Strainer Model", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTROLLINEMANUFACTURER", "TEXT", None, None, 50, "Control Line Manufacturer", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTROLLINEMODEL", "TEXT", None, None, 30, "Control Line Model", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DEVICETYPE", "TEXT", None, None, 15, "Device Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DIFFERENTIALPRESSURE", "SHORT", None, None, None, "Differential Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LEAKS", "SHORT", None, None, None, "LEAKS", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 150, "Comments", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "UPDMDevice_GlobalID", "GUID", None, None, None, "UPDMDevice GlobalID", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)  
    logging.debug("     Successfully Added 20 Attributes to P_StrainerInspect")
    
    #Add Domains to Featureclass
    logging.debug("     Assigning 7 Domains to P_StrainerInspect")
    arcpy.management.AssignDomainToField(InputDataset, "STRAINERMANUFACTURER", "UPDM_StrainerManufacturer", None)
    arcpy.management.AssignDomainToField(InputDataset, "STRAINERMODEL", "UPDM_StrainerModel", None)
    arcpy.management.AssignDomainToField(InputDataset, "CONTROLLINEMANUFACTURER", "UPDM_ControlLineManufacturer", None)
    arcpy.management.AssignDomainToField(InputDataset, "CONTROLLINEMODEL", "UPDM_ControlLineModel", None)
    arcpy.management.AssignDomainToField(InputDataset, "DEVICETYPE", "UPDM_StrainerDeviceType", None)
    arcpy.management.AssignDomainToField(InputDataset, "DIFFERENTIALPRESSURE", "UPDM_PassFailStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "LEAKS", "UPDM_YesNoIndicator", None)  
    logging.debug("     Successfully Assigned 7 Domains to P_StrainerInspect")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 2 Default Values to P_StrainerInspect")
    arcpy.management.AssignDefaultToField(InputDataset, "DIFFERENTIALPRESSURE", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "LEAKS", 0, None, False)
    logging.debug("     Successfully Assigned 2 Default Values to P_StrainerInspect")

    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMDevice_P_StrainerInspect"
    arcpy.management.CreateRelationshipClass(UPDMDevice, InputDataset, RelName, "SIMPLE", roleUPDMDevice, "P_StrainerInspect", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMDevice_GlobalID", None, None)

    logging.debug("Completed setting up the P_StrainerInspect featureclass...")

    ##############################################################
    # Defining P_StructureFootprint
    ##############################################################
    logging.debug("Create Polygon featureclass P_StructureFootPrint class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_StructureFootPrint", "POLYGON", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_StructureFootPrint"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 24 Attribute to P_StructureFootPrint")
    arcpy.management.AddField(InputDataset, "STRUCTURENAME", "TEXT", None, None, 50, "Structure Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STRUCTURETYPE", "TEXT", None, None, 30, "Structure Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STRUCTURESTATUS", "TEXT", None, None, 20, "Structure Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "HUMANOCCUPANCY", "SHORT", None, None, None, "Human Occupancy", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "DAYSPERWEEK", "SHORT", None, None, None, "Days Per Week", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LIMITEDMOBILITY", "SHORT", None, None, None, "Limited Mobility", "NULLABLE", "NON_REQUIRED", None)        
    arcpy.management.AddField(InputDataset, "LIMITEDMOBILITYREASON", "TEXT", None, None, 50, "Limited Mobility Reason", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "IMPAIREDMOBILITY", "SHORT", None, None, None, "Impaired Mobility", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GATHERINGPLACE", "SHORT", None, None, None, "Gathering Place", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DISCOVERYDATE", "DATE", None, None, None, "Discovery Place", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOURCE", "TEXT", None, None, 50, "Source", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OCCUPANTCOUNT", "SHORT", None, None, None, "Occupant Count", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NUMBEROFSTORIES", "SHORT", None, None, None, "Number of Stories", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NUMBEROFUNITS", "SHORT", None, None, None, "Number of Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WEEKSPERYEAR", "SHORT", None, None, None, "Weeks Per Year", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "IDENTIFIEDSITE", "SHORT", None, None, None, "Identified Site", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "IDENTIFIEDSITETYPE", "TEXT", None, None, 50, "Identified Site Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 24 Attributes to P_StructureFootPrint")

    #Add Domains to Featureclass
    logging.debug("     Assigning 11 Domains to P_StructureFootPrint")
    arcpy.management.AssignDomainToField(InputDataset, "STRUCTURETYPE", "UPDM_StructureType", None)
    arcpy.management.AssignDomainToField(InputDataset, "STRUCTURESTATUS", "UPDM_ObjectStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "HUMANOCCUPANCY", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "DAYSPERWEEK", "UPDM_DaysPerWeek", None)
    arcpy.management.AssignDomainToField(InputDataset, "WEEKSPERYEAR", "UPDM_WeeksPerYear", None)
    arcpy.management.AssignDomainToField(InputDataset, "LIMITEDMOBILITY", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "LIMITEDMOBILITYREASON", "UPDM_StructureLimitedMobility", None)
    arcpy.management.AssignDomainToField(InputDataset, "IMPAIREDMOBILITY", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "GATHERINGPLACE", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "IDENTIFIEDSITE", "UPDM_YesNoIndicator", None)    
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 11 Domains to P_StructureFootPrint")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 2 Default Values to P_StuctureFootPrint")
    arcpy.management.AssignDefaultToField(InputDataset, "HUMANOCCUPANCY", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "LIMITEDMOBILITY", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "IMPAIREDMOBILITY", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "GATHERINGPLACE", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "IDENTIFIEDSITE", 0, None, False)
    logging.debug("     Successfully Assigned 2 Default Values to P_StructureFootPrint")

    logging.debug("Completed setting up the P_StructureFootPrint featureclass...")

    ##############################################################
    # Defining P_StructurePoint
    ##############################################################
    logging.debug("Create Point featureclass P_StructurePoint class...")
    arcpy.management.CreateFeatureclass(targetWorkspace, "P_StructurePoint", "POINT", None, "ENABLED", "ENABLED", featureDataset, None, 0, 0, 0)
    InputDataset = targetWorkspace + SQLPrefix + "P_StructurePoint"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 38 Attribute to P_StructurePoint")
    arcpy.management.AddField(InputDataset, "STRUCTURENAME", "TEXT", None, None, 50, "Structure Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STRUCTURETYPE", "TEXT", None, None, 30, "Structure Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "STRUCTURESTATUS", "TEXT", None, None, 20, "Structure Status", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "HUMANOCCUPANCY", "SHORT", None, None, None, "Human Occupancy", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "DAYSPERWEEK", "SHORT", None, None, None, "Days Per Week", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "LIMITEDMOBILITY", "SHORT", None, None, None, "Limited Mobility", "NULLABLE", "NON_REQUIRED", None)        
    arcpy.management.AddField(InputDataset, "LIMITEDMOBILITYREASON", "TEXT", None, None, 50, "Limited Mobility Reason", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "IMPAIREDMOBILITY", "SHORT", None, None, None, "Impaired Mobility", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GATHERINGPLACE", "SHORT", None, None, None, "Gathering Place", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DISCOVERYDATE", "DATE", None, None, None, "Discovery Place", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SOURCE", "TEXT", None, None, 50, "Source", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OCCUPANTCOUNT", "SHORT", None, None, None, "Occupant Count", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NUMBEROFSTORIES", "SHORT", None, None, None, "Number of Stories", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "NUMBEROFUNITS", "SHORT", None, None, None, "Number of Units", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "WEEKSPERYEAR", "SHORT", None, None, None, "Weeks Per Year", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DESCRIPTION", "TEXT", None, None, 255, "Description", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "IDENTIFIEDSITE", "SHORT", None, None, None, "Identified Site", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "IDENTIFIEDSITETYPE", "TEXT", None, None, 50, "Identified Site Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SPATIALACCURACY", "SHORT", None, None, None, "Spatial Accuracy", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GPSX", "DOUBLE", 16, 8, None, "GPS X", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GPSY", "DOUBLE", 16, 8, None, "GPSY", "NULLABLE", "NON_REQUIRED", None)        
    arcpy.management.AddField(InputDataset, "EVENTID", "TEXT", None, None, 38, "EventID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "FROMDATE", "DATE", None, None, None, "From Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TODATE", "DATE", None, None, None, "To Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTEID", "TEXT", None, None, 38, "Engineering RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGROUTENAME", "TEXT", None, None, 100, "Engineering Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ENGM", "DOUBLE", 16, 5, None, "Engineering Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTEID", "TEXT", None, None, 38, "Continuous RouteID", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINROUTENAME", "TEXT", None, None, 100, "Continuous Route Name", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "CONTINM", "DOUBLE", 16, 5, None, "Continuous Measure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFMETHOD", "SHORT", None, None, None, "Reference Method", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFOFFSET", "TEXT", None, None, 50, "Reference Offset", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REFLOCATION", "TEXT", None, None, 50, "Reference Location", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)
    logging.debug("     Successfully Added 38 Attributes to P_StructurePoint")

    #Add Domains to Featureclass
    logging.debug("     Assigning 11 Domains to P_StructurePoint")
    arcpy.management.AssignDomainToField(InputDataset, "STRUCTURETYPE", "UPDM_StructureType", None)
    arcpy.management.AssignDomainToField(InputDataset, "STRUCTURESTATUS", "UPDM_ObjectStatus", None)
    arcpy.management.AssignDomainToField(InputDataset, "HUMANOCCUPANCY", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "DAYSPERWEEK", "UPDM_DaysPerWeek", None)
    arcpy.management.AssignDomainToField(InputDataset, "WEEKSPERYEAR", "UPDM_WeeksPerYear", None)
    arcpy.management.AssignDomainToField(InputDataset, "LIMITEDMOBILITY", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "LIMITEDMOBILITYREASON", "UPDM_StructureLimitedMobility", None)
    arcpy.management.AssignDomainToField(InputDataset, "IMPAIREDMOBILITY", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "GATHERINGPLACE", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "IDENTIFIEDSITE", "UPDM_YesNoIndicator", None)    
    arcpy.management.AssignDomainToField(InputDataset, "SPATIALACCURACY", "UPDM_SpatialAccuracy", None)
    logging.debug("     Successfully Assigned 11 Domains to P_StructurePoint")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 2 Default Values to P_StucturePoint")
    arcpy.management.AssignDefaultToField(InputDataset, "HUMANOCCUPANCY", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "LIMITEDMOBILITY", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "IMPAIREDMOBILITY", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "GATHERINGPLACE", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "IDENTIFIEDSITE", 0, None, False)
    logging.debug("     Successfully Assigned 2 Default Values to P_StructurePoint")

    logging.debug("Completed setting up the P_StructurePoint featureclass...")

    ##############################################################
    # Defining UPDM_ValveInspection
    ##############################################################
    logging.debug("Create Table P_ValveInspection class...")
    
    # Delete sample Valve Inspection table provided with core
##    InputDataset = targetWorkspace + SQLPrefix + "ValveInspection"
##    arcpy.management.Delete(targetWorkspace, "Table")
    # Recreate Valve Inspection table with UPDM configuration
    arcpy.management.CreateTable(targetWorkspace, "P_ValveInspection", None, None)
    InputDataset = targetWorkspace + SQLPrefix + "P_ValveInspection"
                                           
    #Adding Attributes to featureclass
    logging.debug("     Adding 24 Attribute to P_ValveInspection")
    arcpy.management.AddField(InputDataset, "INSPECTEDBY", "TEXT", None, None, 50, "Inspected By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "DATEINSPECTED", "DATE", None, None, None, "Date Inspected", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "INSPECTEDNUMBER", "TEXT", None, None, 20, "Inspected Number", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SYSTEMTYPE", "SHORT", None, None, None, "System Type", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ATMOSCORROSION", "SHORT", None, None, None, "Atmospheric Corrosion", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REQUIREPAINT", "SHORT", None, None, None, "Differential Pressure", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "GOODCONDITION", "SHORT", None, None, None, "Good Condition", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REQUIRELUBRICATION", "SHORT", None, None, None, "Require Lubrication", "NULLABLE", "NON_REQUIRED", None)    
    arcpy.management.AddField(InputDataset, "LUBRICATED", "SHORT", None, None, None, "Lubricated", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "TAGGED", "SHORT", None, None, None, "Tagged", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "OPERATING", "SHORT", None, None, None, "Operating", "NULLABLE", "NON_REQUIRED", None)  
    arcpy.management.AddField(InputDataset, "SECURED", "SHORT", None, None, None, "Secured", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "ACCESSIBLE", "SHORT", None, None, None, "Accessible", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "SIGNS", "SHORT", None, None, None, "Signs", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "VALVEBOXCOND", "SHORT", None, None, None, "Valve Box Condition", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "PROTECTFROMDAMAGE", "SHORT", None, None, None, "Protect From Damage", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REVIEWEDBY", "TEXT", None, None, 50, "Reviewed By", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "REVIEWEDDATE", "DATE", None, None, None, "Reviewed Date", "NULLABLE", "NON_REQUIRED", None)
    arcpy.management.AddField(InputDataset, "COMMENTS", "TEXT", None, None, 500, "Comments", "NULLABLE", "NON_REQUIRED", None)  
    arcpy.management.AddField(InputDataset, "UPDMDevice_GlobalID", "GUID", None, None, None, "UPDMDevice GlobalID", "NULLABLE", "NON_REQUIRED", None)
    
    #Add Editor Tracking attributes and Enable Editor Tracking
    arcpy.management.EnableEditorTracking(InputDataset, "CREATOR", "CREATIONDATE", "UPDATEDBY", "LASTUPDATE", "ADD_FIELDS", "UTC")
    
    #Add GlobalID to featureclass
    arcpy.management.AddGlobalIDs(InputDataset)

    #Enable Attachments
    arcpy.EnableAttachments_management(InputDataset)
    logging.debug("     Successfully Added 24 Attributes to P_ValveInspection")

    #Add Domains to Featureclass
    logging.debug("     Assigning 13 Domains to P_ValveInspection")
    arcpy.management.AssignDomainToField(InputDataset, "SYSTEMTYPE", "UPDM_RegulatoryType", None)
    arcpy.management.AssignDomainToField(InputDataset, "ATMOSCORROSION", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "REQUIREPAINT", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "GOODCONDITION", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "REQUIRELUBRICATION", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "LUBRICATED", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "TAGGED", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "OPERATING", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "SECURED", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "ACCESSIBLE", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "SIGNS", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "VALVEBOXCOND", "UPDM_YesNoIndicator", None)
    arcpy.management.AssignDomainToField(InputDataset, "PROTECTFROMDAMAGE", "UPDM_YesNoIndicator", None)    
    logging.debug("     Successfully Assigned 13 Domains to P_ValveInspection")

    #Add Default Values to Featureclass
    logging.debug("     Assigning 12 Default Values to P_ValveInspection")
    arcpy.management.AssignDefaultToField(InputDataset, "ATMOSCORROSION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "REQUIREPAINT", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "GOODCONDITION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "REQUIRELUBRICATION", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "LUBRICATED", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "TAGGED", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "OPERATING", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "SECURED", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "ACCESSIBLE", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "SIGNS", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "VALVEBOXCOND", 0, None, False)
    arcpy.management.AssignDefaultToField(InputDataset, "PROTECTFROMDAMAGE", 0, None, False)    
    logging.debug("     Successfully Assigned 12 Default Values to P_ValveInspection")

    #Add Relationship class
    RelName = targetWorkspace + featureDataset + SQLPrefix + "UPDMDevice_P_ValveInspect"
    arcpy.management.CreateRelationshipClass(UPDMDevice, InputDataset, RelName, "SIMPLE", roleUPDMDevice, "P_ValveInspection", "NONE", "ONE_TO_MANY", "NONE", "GlobalID", "UPDMDevice_GlobalID", None, None)

    logging.debug("Completed setting up the P_ValveInspection featureclass...")


    endTime = timer()
    totalElapsedTime = endTime - startTime
    logging.debug("OVERALL PROCESS COMPLETE in : " + str(totalElapsedTime))

    print(arcpy.GetMessages())
    logging.shutdown()
except:
    logging.debug("Exception occurred")
    logging.shutdown()
